import Vue from 'vue';
import Router from 'vue-router';
import { AuthGuard } from '@/utils';
import qs from 'qs';
import { globalRoutes, indexRoutes} from '@/router'

Vue.use(Router);

const router = new Router({
    routes: [
        {
            path: '/appindex/:appindex?',
            beforeEnter: (to: any, from: any, next: any) => {
                const routerParamsName = 'appindex';
                const params: any = {};
                if (to.params && to.params[routerParamsName]) {
                    Object.assign(params, qs.parse(to.params[routerParamsName], { delimiter: ';' }));
                }
                const url: string = '/appdata';
                const auth: Promise<any> = AuthGuard.getInstance().authGuard(url, params, router);
                auth.then(() => {
                    next();
                }).catch(() => {
                    next();
                });
            },
            meta: {  
                caption: 'app.views.appindex.caption',
                viewType: 'APPINDEX',
                parameters: [
                    { pathName: 'appindex', parameterName: 'appindex' },
                ],
                requireAuth: true,
            },
            component: () => import('@pages/ungroup/app-index/app-index.vue'),
            children: [
                {
                    path: 'emservices/:emservice?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emservice.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emserviceedit-view9-edit-mode/emserviceedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emserviceevls/:emserviceevl?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emserviceevl.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emserviceevls', parameterName: 'emserviceevl' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emserviceevledit-view9/emserviceevledit-view9.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqahs/:emeqah?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqah.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqahs', parameterName: 'emeqah' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqahgrid-view/emeqahgrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqahs/:emeqah?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqah.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqahs', parameterName: 'emeqah' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqahgrid-view/emeqahgrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqahs/:emeqah?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqah.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqahs', parameterName: 'emeqah' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqahgrid-view/emeqahgrid-view.vue'),
                },
                {
                    path: 'emeqahs/:emeqah?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqah.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqahs', parameterName: 'emeqah' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqahgrid-view/emeqahgrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/editview/:editview?',
                    meta: {
                        caption: 'entities.emequip.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emequipedit-view/emequipedit-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/editview/:editview?',
                    meta: {
                        caption: 'entities.emequip.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emequipedit-view/emequipedit-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/editview/:editview?',
                    meta: {
                        caption: 'entities.emequip.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emequipedit-view/emequipedit-view.vue'),
                },
                {
                    path: 'emserviceevls/:emserviceevl?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emserviceevl.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emserviceevls', parameterName: 'emserviceevl' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emserviceevlgrid-view/emserviceevlgrid-view.vue'),
                },
                {
                    path: 'emeqlcttires/:emeqlcttires?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emeqlcttires.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlcttires', parameterName: 'emeqlcttires' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqlcttirespickup-view/emeqlcttirespickup-view.vue'),
                },
                {
                    path: 'emeqlcttires/:emeqlcttires?/editview/:editview?',
                    meta: {
                        caption: 'entities.emeqlcttires.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlcttires', parameterName: 'emeqlcttires' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqlcttiresedit-view/emeqlcttiresedit-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emen.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emengrid-view/emengrid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emen/:emen?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emen.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emengrid-view/emengrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emen/:emen?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emen.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emengrid-view/emengrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emen/:emen?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emen.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emengrid-view/emengrid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emen.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emengrid-view/emengrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emen/:emen?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emen.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emengrid-view/emengrid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emen/:emen?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emen.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emengrid-view/emengrid-view.vue'),
                },
                {
                    path: 'emen/:emen?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emen.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emengrid-view/emengrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emen.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenedit-view9/emenedit-view9.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emen/:emen?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emen.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenedit-view9/emenedit-view9.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emen/:emen?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emen.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenedit-view9/emenedit-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emen/:emen?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emen.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenedit-view9/emenedit-view9.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emen.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenedit-view9/emenedit-view9.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emen/:emen?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emen.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenedit-view9/emenedit-view9.vue'),
                },
                {
                    path: 'emitems/:emitem?/emen/:emen?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emen.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenedit-view9/emenedit-view9.vue'),
                },
                {
                    path: 'emen/:emen?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emen.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenedit-view9/emenedit-view9.vue'),
                },
                {
                    path: 'emeitires/:emeitires?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emeitires.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeitires', parameterName: 'emeitires' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeitirespickup-view/emeitirespickup-view.vue'),
                },
                {
                    path: 'emitempls/:emitempl?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempl.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitempls', parameterName: 'emitempl' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempledit-view9-edit-mode/emitempledit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emplan.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emplan.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emplan.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emplan.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emplan.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emplan.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emplan.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplans/:emplan?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emplan.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplans/:emplan?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emplan.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplans/:emplan?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emplan.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplans/:emplan?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emplan.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
                },
                {
                    path: 'emplantempls/:emplantempl?/emplans/:emplan?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emplan.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emplans/:emplan?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emplan.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplans/:emplan?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emplan.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
                },
                {
                    path: 'emplans/:emplan?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emplan.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
                },
                {
                    path: 'emitemtypes/:emitemtype?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emitemtype.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemtypes', parameterName: 'emitemtype' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtypetree-exp-view/emitemtypetree-exp-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emstorepart.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstorepartgrid-view/emstorepartgrid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emstorepart.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstorepartgrid-view/emstorepartgrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emwplist.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplisttree-exp-view/emwplisttree-exp-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emwplists/:emwplist?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emwplist.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplisttree-exp-view/emwplisttree-exp-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emwplists/:emwplist?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emwplist.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplisttree-exp-view/emwplisttree-exp-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emwplists/:emwplist?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emwplist.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplisttree-exp-view/emwplisttree-exp-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emwplist.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplisttree-exp-view/emwplisttree-exp-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emwplists/:emwplist?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emwplist.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplisttree-exp-view/emwplisttree-exp-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emwplists/:emwplist?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emwplist.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplisttree-exp-view/emwplisttree-exp-view.vue'),
                },
                {
                    path: 'emwplists/:emwplist?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emwplist.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplisttree-exp-view/emwplisttree-exp-view.vue'),
                },
                {
                    path: 'emitemcs/:emitemcs?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemcs.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemcs', parameterName: 'emitemcs' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemcsedit-view9/emitemcsedit-view9.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.pfdept.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-pf/pfdeptpickup-grid-view/pfdeptpickup-grid-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfomos/:emrfomo?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emrfomo.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfomopickup-view/emrfomopickup-view.vue'),
                },
                {
                    path: 'emrfomos/:emrfomo?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emrfomo.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfomopickup-view/emrfomopickup-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfomos/:emrfomo?/emrfocas/:emrfoca?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emrfoca.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'emrfocas', parameterName: 'emrfoca' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfocapickup-view/emrfocapickup-view.vue'),
                },
                {
                    path: 'emrfomos/:emrfomo?/emrfocas/:emrfoca?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emrfoca.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'emrfocas', parameterName: 'emrfoca' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfocapickup-view/emrfocapickup-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfocas/:emrfoca?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emrfoca.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfocas', parameterName: 'emrfoca' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfocapickup-view/emrfocapickup-view.vue'),
                },
                {
                    path: 'emrfocas/:emrfoca?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emrfoca.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfocas', parameterName: 'emrfoca' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfocapickup-view/emrfocapickup-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emwo_dps/:emwo_dp?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_dp.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpgrid-view/emwo-dpgrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emwo_dps/:emwo_dp?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_dp.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpgrid-view/emwo-dpgrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emwo_dps/:emwo_dp?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_dp.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpgrid-view/emwo-dpgrid-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emwo_dps/:emwo_dp?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_dp.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpgrid-view/emwo-dpgrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emwo_dps/:emwo_dp?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_dp.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpgrid-view/emwo-dpgrid-view.vue'),
                },
                {
                    path: 'emwo_dps/:emwo_dp?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_dp.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpgrid-view/emwo-dpgrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emwo_inners/:emwo_inner?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_inner.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-innergrid-view/emwo-innergrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emwo_inners/:emwo_inner?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_inner.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-innergrid-view/emwo-innergrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emwo_inners/:emwo_inner?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_inner.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-innergrid-view/emwo-innergrid-view.vue'),
                },
                {
                    path: 'emwo_inners/:emwo_inner?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_inner.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-innergrid-view/emwo-innergrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emservice.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emserviceedit-view9/emserviceedit-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/editview_7215/:editview_7215?',
                    meta: {
                        caption: 'entities.emstorepart.views.editview_7215.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'editview_7215', parameterName: 'editview_7215' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstorepartedit-view-7215/emstorepartedit-view-7215.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/editview_7215/:editview_7215?',
                    meta: {
                        caption: 'entities.emstorepart.views.editview_7215.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'editview_7215', parameterName: 'editview_7215' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstorepartedit-view-7215/emstorepartedit-view-7215.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emapplies/:emapply?/editview/:editview?',
                    meta: {
                        caption: 'entities.emapply.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emapplies', parameterName: 'emapply' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emapplyedit-view/emapplyedit-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emapplies/:emapply?/editview/:editview?',
                    meta: {
                        caption: 'entities.emapply.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emapplies', parameterName: 'emapply' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emapplyedit-view/emapplyedit-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emapplies/:emapply?/editview/:editview?',
                    meta: {
                        caption: 'entities.emapply.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emapplies', parameterName: 'emapply' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emapplyedit-view/emapplyedit-view.vue'),
                },
                {
                    path: 'emapplies/:emapply?/editview/:editview?',
                    meta: {
                        caption: 'entities.emapply.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emapplies', parameterName: 'emapply' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emapplyedit-view/emapplyedit-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqmaintances/:emeqmaintance?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqmaintance.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqmaintanceedit-view9/emeqmaintanceedit-view9.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqmaintances/:emeqmaintance?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqmaintance.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqmaintanceedit-view9/emeqmaintanceedit-view9.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqmaintances/:emeqmaintance?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqmaintance.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqmaintanceedit-view9/emeqmaintanceedit-view9.vue'),
                },
                {
                    path: 'emeqmaintances/:emeqmaintance?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqmaintance.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqmaintanceedit-view9/emeqmaintanceedit-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitem.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempickup-grid-view/emitempickup-grid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitem.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempickup-grid-view/emitempickup-grid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitem.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempickup-grid-view/emitempickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitem.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempickup-grid-view/emitempickup-grid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitem.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempickup-grid-view/emitempickup-grid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitem.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempickup-grid-view/emitempickup-grid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitem.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempickup-grid-view/emitempickup-grid-view.vue'),
                },
                {
                    path: 'emitemtypes/:emitemtype?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emitemtype.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemtypes', parameterName: 'emitemtype' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemtypeedit-view-edit-mode/emitemtypeedit-view-edit-mode.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqsetups/:emeqsetup?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqsetup.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqsetupgrid-view/emeqsetupgrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqsetups/:emeqsetup?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqsetup.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqsetupgrid-view/emeqsetupgrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqsetups/:emeqsetup?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqsetup.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqsetupgrid-view/emeqsetupgrid-view.vue'),
                },
                {
                    path: 'emeqsetups/:emeqsetup?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqsetup.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqsetupgrid-view/emeqsetupgrid-view.vue'),
                },
                {
                    path: 'emoutputs/:emoutput?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emoutput.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emoutputs', parameterName: 'emoutput' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emoutputpickup-view/emoutputpickup-view.vue'),
                },
                {
                    path: 'emoutputs/:emoutput?/emoutputrcts/:emoutputrct?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emoutputrct.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emoutputs', parameterName: 'emoutput' },
                            { pathName: 'emoutputrcts', parameterName: 'emoutputrct' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emoutputrctgrid-view/emoutputrctgrid-view.vue'),
                },
                {
                    path: 'emoutputrcts/:emoutputrct?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emoutputrct.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emoutputrcts', parameterName: 'emoutputrct' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emoutputrctgrid-view/emoutputrctgrid-view.vue'),
                },
                {
                    path: 'emeqlocations/:emeqlocation?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqlocation.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlocations', parameterName: 'emeqlocation' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqlocationedit-view9/emeqlocationedit-view9.vue'),
                },
                {
                    path: 'emservices/:emservice?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emservice.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emservicepickup-grid-view/emservicepickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/editview/:editview?',
                    meta: {
                        caption: 'entities.emitem.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemedit-view/emitemedit-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/editview/:editview?',
                    meta: {
                        caption: 'entities.emitem.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemedit-view/emitemedit-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/editview/:editview?',
                    meta: {
                        caption: 'entities.emitem.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemedit-view/emitemedit-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/editview/:editview?',
                    meta: {
                        caption: 'entities.emitem.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemedit-view/emitemedit-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/editview/:editview?',
                    meta: {
                        caption: 'entities.emitem.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemedit-view/emitemedit-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/editview/:editview?',
                    meta: {
                        caption: 'entities.emitem.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemedit-view/emitemedit-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/editview/:editview?',
                    meta: {
                        caption: 'entities.emitem.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemedit-view/emitemedit-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqkeeps/:emeqkeep?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqkeep.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqkeepedit-view9-edit-mode/emeqkeepedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqkeeps/:emeqkeep?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqkeep.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqkeepedit-view9-edit-mode/emeqkeepedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqkeeps/:emeqkeep?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqkeep.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqkeepedit-view9-edit-mode/emeqkeepedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emeqkeeps/:emeqkeep?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqkeep.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqkeepedit-view9-edit-mode/emeqkeepedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitemrin.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinpickup-view/emitemrinpickup-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitemrins/:emitemrin?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitemrin.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinpickup-view/emitemrinpickup-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitemrins/:emitemrin?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitemrin.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinpickup-view/emitemrinpickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitemrins/:emitemrin?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitemrin.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinpickup-view/emitemrinpickup-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitemrin.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinpickup-view/emitemrinpickup-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitemrins/:emitemrin?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitemrin.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinpickup-view/emitemrinpickup-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitemrins/:emitemrin?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitemrin.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinpickup-view/emitemrinpickup-view.vue'),
                },
                {
                    path: 'emitemrins/:emitemrin?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitemrin.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinpickup-view/emitemrinpickup-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplans/:emplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplans/:emplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplans/:emplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplans/:emplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
                },
                {
                    path: 'emplantempls/:emplantempl?/emplans/:emplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emplans/:emplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplans/:emplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
                },
                {
                    path: 'emplans/:emplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqchecks/:emeqcheck?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqcheck.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqcheckedit-view9-edit-mode/emeqcheckedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqchecks/:emeqcheck?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqcheck.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqcheckedit-view9-edit-mode/emeqcheckedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqchecks/:emeqcheck?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqcheck.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqcheckedit-view9-edit-mode/emeqcheckedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emeqchecks/:emeqcheck?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqcheck.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqcheckedit-view9-edit-mode/emeqcheckedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emrfode.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfodetab-exp-view/emrfodetab-exp-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emstocks/:emstock?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emstocks/:emstock?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emstocks/:emstock?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emstocks/:emstock?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emstocks/:emstock?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emstocks/:emstock?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emstocks/:emstock?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstocks/:emstock?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emstocks/:emstock?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emstocks/:emstock?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
                },
                {
                    path: 'emstocks/:emstock?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'empurplans/:empurplan?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empurplans', parameterName: 'empurplan' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'emequips/:emequip?/emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'emitempuses/:emitempuse?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emwo_oscs/:emwo_osc?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_osc.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-oscedit-view-edit-mode/emwo-oscedit-view-edit-mode.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emwo_oscs/:emwo_osc?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_osc.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-oscedit-view-edit-mode/emwo-oscedit-view-edit-mode.vue'),
                },
                {
                    path: 'emequips/:emequip?/emwo_oscs/:emwo_osc?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_osc.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-oscedit-view-edit-mode/emwo-oscedit-view-edit-mode.vue'),
                },
                {
                    path: 'emwo_oscs/:emwo_osc?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_osc.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-oscedit-view-edit-mode/emwo-oscedit-view-edit-mode.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqdebugs/:emeqdebug?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqdebug.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqdebugedit-view9/emeqdebugedit-view9.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqdebugs/:emeqdebug?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqdebug.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqdebugedit-view9/emeqdebugedit-view9.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqdebugs/:emeqdebug?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqdebug.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqdebugedit-view9/emeqdebugedit-view9.vue'),
                },
                {
                    path: 'emeqdebugs/:emeqdebug?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqdebug.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqdebugedit-view9/emeqdebugedit-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
                },
                {
                    path: 'empos/:empo?/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empos', parameterName: 'empo' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emitems/:emitem?/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
                },
                {
                    path: 'empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emstore.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstorepickup-view/emstorepickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
                },
                {
                    path: 'emstocks/:emstock?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emstock.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
                },
                {
                    path: 'pfcontracts/:pfcontract?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.pfcontract.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfcontracts', parameterName: 'pfcontract' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-pf/pfcontractedit-view9/pfcontractedit-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'empurplans/:empurplan?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empurplans', parameterName: 'empurplan' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'emitempuses/:emitempuse?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
                },
                {
                    path: 'emwooris/:emwoori?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwoori.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwooris', parameterName: 'emwoori' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwooripickup-view/emwooripickup-view.vue'),
                },
                {
                    path: 'emeqlctrhies/:emeqlctrhy?/editview/:editview?',
                    meta: {
                        caption: 'entities.emeqlctrhy.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlctrhies', parameterName: 'emeqlctrhy' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqlctrhyedit-view/emeqlctrhyedit-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemprtn.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemprtnedit-view9/emitemprtnedit-view9.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemprtn.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemprtnedit-view9/emitemprtnedit-view9.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemprtn.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemprtnedit-view9/emitemprtnedit-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemprtn.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemprtnedit-view9/emitemprtnedit-view9.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemprtn.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemprtnedit-view9/emitemprtnedit-view9.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemprtn.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemprtnedit-view9/emitemprtnedit-view9.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitemprtns/:emitemprtn?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemprtn.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemprtnedit-view9/emitemprtnedit-view9.vue'),
                },
                {
                    path: 'emitemprtns/:emitemprtn?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemprtn.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemprtnedit-view9/emitemprtnedit-view9.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplans/:emplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplans/:emplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplans/:emplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplans/:emplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
                },
                {
                    path: 'emplantempls/:emplantempl?/emplans/:emplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emplans/:emplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplans/:emplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
                },
                {
                    path: 'emplans/:emplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emplan.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emdrwgs/:emdrwg?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emdrwg.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emdrwgs', parameterName: 'emdrwg' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emdrwgedit-view-edit-mode/emdrwgedit-view-edit-mode.vue'),
                },
                {
                    path: 'emdrwgs/:emdrwg?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emdrwg.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emdrwgs', parameterName: 'emdrwg' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emdrwgedit-view-edit-mode/emdrwgedit-view-edit-mode.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.pfunit.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-pf/pfunitpickup-view/pfunitpickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitem.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempickup-view/emitempickup-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitem.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempickup-view/emitempickup-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitem.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempickup-view/emitempickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitem.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempickup-view/emitempickup-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitem.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempickup-view/emitempickup-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitem.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempickup-view/emitempickup-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitem.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempickup-view/emitempickup-view.vue'),
                },
                {
                    path: 'emassets/:emasset?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emasset.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassets', parameterName: 'emasset' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emassetedit-view9/emassetedit-view9.vue'),
                },
                {
                    path: 'emeqlocations/:emeqlocation?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emeqlocation.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlocations', parameterName: 'emeqlocation' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqlocationpickup-grid-view/emeqlocationpickup-grid-view.vue'),
                },
                {
                    path: 'emeqlocations/:emeqlocation?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emeqlocation.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlocations', parameterName: 'emeqlocation' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqlocationpickup-view/emeqlocationpickup-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfomos/:emrfomo?/emrfoacs/:emrfoac?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emrfoac.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfoacpickup-view/emrfoacpickup-view.vue'),
                },
                {
                    path: 'emrfomos/:emrfomo?/emrfoacs/:emrfoac?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emrfoac.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfoacpickup-view/emrfoacpickup-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfoacs/:emrfoac?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emrfoac.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfoacpickup-view/emrfoacpickup-view.vue'),
                },
                {
                    path: 'emrfoacs/:emrfoac?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emrfoac.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfoacpickup-view/emrfoacpickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emwplistcost.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistcostedit-view9-edit-mode/emwplistcostedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emwplistcost.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistcostedit-view9-edit-mode/emwplistcostedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emwplistcost.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistcostedit-view9-edit-mode/emwplistcostedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emwplistcost.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistcostedit-view9-edit-mode/emwplistcostedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emwplistcost.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistcostedit-view9-edit-mode/emwplistcostedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emwplistcost.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistcostedit-view9-edit-mode/emwplistcostedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emwplistcost.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistcostedit-view9-edit-mode/emwplistcostedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emwplistcosts/:emwplistcost?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emwplistcost.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistcostedit-view9-edit-mode/emwplistcostedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emeqlocations/:emeqlocation?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqlocation.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlocations', parameterName: 'emeqlocation' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqlocationedit-view9-edit-mode/emeqlocationedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqmaintances/:emeqmaintance?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqmaintance.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqmaintanceedit-view9-edit-mode/emeqmaintanceedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqmaintances/:emeqmaintance?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqmaintance.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqmaintanceedit-view9-edit-mode/emeqmaintanceedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqmaintances/:emeqmaintance?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqmaintance.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqmaintanceedit-view9-edit-mode/emeqmaintanceedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emeqmaintances/:emeqmaintance?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqmaintance.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqmaintanceedit-view9-edit-mode/emeqmaintanceedit-view9-edit-mode.vue'),
                },
                {
                    path: 'empos/:empo?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.empo.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empos', parameterName: 'empo' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empopickup-view/empopickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemrout.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemroutedit-view9/emitemroutedit-view9.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemrout.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemroutedit-view9/emitemroutedit-view9.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemrout.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemroutedit-view9/emitemroutedit-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemrout.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemroutedit-view9/emitemroutedit-view9.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemrout.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemroutedit-view9/emitemroutedit-view9.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemrout.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemroutedit-view9/emitemroutedit-view9.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitemrouts/:emitemrout?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemrout.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemroutedit-view9/emitemroutedit-view9.vue'),
                },
                {
                    path: 'emitemrouts/:emitemrout?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemrout.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemroutedit-view9/emitemroutedit-view9.vue'),
                },
                {
                    path: 'emeqlctfdjs/:emeqlctfdj?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqlctfdj.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlctfdjs', parameterName: 'emeqlctfdj' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqlctfdjgrid-view/emeqlctfdjgrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emwo_oscs/:emwo_osc?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_osc.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-oscedit-view/emwo-oscedit-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emwo_oscs/:emwo_osc?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_osc.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-oscedit-view/emwo-oscedit-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emwo_oscs/:emwo_osc?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_osc.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-oscedit-view/emwo-oscedit-view.vue'),
                },
                {
                    path: 'emwo_oscs/:emwo_osc?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_osc.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-oscedit-view/emwo-oscedit-view.vue'),
                },
                {
                    path: 'emeqlctgsses/:emeqlctgss?/editview/:editview?',
                    meta: {
                        caption: 'entities.emeqlctgss.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqlctgssedit-view/emeqlctgssedit-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplantempls/:emplantempl?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplantempl.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantemplgrid-view/emplantemplgrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplantempls/:emplantempl?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplantempl.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantemplgrid-view/emplantemplgrid-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplantempls/:emplantempl?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplantempl.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantemplgrid-view/emplantemplgrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplantempls/:emplantempl?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplantempl.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantemplgrid-view/emplantemplgrid-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplantempls/:emplantempl?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplantempl.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantemplgrid-view/emplantemplgrid-view.vue'),
                },
                {
                    path: 'emplantempls/:emplantempl?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplantempl.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantemplgrid-view/emplantemplgrid-view.vue'),
                },
                {
                    path: 'emrfodetypes/:emrfodetype?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emrfodetype.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodetypes', parameterName: 'emrfodetype' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfodetypegrid-view/emrfodetypegrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemtrades/:emitemtrade?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemtrade.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtradegrid-view/emitemtradegrid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitemtrades/:emitemtrade?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemtrade.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtradegrid-view/emitemtradegrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitemtrades/:emitemtrade?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemtrade.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtradegrid-view/emitemtradegrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitemtrades/:emitemtrade?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemtrade.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtradegrid-view/emitemtradegrid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitemtrades/:emitemtrade?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemtrade.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtradegrid-view/emitemtradegrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitemtrades/:emitemtrade?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemtrade.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtradegrid-view/emitemtradegrid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitemtrades/:emitemtrade?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemtrade.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtradegrid-view/emitemtradegrid-view.vue'),
                },
                {
                    path: 'emitemtrades/:emitemtrade?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemtrade.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtradegrid-view/emitemtradegrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwplist.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistpickup-view/emwplistpickup-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emwplists/:emwplist?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwplist.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistpickup-view/emwplistpickup-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emwplists/:emwplist?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwplist.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistpickup-view/emwplistpickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emwplists/:emwplist?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwplist.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistpickup-view/emwplistpickup-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwplist.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistpickup-view/emwplistpickup-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emwplists/:emwplist?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwplist.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistpickup-view/emwplistpickup-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emwplists/:emwplist?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwplist.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistpickup-view/emwplistpickup-view.vue'),
                },
                {
                    path: 'emwplists/:emwplist?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwplist.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistpickup-view/emwplistpickup-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqchecks/:emeqcheck?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqcheck.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqcheckgrid-view/emeqcheckgrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqchecks/:emeqcheck?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqcheck.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqcheckgrid-view/emeqcheckgrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqchecks/:emeqcheck?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqcheck.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqcheckgrid-view/emeqcheckgrid-view.vue'),
                },
                {
                    path: 'emeqchecks/:emeqcheck?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqcheck.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqcheckgrid-view/emeqcheckgrid-view.vue'),
                },
                {
                    path: 'emassetclasses/:emassetclass?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emassetclass.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassetclasses', parameterName: 'emassetclass' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-as/emassetclasspickup-grid-view/emassetclasspickup-grid-view.vue'),
                },
                {
                    path: 'emproducts/:emproduct?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emproduct.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emproducts', parameterName: 'emproduct' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emproductedit-view9/emproductedit-view9.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqmaintances/:emeqmaintance?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqmaintance.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqmaintancegrid-view/emeqmaintancegrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqmaintances/:emeqmaintance?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqmaintance.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqmaintancegrid-view/emeqmaintancegrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqmaintances/:emeqmaintance?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqmaintance.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqmaintancegrid-view/emeqmaintancegrid-view.vue'),
                },
                {
                    path: 'emeqmaintances/:emeqmaintance?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqmaintance.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqmaintancegrid-view/emeqmaintancegrid-view.vue'),
                },
                {
                    path: 'emrfodetypes/:emrfodetype?/editview/:editview?',
                    meta: {
                        caption: 'entities.emrfodetype.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodetypes', parameterName: 'emrfodetype' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfodetypeedit-view/emrfodetypeedit-view.vue'),
                },
                {
                    path: 'empurplans/:empurplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.empurplan.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empurplans', parameterName: 'empurplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empurplanpickup-grid-view/empurplanpickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemprtn.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemprtnedit-view9-edit-mode/emitemprtnedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemprtn.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemprtnedit-view9-edit-mode/emitemprtnedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemprtn.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemprtnedit-view9-edit-mode/emitemprtnedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemprtn.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemprtnedit-view9-edit-mode/emitemprtnedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemprtn.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemprtnedit-view9-edit-mode/emitemprtnedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemprtn.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemprtnedit-view9-edit-mode/emitemprtnedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitemprtns/:emitemprtn?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemprtn.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemprtnedit-view9-edit-mode/emitemprtnedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emitemprtns/:emitemprtn?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemprtn.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemprtnedit-view9-edit-mode/emitemprtnedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
                },
                {
                    path: 'empos/:empo?/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empos', parameterName: 'empo' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
                },
                {
                    path: 'empodetails/:empodetail?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostpickup-grid-view/emwplistcostpickup-grid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostpickup-grid-view/emwplistcostpickup-grid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostpickup-grid-view/emwplistcostpickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostpickup-grid-view/emwplistcostpickup-grid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostpickup-grid-view/emwplistcostpickup-grid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostpickup-grid-view/emwplistcostpickup-grid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostpickup-grid-view/emwplistcostpickup-grid-view.vue'),
                },
                {
                    path: 'emwplistcosts/:emwplistcost?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostpickup-grid-view/emwplistcostpickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemrin.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinedit-view9/emitemrinedit-view9.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitemrins/:emitemrin?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemrin.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinedit-view9/emitemrinedit-view9.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitemrins/:emitemrin?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemrin.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinedit-view9/emitemrinedit-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitemrins/:emitemrin?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemrin.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinedit-view9/emitemrinedit-view9.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemrin.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinedit-view9/emitemrinedit-view9.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitemrins/:emitemrin?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemrin.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinedit-view9/emitemrinedit-view9.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitemrins/:emitemrin?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemrin.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinedit-view9/emitemrinedit-view9.vue'),
                },
                {
                    path: 'emitemrins/:emitemrin?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitemrin.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinedit-view9/emitemrinedit-view9.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqdebugs/:emeqdebug?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqdebug.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqdebuggrid-view/emeqdebuggrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqdebugs/:emeqdebug?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqdebug.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqdebuggrid-view/emeqdebuggrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqdebugs/:emeqdebug?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqdebug.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqdebuggrid-view/emeqdebuggrid-view.vue'),
                },
                {
                    path: 'emeqdebugs/:emeqdebug?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqdebug.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqdebuggrid-view/emeqdebuggrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emwos/:emwo?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwo.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwos', parameterName: 'emwo' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwopickup-grid-view/emwopickup-grid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emwos/:emwo?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwo.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwos', parameterName: 'emwo' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwopickup-grid-view/emwopickup-grid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emwos/:emwo?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwo.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwos', parameterName: 'emwo' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwopickup-grid-view/emwopickup-grid-view.vue'),
                },
                {
                    path: 'emwos/:emwo?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwo.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwos', parameterName: 'emwo' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwopickup-grid-view/emwopickup-grid-view.vue'),
                },
                {
                    path: 'emassets/:emasset?/emassetclears/:emassetclear?/editview/:editview?',
                    meta: {
                        caption: 'entities.emassetclear.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassets', parameterName: 'emasset' },
                            { pathName: 'emassetclears', parameterName: 'emassetclear' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-as/emassetclearedit-view/emassetclearedit-view.vue'),
                },
                {
                    path: 'emassetclears/:emassetclear?/editview/:editview?',
                    meta: {
                        caption: 'entities.emassetclear.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassetclears', parameterName: 'emassetclear' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-as/emassetclearedit-view/emassetclearedit-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfomos/:emrfomo?/emrfoacs/:emrfoac?/editview/:editview?',
                    meta: {
                        caption: 'entities.emrfoac.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfoacedit-view/emrfoacedit-view.vue'),
                },
                {
                    path: 'emrfomos/:emrfomo?/emrfoacs/:emrfoac?/editview/:editview?',
                    meta: {
                        caption: 'entities.emrfoac.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfoacedit-view/emrfoacedit-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfoacs/:emrfoac?/editview/:editview?',
                    meta: {
                        caption: 'entities.emrfoac.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfoacedit-view/emrfoacedit-view.vue'),
                },
                {
                    path: 'emrfoacs/:emrfoac?/editview/:editview?',
                    meta: {
                        caption: 'entities.emrfoac.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfoacedit-view/emrfoacedit-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwplist.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistgrid-view/emwplistgrid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emwplists/:emwplist?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwplist.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistgrid-view/emwplistgrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emwplists/:emwplist?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwplist.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistgrid-view/emwplistgrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emwplists/:emwplist?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwplist.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistgrid-view/emwplistgrid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwplist.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistgrid-view/emwplistgrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emwplists/:emwplist?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwplist.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistgrid-view/emwplistgrid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emwplists/:emwplist?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwplist.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistgrid-view/emwplistgrid-view.vue'),
                },
                {
                    path: 'emwplists/:emwplist?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwplist.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistgrid-view/emwplistgrid-view.vue'),
                },
                {
                    path: 'emassets/:emasset?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emasset.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassets', parameterName: 'emasset' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emassetpickup-grid-view/emassetpickup-grid-view.vue'),
                },
                {
                    path: 'emassets/:emasset?/emassetclears/:emassetclear?/gridview_5564/:gridview_5564?',
                    meta: {
                        caption: 'entities.emassetclear.views.gridview_5564.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassets', parameterName: 'emasset' },
                            { pathName: 'emassetclears', parameterName: 'emassetclear' },
                            { pathName: 'gridview_5564', parameterName: 'gridview_5564' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-as/emassetcleargrid-view-5564/emassetcleargrid-view-5564.vue'),
                },
                {
                    path: 'emassetclears/:emassetclear?/gridview_5564/:gridview_5564?',
                    meta: {
                        caption: 'entities.emassetclear.views.gridview_5564.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassetclears', parameterName: 'emassetclear' },
                            { pathName: 'gridview_5564', parameterName: 'gridview_5564' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-as/emassetcleargrid-view-5564/emassetcleargrid-view-5564.vue'),
                },
                {
                    path: 'emstores/:emstore?/editview_9924/:editview_9924?',
                    meta: {
                        caption: 'entities.emstore.views.editview_9924.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'editview_9924', parameterName: 'editview_9924' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstoreedit-view-9924/emstoreedit-view-9924.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitem.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemgrid-view/emitemgrid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitem.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemgrid-view/emitemgrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitem.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemgrid-view/emitemgrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitem.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemgrid-view/emitemgrid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitem.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemgrid-view/emitemgrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitem.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemgrid-view/emitemgrid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitem.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemgrid-view/emitemgrid-view.vue'),
                },
                {
                    path: 'emitemcs/:emitemcs?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemcs.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemcs', parameterName: 'emitemcs' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemcsedit-view9-edit-mode/emitemcsedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
                },
                {
                    path: 'emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
                },
                {
                    path: 'emeqspares/:emeqspare?/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqspares', parameterName: 'emeqspare' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
                },
                {
                    path: 'emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
                },
                {
                    path: 'emitempls/:emitempl?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitempl.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitempls', parameterName: 'emitempl' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemplgrid-view/emitemplgrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.empodetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/empodetails/:empodetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.empodetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/empodetails/:empodetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.empodetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/empodetails/:empodetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.empodetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.empodetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/empodetails/:empodetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.empodetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
                },
                {
                    path: 'empos/:empo?/empodetails/:empodetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.empodetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empos', parameterName: 'empo' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/empodetails/:empodetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.empodetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
                },
                {
                    path: 'empodetails/:empodetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.empodetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqsetups/:emeqsetup?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqsetup.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqsetupedit-view9-edit-mode/emeqsetupedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqsetups/:emeqsetup?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqsetup.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqsetupedit-view9-edit-mode/emeqsetupedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqsetups/:emeqsetup?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqsetup.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqsetupedit-view9-edit-mode/emeqsetupedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emeqsetups/:emeqsetup?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqsetup.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqsetupedit-view9-edit-mode/emeqsetupedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emequip.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emequippickup-grid-view/emequippickup-grid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emequip.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emequippickup-grid-view/emequippickup-grid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emequip.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emequippickup-grid-view/emequippickup-grid-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfomos/:emrfomo?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emrfomo.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfomogrid-view/emrfomogrid-view.vue'),
                },
                {
                    path: 'emrfomos/:emrfomo?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emrfomo.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfomogrid-view/emrfomogrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplandetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplandetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplandetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplandetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplandetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplandetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplandetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplandetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplandetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplandetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplandetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
                },
                {
                    path: 'emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplandetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplandetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplandetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
                },
                {
                    path: 'emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplandetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
                },
                {
                    path: 'emplandetails/:emplandetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplandetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
                },
                {
                    path: 'emitemtypes/:emitemtype?/editview_itemtype/:editview_itemtype?',
                    meta: {
                        caption: 'entities.emitemtype.views.editview_itemtype.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemtypes', parameterName: 'emitemtype' },
                            { pathName: 'editview_itemtype', parameterName: 'editview_itemtype' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemtypeedit-view-itemtype/emitemtypeedit-view-itemtype.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'empurplans/:empurplan?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empurplans', parameterName: 'empurplan' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'emitempuses/:emitempuse?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emstocks/:emstock?/editview/:editview?',
                    meta: {
                        caption: 'entities.emstock.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emstocks/:emstock?/editview/:editview?',
                    meta: {
                        caption: 'entities.emstock.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emstocks/:emstock?/editview/:editview?',
                    meta: {
                        caption: 'entities.emstock.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emstocks/:emstock?/editview/:editview?',
                    meta: {
                        caption: 'entities.emstock.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emstocks/:emstock?/editview/:editview?',
                    meta: {
                        caption: 'entities.emstock.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emstocks/:emstock?/editview/:editview?',
                    meta: {
                        caption: 'entities.emstock.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emstocks/:emstock?/editview/:editview?',
                    meta: {
                        caption: 'entities.emstock.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstocks/:emstock?/editview/:editview?',
                    meta: {
                        caption: 'entities.emstock.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emstocks/:emstock?/editview/:editview?',
                    meta: {
                        caption: 'entities.emstock.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emstocks/:emstock?/editview/:editview?',
                    meta: {
                        caption: 'entities.emstock.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
                },
                {
                    path: 'emstocks/:emstock?/editview/:editview?',
                    meta: {
                        caption: 'entities.emstock.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emrfode.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfodeedit-view9/emrfodeedit-view9.vue'),
                },
                {
                    path: 'emproducts/:emproduct?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emproduct.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emproducts', parameterName: 'emproduct' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emproductgrid-view/emproductgrid-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfomos/:emrfomo?/emrfocas/:emrfoca?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emrfoca.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'emrfocas', parameterName: 'emrfoca' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfocapickup-grid-view/emrfocapickup-grid-view.vue'),
                },
                {
                    path: 'emrfomos/:emrfomo?/emrfocas/:emrfoca?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emrfoca.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'emrfocas', parameterName: 'emrfoca' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfocapickup-grid-view/emrfocapickup-grid-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfocas/:emrfoca?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emrfoca.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfocas', parameterName: 'emrfoca' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfocapickup-grid-view/emrfocapickup-grid-view.vue'),
                },
                {
                    path: 'emrfocas/:emrfoca?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emrfoca.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfocas', parameterName: 'emrfoca' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfocapickup-grid-view/emrfocapickup-grid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emeqtype.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqtypeedit-view-edit-mode/emeqtypeedit-view-edit-mode.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfomos/:emrfomo?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emrfomo.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfomopickup-grid-view/emrfomopickup-grid-view.vue'),
                },
                {
                    path: 'emrfomos/:emrfomo?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emrfomo.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfomopickup-grid-view/emrfomopickup-grid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqsetups/:emeqsetup?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqsetup.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqsetupedit-view9/emeqsetupedit-view9.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqsetups/:emeqsetup?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqsetup.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqsetupedit-view9/emeqsetupedit-view9.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqsetups/:emeqsetup?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqsetup.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqsetupedit-view9/emeqsetupedit-view9.vue'),
                },
                {
                    path: 'emeqsetups/:emeqsetup?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqsetup.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqsetupedit-view9/emeqsetupedit-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emstore.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstorepickup-grid-view/emstorepickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emequips/:emequip?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emen/:emen?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqchecks/:emeqcheck?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqcheck.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqcheckedit-view9/emeqcheckedit-view9.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqchecks/:emeqcheck?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqcheck.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqcheckedit-view9/emeqcheckedit-view9.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqchecks/:emeqcheck?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqcheck.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqcheckedit-view9/emeqcheckedit-view9.vue'),
                },
                {
                    path: 'emeqchecks/:emeqcheck?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqcheck.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqcheckedit-view9/emeqcheckedit-view9.vue'),
                },
                {
                    path: 'emitemtypes/:emitemtype?/itemtreeexpview/:itemtreeexpview?',
                    meta: {
                        caption: 'entities.emitemtype.views.itemtreeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemtypes', parameterName: 'emitemtype' },
                            { pathName: 'itemtreeexpview', parameterName: 'itemtreeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtypeitem-tree-exp-view/emitemtypeitem-tree-exp-view.vue'),
                },
                {
                    path: 'emproducts/:emproduct?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emproduct.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emproducts', parameterName: 'emproduct' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emproductedit-view9-edit-mode/emproductedit-view9-edit-mode.vue'),
                },
                {
                    path: 'empos/:empo?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.empo.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empos', parameterName: 'empo' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empoedit-view9/empoedit-view9.vue'),
                },
                {
                    path: 'pfcontracts/:pfcontract?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.pfcontract.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfcontracts', parameterName: 'pfcontract' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-pf/pfcontractpickup-grid-view/pfcontractpickup-grid-view.vue'),
                },
                {
                    path: 'emitemtypes/:emitemtype?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitemtype.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemtypes', parameterName: 'emitemtype' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemtypepickup-grid-view/emitemtypepickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/gridview_7848/:gridview_7848?',
                    meta: {
                        caption: 'entities.emstore.views.gridview_7848.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'gridview_7848', parameterName: 'gridview_7848' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstoregrid-view-7848/emstoregrid-view-7848.vue'),
                },
                {
                    path: 'emassets/:emasset?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emasset.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassets', parameterName: 'emasset' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emassettab-exp-view/emassettab-exp-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emrfode.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfodepickup-view/emrfodepickup-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emwo_oscs/:emwo_osc?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_osc.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-oscgrid-view/emwo-oscgrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emwo_oscs/:emwo_osc?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_osc.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-oscgrid-view/emwo-oscgrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emwo_oscs/:emwo_osc?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_osc.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-oscgrid-view/emwo-oscgrid-view.vue'),
                },
                {
                    path: 'emwo_oscs/:emwo_osc?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_osc.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-oscgrid-view/emwo-oscgrid-view.vue'),
                },
                {
                    path: 'emeqlocations/:emeqlocation?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emeqlocation.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlocations', parameterName: 'emeqlocation' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqlocationtab-exp-view/emeqlocationtab-exp-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemrout.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemroutedit-view9-edit-mode/emitemroutedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemrout.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemroutedit-view9-edit-mode/emitemroutedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemrout.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemroutedit-view9-edit-mode/emitemroutedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemrout.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemroutedit-view9-edit-mode/emitemroutedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemrout.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemroutedit-view9-edit-mode/emitemroutedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemrout.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemroutedit-view9-edit-mode/emitemroutedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitemrouts/:emitemrout?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemrout.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemroutedit-view9-edit-mode/emitemroutedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emitemrouts/:emitemrout?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemrout.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemroutedit-view9-edit-mode/emitemroutedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emoutputs/:emoutput?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emoutput.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emoutputs', parameterName: 'emoutput' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emoutputgrid-view/emoutputgrid-view.vue'),
                },
                {
                    path: 'emoutputs/:emoutput?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emoutput.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emoutputs', parameterName: 'emoutput' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emoutputpickup-grid-view/emoutputpickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emenconsums/:emenconsum?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emenconsums/:emenconsum?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
                },
                {
                    path: 'emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emenconsums/:emenconsum?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
                },
                {
                    path: 'emequips/:emequip?/emenconsums/:emenconsum?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
                },
                {
                    path: 'emen/:emen?/emenconsums/:emenconsum?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
                },
                {
                    path: 'emenconsums/:emenconsum?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emenconsum.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.pfunit.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-pf/pfunitpickup-grid-view/pfunitpickup-grid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emplan.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emplan.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emplan.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emplan.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emplan.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emplan.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emplan.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplans/:emplan?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emplan.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplans/:emplan?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emplan.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplans/:emplan?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emplan.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplans/:emplan?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emplan.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
                },
                {
                    path: 'emplantempls/:emplantempl?/emplans/:emplan?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emplan.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emplans/:emplan?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emplan.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplans/:emplan?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emplan.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
                },
                {
                    path: 'emplans/:emplan?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emplan.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostpickup-view/emwplistcostpickup-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostpickup-view/emwplistcostpickup-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostpickup-view/emwplistcostpickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostpickup-view/emwplistcostpickup-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostpickup-view/emwplistcostpickup-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostpickup-view/emwplistcostpickup-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostpickup-view/emwplistcostpickup-view.vue'),
                },
                {
                    path: 'emwplistcosts/:emwplistcost?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostpickup-view/emwplistcostpickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emwplist.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistedit-view9/emwplistedit-view9.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emwplists/:emwplist?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emwplist.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistedit-view9/emwplistedit-view9.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emwplists/:emwplist?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emwplist.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistedit-view9/emwplistedit-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emwplists/:emwplist?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emwplist.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistedit-view9/emwplistedit-view9.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emwplist.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistedit-view9/emwplistedit-view9.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emwplists/:emwplist?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emwplist.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistedit-view9/emwplistedit-view9.vue'),
                },
                {
                    path: 'emitems/:emitem?/emwplists/:emwplist?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emwplist.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistedit-view9/emwplistedit-view9.vue'),
                },
                {
                    path: 'emwplists/:emwplist?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emwplist.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistedit-view9/emwplistedit-view9.vue'),
                },
                {
                    path: 'emeqspares/:emeqspare?/emeqsparemaps/:emeqsparemap?/gridview9/:gridview9?',
                    meta: {
                        caption: 'entities.emeqsparemap.views.gridview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqspares', parameterName: 'emeqspare' },
                            { pathName: 'emeqsparemaps', parameterName: 'emeqsparemap' },
                            { pathName: 'gridview9', parameterName: 'gridview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqsparemapgrid-view9/emeqsparemapgrid-view9.vue'),
                },
                {
                    path: 'emeqsparemaps/:emeqsparemap?/gridview9/:gridview9?',
                    meta: {
                        caption: 'entities.emeqsparemap.views.gridview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqsparemaps', parameterName: 'emeqsparemap' },
                            { pathName: 'gridview9', parameterName: 'gridview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqsparemapgrid-view9/emeqsparemapgrid-view9.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emeqtype.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqtypetree-exp-view/emeqtypetree-exp-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emen.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenpickup-grid-view/emenpickup-grid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emen/:emen?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emen.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenpickup-grid-view/emenpickup-grid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emen/:emen?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emen.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenpickup-grid-view/emenpickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emen/:emen?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emen.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenpickup-grid-view/emenpickup-grid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emen.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenpickup-grid-view/emenpickup-grid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emen/:emen?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emen.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenpickup-grid-view/emenpickup-grid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emen/:emen?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emen.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenpickup-grid-view/emenpickup-grid-view.vue'),
                },
                {
                    path: 'emen/:emen?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emen.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenpickup-grid-view/emenpickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemrin.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemringrid-view/emitemringrid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitemrins/:emitemrin?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemrin.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemringrid-view/emitemringrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitemrins/:emitemrin?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemrin.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemringrid-view/emitemringrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitemrins/:emitemrin?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemrin.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemringrid-view/emitemringrid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemrin.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemringrid-view/emitemringrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitemrins/:emitemrin?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemrin.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemringrid-view/emitemringrid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitemrins/:emitemrin?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemrin.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemringrid-view/emitemringrid-view.vue'),
                },
                {
                    path: 'emitemrins/:emitemrin?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemrin.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemringrid-view/emitemringrid-view.vue'),
                },
                {
                    path: 'emobjects/:emobject?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emobject.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emobjects', parameterName: 'emobject' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emobjectpickup-view/emobjectpickup-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emwo_dps/:emwo_dp?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_dp.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpedit-view/emwo-dpedit-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emwo_dps/:emwo_dp?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_dp.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpedit-view/emwo-dpedit-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emwo_dps/:emwo_dp?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_dp.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpedit-view/emwo-dpedit-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emwo_dps/:emwo_dp?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_dp.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpedit-view/emwo-dpedit-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emwo_dps/:emwo_dp?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_dp.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpedit-view/emwo-dpedit-view.vue'),
                },
                {
                    path: 'emwo_dps/:emwo_dp?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_dp.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpedit-view/emwo-dpedit-view.vue'),
                },
                {
                    path: 'emassetclasses/:emassetclass?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emassetclass.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassetclasses', parameterName: 'emassetclass' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-as/emassetclasspickup-view/emassetclasspickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'empurplans/:empurplan?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empurplans', parameterName: 'empurplan' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitempuse.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplandetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplandetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplandetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplandetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplandetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplandetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplandetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplandetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplandetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplandetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplandetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
                },
                {
                    path: 'emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplandetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplandetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplandetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
                },
                {
                    path: 'emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplandetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
                },
                {
                    path: 'emplandetails/:emplandetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplandetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplandetails', parameterName: 'emplandetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
                },
                {
                    path: 'emeqlctgsses/:emeqlctgss?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emeqlctgss.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqlctgsspickup-grid-view/emeqlctgsspickup-grid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplan.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplan.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplan.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplan.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplan.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplan.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplan.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplans/:emplan?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplan.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplans/:emplan?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplan.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplans/:emplan?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplan.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplans/:emplan?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplan.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
                },
                {
                    path: 'emplantempls/:emplantempl?/emplans/:emplan?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplan.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emplans/:emplan?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplan.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplans/:emplan?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplan.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
                },
                {
                    path: 'emplans/:emplan?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplan.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/gridview_ydh/:gridview_ydh?',
                    meta: {
                        caption: 'entities.emwplist.views.gridview_ydh.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'gridview_ydh', parameterName: 'gridview_ydh' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistgrid-view-ydh/emwplistgrid-view-ydh.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emwplists/:emwplist?/gridview_ydh/:gridview_ydh?',
                    meta: {
                        caption: 'entities.emwplist.views.gridview_ydh.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'gridview_ydh', parameterName: 'gridview_ydh' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistgrid-view-ydh/emwplistgrid-view-ydh.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emwplists/:emwplist?/gridview_ydh/:gridview_ydh?',
                    meta: {
                        caption: 'entities.emwplist.views.gridview_ydh.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'gridview_ydh', parameterName: 'gridview_ydh' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistgrid-view-ydh/emwplistgrid-view-ydh.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emwplists/:emwplist?/gridview_ydh/:gridview_ydh?',
                    meta: {
                        caption: 'entities.emwplist.views.gridview_ydh.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'gridview_ydh', parameterName: 'gridview_ydh' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistgrid-view-ydh/emwplistgrid-view-ydh.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/gridview_ydh/:gridview_ydh?',
                    meta: {
                        caption: 'entities.emwplist.views.gridview_ydh.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'gridview_ydh', parameterName: 'gridview_ydh' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistgrid-view-ydh/emwplistgrid-view-ydh.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emwplists/:emwplist?/gridview_ydh/:gridview_ydh?',
                    meta: {
                        caption: 'entities.emwplist.views.gridview_ydh.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'gridview_ydh', parameterName: 'gridview_ydh' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistgrid-view-ydh/emwplistgrid-view-ydh.vue'),
                },
                {
                    path: 'emitems/:emitem?/emwplists/:emwplist?/gridview_ydh/:gridview_ydh?',
                    meta: {
                        caption: 'entities.emwplist.views.gridview_ydh.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'gridview_ydh', parameterName: 'gridview_ydh' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistgrid-view-ydh/emwplistgrid-view-ydh.vue'),
                },
                {
                    path: 'emwplists/:emwplist?/gridview_ydh/:gridview_ydh?',
                    meta: {
                        caption: 'entities.emwplist.views.gridview_ydh.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'gridview_ydh', parameterName: 'gridview_ydh' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistgrid-view-ydh/emwplistgrid-view-ydh.vue'),
                },
                {
                    path: 'emeqlctrhies/:emeqlctrhy?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqlctrhy.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlctrhies', parameterName: 'emeqlctrhy' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqlctrhygrid-view/emeqlctrhygrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplantempls/:emplantempl?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplantempl.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantempledit-view/emplantempledit-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplantempls/:emplantempl?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplantempl.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantempledit-view/emplantempledit-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplantempls/:emplantempl?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplantempl.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantempledit-view/emplantempledit-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplantempls/:emplantempl?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplantempl.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantempledit-view/emplantempledit-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplantempls/:emplantempl?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplantempl.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantempledit-view/emplantempledit-view.vue'),
                },
                {
                    path: 'emplantempls/:emplantempl?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplantempl.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantempledit-view/emplantempledit-view.vue'),
                },
                {
                    path: 'emassetclasses/:emassetclass?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emassetclass.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassetclasses', parameterName: 'emassetclass' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-as/emassetclassgrid-view/emassetclassgrid-view.vue'),
                },
                {
                    path: 'emitempls/:emitempl?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emitempl.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitempls', parameterName: 'emitempl' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempledit-view9/emitempledit-view9.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emdrwgs/:emdrwg?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emdrwg.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emdrwgs', parameterName: 'emdrwg' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emdrwggrid-view/emdrwggrid-view.vue'),
                },
                {
                    path: 'emdrwgs/:emdrwg?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emdrwg.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emdrwgs', parameterName: 'emdrwg' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emdrwggrid-view/emdrwggrid-view.vue'),
                },
                {
                    path: 'emeqspares/:emeqspare?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emeqspare.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqspares', parameterName: 'emeqspare' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparepickup-grid-view/emeqsparepickup-grid-view.vue'),
                },
                {
                    path: 'emeqlctgsses/:emeqlctgss?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emeqlctgss.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqlctgsstab-exp-view/emeqlctgsstab-exp-view.vue'),
                },
                {
                    path: 'empos/:empo?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.empo.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empos', parameterName: 'empo' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empoedit-view9-edit-mode/empoedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emeqlctfdjs/:emeqlctfdj?/editview/:editview?',
                    meta: {
                        caption: 'entities.emeqlctfdj.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlctfdjs', parameterName: 'emeqlctfdj' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqlctfdjedit-view/emeqlctfdjedit-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emequip.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emequipgrid-view/emequipgrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emequip.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emequipgrid-view/emequipgrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emequip.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emequipgrid-view/emequipgrid-view.vue'),
                },
                {
                    path: 'emeitires/:emeitires?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emeitires.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeitires', parameterName: 'emeitires' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeitirespickup-grid-view/emeitirespickup-grid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emapplies/:emapply?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emapply.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emapplies', parameterName: 'emapply' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emapplygrid-view/emapplygrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emapplies/:emapply?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emapply.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emapplies', parameterName: 'emapply' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emapplygrid-view/emapplygrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emapplies/:emapply?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emapply.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emapplies', parameterName: 'emapply' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emapplygrid-view/emapplygrid-view.vue'),
                },
                {
                    path: 'emapplies/:emapply?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emapply.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emapplies', parameterName: 'emapply' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emapplygrid-view/emapplygrid-view.vue'),
                },
                {
                    path: 'emeqlctgsses/:emeqlctgss?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emeqlctgss.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqlctgsspickup-view/emeqlctgsspickup-view.vue'),
                },
                {
                    path: 'emassets/:emasset?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emasset.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassets', parameterName: 'emasset' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-as/emassetedit-view9-edit-mode/emassetedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emeqspares/:emeqspare?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emeqspare.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqspares', parameterName: 'emeqspare' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqspareedit-view-edit-mode/emeqspareedit-view-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitemrin.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinpickup-grid-view/emitemrinpickup-grid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitemrins/:emitemrin?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitemrin.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinpickup-grid-view/emitemrinpickup-grid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitemrins/:emitemrin?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitemrin.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinpickup-grid-view/emitemrinpickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitemrins/:emitemrin?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitemrin.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinpickup-grid-view/emitemrinpickup-grid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitemrin.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinpickup-grid-view/emitemrinpickup-grid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitemrins/:emitemrin?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitemrin.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinpickup-grid-view/emitemrinpickup-grid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitemrins/:emitemrin?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitemrin.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinpickup-grid-view/emitemrinpickup-grid-view.vue'),
                },
                {
                    path: 'emitemrins/:emitemrin?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emitemrin.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemrinpickup-grid-view/emitemrinpickup-grid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqkeeps/:emeqkeep?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqkeep.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqkeepgrid-view/emeqkeepgrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqkeeps/:emeqkeep?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqkeep.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqkeepgrid-view/emeqkeepgrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqkeeps/:emeqkeep?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqkeep.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqkeepgrid-view/emeqkeepgrid-view.vue'),
                },
                {
                    path: 'emeqkeeps/:emeqkeep?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqkeep.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqkeepgrid-view/emeqkeepgrid-view.vue'),
                },
                {
                    path: 'empos/:empo?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.empo.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empos', parameterName: 'empo' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/empogrid-view/empogrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplancdt.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplancdt.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplancdt.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplancdt.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplancdt.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplancdt.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplancdt.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplancdt.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplancdt.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplancdt.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplancdt.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
                },
                {
                    path: 'emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplancdt.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplancdt.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplancdt.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
                },
                {
                    path: 'emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplancdt.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
                },
                {
                    path: 'emplancdts/:emplancdt?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplancdt.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.pfteam.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-pf/pfteampickup-grid-view/pfteampickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emen.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenedit-view9-edit-mode/emenedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emen/:emen?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emen.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenedit-view9-edit-mode/emenedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emen/:emen?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emen.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenedit-view9-edit-mode/emenedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emen/:emen?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emen.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenedit-view9-edit-mode/emenedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emen.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenedit-view9-edit-mode/emenedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emen/:emen?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emen.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenedit-view9-edit-mode/emenedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emitems/:emitem?/emen/:emen?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emen.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenedit-view9-edit-mode/emenedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emen/:emen?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emen.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenedit-view9-edit-mode/emenedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emequip.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emequippickup-view/emequippickup-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emequip.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emequippickup-view/emequippickup-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emequip.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emequippickup-view/emequippickup-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/dashboardview9/:dashboardview9?',
                    meta: {
                        caption: 'entities.emequip.views.dashboardview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'dashboardview9', parameterName: 'dashboardview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emequipdashboard-view9/emequipdashboard-view9.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/dashboardview9/:dashboardview9?',
                    meta: {
                        caption: 'entities.emequip.views.dashboardview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'dashboardview9', parameterName: 'dashboardview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emequipdashboard-view9/emequipdashboard-view9.vue'),
                },
                {
                    path: 'emequips/:emequip?/dashboardview9/:dashboardview9?',
                    meta: {
                        caption: 'entities.emequip.views.dashboardview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'dashboardview9', parameterName: 'dashboardview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emequipdashboard-view9/emequipdashboard-view9.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplantempls/:emplantempl?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emplantempl.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantempledit-view-edit-mode/emplantempledit-view-edit-mode.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplantempls/:emplantempl?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emplantempl.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantempledit-view-edit-mode/emplantempledit-view-edit-mode.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplantempls/:emplantempl?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emplantempl.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantempledit-view-edit-mode/emplantempledit-view-edit-mode.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplantempls/:emplantempl?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emplantempl.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantempledit-view-edit-mode/emplantempledit-view-edit-mode.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplantempls/:emplantempl?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emplantempl.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantempledit-view-edit-mode/emplantempledit-view-edit-mode.vue'),
                },
                {
                    path: 'emplantempls/:emplantempl?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emplantempl.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplantempledit-view-edit-mode/emplantempledit-view-edit-mode.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.pfdept.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-pf/pfdeptpickup-view/pfdeptpickup-view.vue'),
                },
                {
                    path: 'emassets/:emasset?/emassetclears/:emassetclear?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emassetclear.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassets', parameterName: 'emasset' },
                            { pathName: 'emassetclears', parameterName: 'emassetclear' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-as/emassetcleargrid-view/emassetcleargrid-view.vue'),
                },
                {
                    path: 'emassetclears/:emassetclear?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emassetclear.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassetclears', parameterName: 'emassetclear' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-as/emassetcleargrid-view/emassetcleargrid-view.vue'),
                },
                {
                    path: 'emassetclasses/:emassetclass?/editview/:editview?',
                    meta: {
                        caption: 'entities.emassetclass.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassetclasses', parameterName: 'emassetclass' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-as/emassetclassedit-view/emassetclassedit-view.vue'),
                },
                {
                    path: 'emeqlctgsses/:emeqlctgss?/gridview_cqyj/:gridview_cqyj?',
                    meta: {
                        caption: 'entities.emeqlctgss.views.gridview_cqyj.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                            { pathName: 'gridview_cqyj', parameterName: 'gridview_cqyj' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-yj/emeqlctgssgrid-view-cqyj/emeqlctgssgrid-view-cqyj.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emequip.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emequiptab-exp-view/emequiptab-exp-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emequip.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emequiptab-exp-view/emequiptab-exp-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emequip.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emequiptab-exp-view/emequiptab-exp-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emwo_dps/:emwo_dp?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_dp.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpedit-view-edit-mode/emwo-dpedit-view-edit-mode.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emwo_dps/:emwo_dp?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_dp.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpedit-view-edit-mode/emwo-dpedit-view-edit-mode.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emwo_dps/:emwo_dp?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_dp.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpedit-view-edit-mode/emwo-dpedit-view-edit-mode.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emwo_dps/:emwo_dp?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_dp.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpedit-view-edit-mode/emwo-dpedit-view-edit-mode.vue'),
                },
                {
                    path: 'emequips/:emequip?/emwo_dps/:emwo_dp?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_dp.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpedit-view-edit-mode/emwo-dpedit-view-edit-mode.vue'),
                },
                {
                    path: 'emwo_dps/:emwo_dp?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_dp.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-dpedit-view-edit-mode/emwo-dpedit-view-edit-mode.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/editview/:editview?',
                    meta: {
                        caption: 'entities.emeqtype.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqtypeedit-view/emeqtypeedit-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfomos/:emrfomo?/emrfocas/:emrfoca?/editview/:editview?',
                    meta: {
                        caption: 'entities.emrfoca.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'emrfocas', parameterName: 'emrfoca' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfocaedit-view/emrfocaedit-view.vue'),
                },
                {
                    path: 'emrfomos/:emrfomo?/emrfocas/:emrfoca?/editview/:editview?',
                    meta: {
                        caption: 'entities.emrfoca.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'emrfocas', parameterName: 'emrfoca' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfocaedit-view/emrfocaedit-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfocas/:emrfoca?/editview/:editview?',
                    meta: {
                        caption: 'entities.emrfoca.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfocas', parameterName: 'emrfoca' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfocaedit-view/emrfocaedit-view.vue'),
                },
                {
                    path: 'emrfocas/:emrfoca?/editview/:editview?',
                    meta: {
                        caption: 'entities.emrfoca.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfocas', parameterName: 'emrfoca' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfocaedit-view/emrfocaedit-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emwos/:emwo?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwo.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwos', parameterName: 'emwo' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwopickup-view/emwopickup-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emwos/:emwo?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwo.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwos', parameterName: 'emwo' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwopickup-view/emwopickup-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emwos/:emwo?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwo.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwos', parameterName: 'emwo' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwopickup-view/emwopickup-view.vue'),
                },
                {
                    path: 'emwos/:emwo?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emwo.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwos', parameterName: 'emwo' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwopickup-view/emwopickup-view.vue'),
                },
                {
                    path: 'pfcontracts/:pfcontract?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.pfcontract.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfcontracts', parameterName: 'pfcontract' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/pfcontractgrid-view/pfcontractgrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemrin.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemrinedit-view9-edit-mode/emitemrinedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitemrins/:emitemrin?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemrin.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemrinedit-view9-edit-mode/emitemrinedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitemrins/:emitemrin?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemrin.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemrinedit-view9-edit-mode/emitemrinedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitemrins/:emitemrin?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemrin.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemrinedit-view9-edit-mode/emitemrinedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemrin.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemrinedit-view9-edit-mode/emitemrinedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitemrins/:emitemrin?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemrin.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemrinedit-view9-edit-mode/emitemrinedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitemrins/:emitemrin?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemrin.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemrinedit-view9-edit-mode/emitemrinedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emitemrins/:emitemrin?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitemrin.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemrins', parameterName: 'emitemrin' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemrinedit-view9-edit-mode/emitemrinedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emwos/:emwo?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwos', parameterName: 'emwo' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwogrid-view/emwogrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emwos/:emwo?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwos', parameterName: 'emwo' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwogrid-view/emwogrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emwos/:emwo?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwos', parameterName: 'emwo' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwogrid-view/emwogrid-view.vue'),
                },
                {
                    path: 'emwos/:emwo?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwos', parameterName: 'emwo' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwogrid-view/emwogrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emequip.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emequipoption-view/emequipoption-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emequip.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emequipoption-view/emequipoption-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emequip.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emequipoption-view/emequipoption-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emitem.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtab-exp-view/emitemtab-exp-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emitem.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtab-exp-view/emitemtab-exp-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emitem.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtab-exp-view/emitemtab-exp-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emitem.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtab-exp-view/emitemtab-exp-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emitem.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtab-exp-view/emitemtab-exp-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emitem.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtab-exp-view/emitemtab-exp-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.emitem.views.tabexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtab-exp-view/emitemtab-exp-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfomos/:emrfomo?/emrfoacs/:emrfoac?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emrfoac.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfoacgrid-view/emrfoacgrid-view.vue'),
                },
                {
                    path: 'emrfomos/:emrfomo?/emrfoacs/:emrfoac?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emrfoac.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfoacgrid-view/emrfoacgrid-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfoacs/:emrfoac?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emrfoac.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfoacgrid-view/emrfoacgrid-view.vue'),
                },
                {
                    path: 'emrfoacs/:emrfoac?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emrfoac.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfoacgrid-view/emrfoacgrid-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfomos/:emrfomo?/emrfocas/:emrfoca?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emrfoca.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'emrfocas', parameterName: 'emrfoca' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfocagrid-view/emrfocagrid-view.vue'),
                },
                {
                    path: 'emrfomos/:emrfomo?/emrfocas/:emrfoca?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emrfoca.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'emrfocas', parameterName: 'emrfoca' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfocagrid-view/emrfocagrid-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfocas/:emrfoca?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emrfoca.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfocas', parameterName: 'emrfoca' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfocagrid-view/emrfocagrid-view.vue'),
                },
                {
                    path: 'emrfocas/:emrfoca?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emrfoca.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfocas', parameterName: 'emrfoca' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfocagrid-view/emrfocagrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emeqtype.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqtypepickup-view/emeqtypepickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/empodetails/:empodetail?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/empodetails/:empodetail?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/empodetails/:empodetail?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/empodetails/:empodetail?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
                },
                {
                    path: 'empos/:empo?/empodetails/:empodetail?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empos', parameterName: 'empo' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/empodetails/:empodetail?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
                },
                {
                    path: 'empodetails/:empodetail?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.empodetail.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrouts/:emitemrout?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemrout.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemroutgrid-view/emitemroutgrid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitemrouts/:emitemrout?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemrout.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemroutgrid-view/emitemroutgrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitemrouts/:emitemrout?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemrout.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemroutgrid-view/emitemroutgrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitemrouts/:emitemrout?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemrout.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemroutgrid-view/emitemroutgrid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitemrouts/:emitemrout?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemrout.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemroutgrid-view/emitemroutgrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitemrouts/:emitemrout?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemrout.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemroutgrid-view/emitemroutgrid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitemrouts/:emitemrout?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemrout.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemroutgrid-view/emitemroutgrid-view.vue'),
                },
                {
                    path: 'emitemrouts/:emitemrout?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemrout.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemroutgrid-view/emitemroutgrid-view.vue'),
                },
                {
                    path: 'emeqlctgsses/:emeqlctgss?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqlctgss.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqlctgssedit-view9/emeqlctgssedit-view9.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqkeeps/:emeqkeep?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqkeep.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqkeepedit-view9/emeqkeepedit-view9.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqkeeps/:emeqkeep?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqkeep.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqkeepedit-view9/emeqkeepedit-view9.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqkeeps/:emeqkeep?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqkeep.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqkeepedit-view9/emeqkeepedit-view9.vue'),
                },
                {
                    path: 'emeqkeeps/:emeqkeep?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emeqkeep.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqkeepedit-view9/emeqkeepedit-view9.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emwo_ens/:emwo_en?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_en.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-enedit-view/emwo-enedit-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emwo_ens/:emwo_en?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_en.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-enedit-view/emwo-enedit-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emwo_ens/:emwo_en?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_en.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-enedit-view/emwo-enedit-view.vue'),
                },
                {
                    path: 'emwo_ens/:emwo_en?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_en.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-enedit-view/emwo-enedit-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwplist.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistpickup-grid-view/emwplistpickup-grid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emwplists/:emwplist?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwplist.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistpickup-grid-view/emwplistpickup-grid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emwplists/:emwplist?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwplist.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistpickup-grid-view/emwplistpickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emwplists/:emwplist?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwplist.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistpickup-grid-view/emwplistpickup-grid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwplist.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistpickup-grid-view/emwplistpickup-grid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emwplists/:emwplist?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwplist.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistpickup-grid-view/emwplistpickup-grid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emwplists/:emwplist?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwplist.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistpickup-grid-view/emwplistpickup-grid-view.vue'),
                },
                {
                    path: 'emwplists/:emwplist?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwplist.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistpickup-grid-view/emwplistpickup-grid-view.vue'),
                },
                {
                    path: 'emeqlcttires/:emeqlcttires?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emeqlcttires.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlcttires', parameterName: 'emeqlcttires' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqlcttirespickup-grid-view/emeqlcttirespickup-grid-view.vue'),
                },
                {
                    path: 'emeqspares/:emeqspare?/emeqsparemaps/:emeqsparemap?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emeqsparemap.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqspares', parameterName: 'emeqspare' },
                            { pathName: 'emeqsparemaps', parameterName: 'emeqsparemap' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparemapedit-view-edit-mode/emeqsparemapedit-view-edit-mode.vue'),
                },
                {
                    path: 'emeqsparemaps/:emeqsparemap?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emeqsparemap.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqsparemaps', parameterName: 'emeqsparemap' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparemapedit-view-edit-mode/emeqsparemapedit-view-edit-mode.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqahs/:emeqah?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emeqah.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqahs', parameterName: 'emeqah' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqahtree-exp-view/emeqahtree-exp-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqahs/:emeqah?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emeqah.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqahs', parameterName: 'emeqah' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqahtree-exp-view/emeqahtree-exp-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqahs/:emeqah?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emeqah.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqahs', parameterName: 'emeqah' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqahtree-exp-view/emeqahtree-exp-view.vue'),
                },
                {
                    path: 'emeqahs/:emeqah?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emeqah.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqahs', parameterName: 'emeqah' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqahtree-exp-view/emeqahtree-exp-view.vue'),
                },
                {
                    path: 'emitemtypes/:emitemtype?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emitemtype.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemtypes', parameterName: 'emitemtype' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemtypepickup-view/emitemtypepickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emitem.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemoption-view/emitemoption-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emitem.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemoption-view/emitemoption-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emitem.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemoption-view/emitemoption-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emitem.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemoption-view/emitemoption-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emitem.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemoption-view/emitemoption-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emitem.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemoption-view/emitemoption-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.emitem.views.optionview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemoption-view/emitemoption-view.vue'),
                },
                {
                    path: 'emeqlocations/:emeqlocation?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqlocation.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlocations', parameterName: 'emeqlocation' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqlocationgrid-view/emeqlocationgrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emeqtype.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqtypepickup-grid-view/emeqtypepickup-grid-view.vue'),
                },
                {
                    path: 'emoutputs/:emoutput?/emoutputrcts/:emoutputrct?/editview/:editview?',
                    meta: {
                        caption: 'entities.emoutputrct.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emoutputs', parameterName: 'emoutput' },
                            { pathName: 'emoutputrcts', parameterName: 'emoutputrct' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emoutputrctedit-view/emoutputrctedit-view.vue'),
                },
                {
                    path: 'emoutputrcts/:emoutputrct?/editview/:editview?',
                    meta: {
                        caption: 'entities.emoutputrct.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emoutputrcts', parameterName: 'emoutputrct' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emoutputrctedit-view/emoutputrctedit-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emenconsum.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emenconsum.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emenconsum.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emenconsum.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emenconsum.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emenconsum.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emenconsums/:emenconsum?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emenconsum.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emenconsums/:emenconsum?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emenconsum.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emenconsum.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emenconsums/:emenconsum?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emenconsum.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emenconsums/:emenconsum?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emenconsum.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
                },
                {
                    path: 'emen/:emen?/emenconsums/:emenconsum?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emenconsum.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
                },
                {
                    path: 'emenconsums/:emenconsum?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emenconsum.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emenconsums', parameterName: 'emenconsum' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/editview/:editview?',
                    meta: {
                        caption: 'entities.emstorepart.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstorepartedit-view/emstorepartedit-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/editview/:editview?',
                    meta: {
                        caption: 'entities.emstorepart.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstorepartedit-view/emstorepartedit-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.pfemp.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-pf/pfemppickup-view/pfemppickup-view.vue'),
                },
                {
                    path: 'emeqspares/:emeqspare?/emeqsparemaps/:emeqsparemap?/editview/:editview?',
                    meta: {
                        caption: 'entities.emeqsparemap.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqspares', parameterName: 'emeqspare' },
                            { pathName: 'emeqsparemaps', parameterName: 'emeqsparemap' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparemapedit-view/emeqsparemapedit-view.vue'),
                },
                {
                    path: 'emeqsparemaps/:emeqsparemap?/editview/:editview?',
                    meta: {
                        caption: 'entities.emeqsparemap.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqsparemaps', parameterName: 'emeqsparemap' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparemapedit-view/emeqsparemapedit-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emstore.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstoretree-exp-view/emstoretree-exp-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'empurplans/:empurplan?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empurplans', parameterName: 'empurplan' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emequips/:emequip?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emitempuse.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitempuses', parameterName: 'emitempuse' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emeqspares/:emeqspare?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqspare.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqspares', parameterName: 'emeqspare' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparegrid-view/emeqsparegrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emwplist.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistedit-view9-edit-mode/emwplistedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emwplists/:emwplist?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emwplist.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistedit-view9-edit-mode/emwplistedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emwplists/:emwplist?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emwplist.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistedit-view9-edit-mode/emwplistedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emwplists/:emwplist?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emwplist.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistedit-view9-edit-mode/emwplistedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emwplist.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistedit-view9-edit-mode/emwplistedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emwplists/:emwplist?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emwplist.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistedit-view9-edit-mode/emwplistedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emitems/:emitem?/emwplists/:emwplist?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emwplist.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistedit-view9-edit-mode/emwplistedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emwplists/:emwplist?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emwplist.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwplists', parameterName: 'emwplist' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistedit-view9-edit-mode/emwplistedit-view9-edit-mode.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emdrwgs/:emdrwg?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emdrwg.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emdrwgs', parameterName: 'emdrwg' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emdrwgtree-exp-view/emdrwgtree-exp-view.vue'),
                },
                {
                    path: 'emdrwgs/:emdrwg?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emdrwg.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emdrwgs', parameterName: 'emdrwg' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emdrwgtree-exp-view/emdrwgtree-exp-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emwo_ens/:emwo_en?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_en.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-engrid-view/emwo-engrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emwo_ens/:emwo_en?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_en.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-engrid-view/emwo-engrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emwo_ens/:emwo_en?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_en.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-engrid-view/emwo-engrid-view.vue'),
                },
                {
                    path: 'emwo_ens/:emwo_en?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwo_en.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-engrid-view/emwo-engrid-view.vue'),
                },
                {
                    path: 'emoutputs/:emoutput?/editview/:editview?',
                    meta: {
                        caption: 'entities.emoutput.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emoutputs', parameterName: 'emoutput' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emoutputedit-view/emoutputedit-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
                },
                {
                    path: 'emeqspares/:emeqspare?/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqspares', parameterName: 'emeqspare' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
                },
                {
                    path: 'emeqsparedetails/:emeqsparedetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
                },
                {
                    path: 'emeqlcttires/:emeqlcttires?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqlcttires.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlcttires', parameterName: 'emeqlcttires' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqlcttiresgrid-view/emeqlcttiresgrid-view.vue'),
                },
                {
                    path: 'emwooris/:emwoori?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emwoori.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwooris', parameterName: 'emwoori' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwooripickup-grid-view/emwooripickup-grid-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emrfode.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfodepickup-grid-view/emrfodepickup-grid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emwo_inners/:emwo_inner?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_inner.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-inneredit-view-edit-mode/emwo-inneredit-view-edit-mode.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emwo_inners/:emwo_inner?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_inner.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-inneredit-view-edit-mode/emwo-inneredit-view-edit-mode.vue'),
                },
                {
                    path: 'emequips/:emequip?/emwo_inners/:emwo_inner?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_inner.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-inneredit-view-edit-mode/emwo-inneredit-view-edit-mode.vue'),
                },
                {
                    path: 'emwo_inners/:emwo_inner?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_inner.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-inneredit-view-edit-mode/emwo-inneredit-view-edit-mode.vue'),
                },
                {
                    path: 'emeqspares/:emeqspare?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emeqspare.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqspares', parameterName: 'emeqspare' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqsparepickup-view/emeqsparepickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemtrades/:emitemtrade?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emitemtrade.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtradetree-exp-view/emitemtradetree-exp-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitemtrades/:emitemtrade?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emitemtrade.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtradetree-exp-view/emitemtradetree-exp-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitemtrades/:emitemtrade?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emitemtrade.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtradetree-exp-view/emitemtradetree-exp-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitemtrades/:emitemtrade?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emitemtrade.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtradetree-exp-view/emitemtradetree-exp-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitemtrades/:emitemtrade?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emitemtrade.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtradetree-exp-view/emitemtradetree-exp-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitemtrades/:emitemtrade?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emitemtrade.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtradetree-exp-view/emitemtradetree-exp-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitemtrades/:emitemtrade?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emitemtrade.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtradetree-exp-view/emitemtradetree-exp-view.vue'),
                },
                {
                    path: 'emitemtrades/:emitemtrade?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emitemtrade.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emitemtradetree-exp-view/emitemtradetree-exp-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqtype.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqtypegrid-view/emeqtypegrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emen.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenpickup-view/emenpickup-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emen/:emen?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emen.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenpickup-view/emenpickup-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emen/:emen?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emen.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenpickup-view/emenpickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emen/:emen?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emen.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenpickup-view/emenpickup-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emen.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenpickup-view/emenpickup-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emen/:emen?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emen.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenpickup-view/emenpickup-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emen/:emen?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emen.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenpickup-view/emenpickup-view.vue'),
                },
                {
                    path: 'emen/:emen?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emen.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emen', parameterName: 'emen' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-en/emenpickup-view/emenpickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emstorepart.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstorepartpickup-view/emstorepartpickup-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emstorepart.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstorepartpickup-view/emstorepartpickup-view.vue'),
                },
                {
                    path: 'pfcontracts/:pfcontract?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.pfcontract.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfcontracts', parameterName: 'pfcontract' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-pf/pfcontractpickup-view/pfcontractpickup-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emwo_ens/:emwo_en?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_en.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-enedit-view-edit-mode/emwo-enedit-view-edit-mode.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emwo_ens/:emwo_en?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_en.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-enedit-view-edit-mode/emwo-enedit-view-edit-mode.vue'),
                },
                {
                    path: 'emequips/:emequip?/emwo_ens/:emwo_en?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_en.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-enedit-view-edit-mode/emwo-enedit-view-edit-mode.vue'),
                },
                {
                    path: 'emwo_ens/:emwo_en?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emwo_en.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-enedit-view-edit-mode/emwo-enedit-view-edit-mode.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emrfode.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfodegrid-view/emrfodegrid-view.vue'),
                },
                {
                    path: 'emassets/:emasset?/emassetclears/:emassetclear?/editview_908/:editview_908?',
                    meta: {
                        caption: 'entities.emassetclear.views.editview_908.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassets', parameterName: 'emasset' },
                            { pathName: 'emassetclears', parameterName: 'emassetclear' },
                            { pathName: 'editview_908', parameterName: 'editview_908' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-as/emassetclearedit-view-908/emassetclearedit-view-908.vue'),
                },
                {
                    path: 'emassetclears/:emassetclear?/editview_908/:editview_908?',
                    meta: {
                        caption: 'entities.emassetclear.views.editview_908.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassetclears', parameterName: 'emassetclear' },
                            { pathName: 'editview_908', parameterName: 'editview_908' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-as/emassetclearedit-view-908/emassetclearedit-view-908.vue'),
                },
                {
                    path: 'emassetclasses/:emassetclass?/editview_4778/:editview_4778?',
                    meta: {
                        caption: 'entities.emassetclass.views.editview_4778.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassetclasses', parameterName: 'emassetclass' },
                            { pathName: 'editview_4778', parameterName: 'editview_4778' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-as/emassetclassedit-view-4778/emassetclassedit-view-4778.vue'),
                },
                {
                    path: 'appportalview/:appportalview?',
                    meta: {
                        caption: 'app.views.appportalview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'appportalview', parameterName: 'appportalview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-dyna/app-portal-view/app-portal-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emstocks/:emstock?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emstock.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emstocks/:emstock?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emstock.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emstocks/:emstock?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emstock.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emstocks/:emstock?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emstock.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emstocks/:emstock?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emstock.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emstocks/:emstock?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emstock.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emstocks/:emstock?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emstock.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstocks/:emstock?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emstock.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emstocks/:emstock?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emstock.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emstocks/:emstock?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emstock.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
                },
                {
                    path: 'emstocks/:emstock?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emstock.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstocks', parameterName: 'emstock' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
                },
                {
                    path: 'emassets/:emasset?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emasset.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassets', parameterName: 'emasset' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emassetpickup-view/emassetpickup-view.vue'),
                },
                {
                    path: 'emitemtypes/:emitemtype?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemtype.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemtypes', parameterName: 'emitemtype' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemtypegrid-view/emitemtypegrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emservice.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emservicegrid-view/emservicegrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emwos/:emwo?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emwo.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwos', parameterName: 'emwo' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwotree-exp-view/emwotree-exp-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emwos/:emwo?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emwo.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwos', parameterName: 'emwo' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwotree-exp-view/emwotree-exp-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emwos/:emwo?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emwo.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwos', parameterName: 'emwo' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwotree-exp-view/emwotree-exp-view.vue'),
                },
                {
                    path: 'emwos/:emwo?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emwo.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwos', parameterName: 'emwo' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwotree-exp-view/emwotree-exp-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplan.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplan.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplan.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplan.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplan.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplan.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplan.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplans/:emplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplan.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplans/:emplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplan.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplans/:emplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplan.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplans/:emplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplan.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
                },
                {
                    path: 'emplantempls/:emplantempl?/emplans/:emplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplan.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emplans/:emplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplan.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplans/:emplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplan.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
                },
                {
                    path: 'emplans/:emplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emplan.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emwplistcost.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostedit-view9/emwplistcostedit-view9.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emwplistcost.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostedit-view9/emwplistcostedit-view9.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emwplistcost.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostedit-view9/emwplistcostedit-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emwplistcost.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostedit-view9/emwplistcostedit-view9.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emwplistcost.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostedit-view9/emwplistcostedit-view9.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emwplistcost.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostedit-view9/emwplistcostedit-view9.vue'),
                },
                {
                    path: 'emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emwplistcost.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostedit-view9/emwplistcostedit-view9.vue'),
                },
                {
                    path: 'emwplistcosts/:emwplistcost?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.emwplistcost.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emwplistcostedit-view9/emwplistcostedit-view9.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfomos/:emrfomo?/editview/:editview?',
                    meta: {
                        caption: 'entities.emrfomo.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfomoedit-view/emrfomoedit-view.vue'),
                },
                {
                    path: 'emrfomos/:emrfomo?/editview/:editview?',
                    meta: {
                        caption: 'entities.emrfomo.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfomoedit-view/emrfomoedit-view.vue'),
                },
                {
                    path: 'emeqlctgsses/:emeqlctgss?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emeqlctgss.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-eq/emeqlctgssgrid-view/emeqlctgssgrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.pfemp.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-pf/pfemppickup-grid-view/pfemppickup-grid-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplancdt.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplancdt.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplancdt.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplancdt.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplancdt.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplancdt.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplancdt.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplancdt.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplancdt.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
                },
                {
                    path: 'pfdepts/:pfdept?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplancdt.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfdepts', parameterName: 'pfdept' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplancdt.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
                },
                {
                    path: 'emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplancdt.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplantempls', parameterName: 'emplantempl' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplancdt.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
                },
                {
                    path: 'emacclasses/:emacclass?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplancdt.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emacclasses', parameterName: 'emacclass' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
                },
                {
                    path: 'emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplancdt.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplans', parameterName: 'emplan' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
                },
                {
                    path: 'emplancdts/:emplancdt?/editview/:editview?',
                    meta: {
                        caption: 'entities.emplancdt.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emplancdts', parameterName: 'emplancdt' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/editview/:editview?',
                    meta: {
                        caption: 'entities.emrfode.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-rfo/emrfodeedit-view/emrfodeedit-view.vue'),
                },
                {
                    path: 'emassets/:emasset?/gridview_bf/:gridview_bf?',
                    meta: {
                        caption: 'entities.emasset.views.gridview_bf.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassets', parameterName: 'emasset' },
                            { pathName: 'gridview_bf', parameterName: 'gridview_bf' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-as/emassetgrid-view-bf/emassetgrid-view-bf.vue'),
                },
                {
                    path: 'emeqlctgsses/:emeqlctgss?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.emeqlctgss.views.treeexpview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqlctgsstree-exp-view/emeqlctgsstree-exp-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.pfteam.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-pf/pfteampickup-view/pfteampickup-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistcostgrid-view/emwplistcostgrid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emwplistcosts/:emwplistcost?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistcostgrid-view/emwplistcostgrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emwplistcosts/:emwplistcost?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistcostgrid-view/emwplistcostgrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emwplistcosts/:emwplistcost?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistcostgrid-view/emwplistcostgrid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistcostgrid-view/emwplistcostgrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emwplistcosts/:emwplistcost?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistcostgrid-view/emwplistcostgrid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emwplistcosts/:emwplistcost?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistcostgrid-view/emwplistcostgrid-view.vue'),
                },
                {
                    path: 'emwplistcosts/:emwplistcost?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emwplistcost.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emwplistcostgrid-view/emwplistcostgrid-view.vue'),
                },
                {
                    path: 'pfcontracts/:pfcontract?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.pfcontract.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfcontracts', parameterName: 'pfcontract' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/pfcontractedit-view9-edit-mode/pfcontractedit-view9-edit-mode.vue'),
                },
                {
                    path: 'empos/:empo?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.empo.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empos', parameterName: 'empo' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empopickup-grid-view/empopickup-grid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emstorepart.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstorepartpickup-grid-view/emstorepartpickup-grid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emstorepart.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emstorepartpickup-grid-view/emstorepartpickup-grid-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfomos/:emrfomo?/emrfoacs/:emrfoac?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emrfoac.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfoacpickup-grid-view/emrfoacpickup-grid-view.vue'),
                },
                {
                    path: 'emrfomos/:emrfomo?/emrfoacs/:emrfoac?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emrfoac.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfomos', parameterName: 'emrfomo' },
                            { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfoacpickup-grid-view/emrfoacpickup-grid-view.vue'),
                },
                {
                    path: 'emrfodes/:emrfode?/emrfoacs/:emrfoac?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emrfoac.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfodes', parameterName: 'emrfode' },
                            { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfoacpickup-grid-view/emrfoacpickup-grid-view.vue'),
                },
                {
                    path: 'emrfoacs/:emrfoac?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emrfoac.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emrfoacpickup-grid-view/emrfoacpickup-grid-view.vue'),
                },
                {
                    path: 'emitemcs/:emitemcs?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemcs.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemcs', parameterName: 'emitemcs' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemcsgrid-view/emitemcsgrid-view.vue'),
                },
                {
                    path: 'emserviceevls/:emserviceevl?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emserviceevl.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emserviceevls', parameterName: 'emserviceevl' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wp/emserviceevledit-view9-edit-mode/emserviceevledit-view9-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/empodetails/:empodetail?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/empodetails/:empodetail?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/empodetails/:empodetail?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/empodetails/:empodetail?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
                },
                {
                    path: 'empos/:empo?/empodetails/:empodetail?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empos', parameterName: 'empo' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
                },
                {
                    path: 'emitems/:emitem?/empodetails/:empodetail?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
                },
                {
                    path: 'empodetails/:empodetail?/editview9/:editview9?',
                    meta: {
                        caption: 'entities.empodetail.views.editview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empodetails', parameterName: 'empodetail' },
                            { pathName: 'editview9', parameterName: 'editview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emwo_inners/:emwo_inner?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_inner.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-inneredit-view/emwo-inneredit-view.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emwo_inners/:emwo_inner?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_inner.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-inneredit-view/emwo-inneredit-view.vue'),
                },
                {
                    path: 'emequips/:emequip?/emwo_inners/:emwo_inner?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_inner.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-inneredit-view/emwo-inneredit-view.vue'),
                },
                {
                    path: 'emwo_inners/:emwo_inner?/editview/:editview?',
                    meta: {
                        caption: 'entities.emwo_inner.views.editview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emwo-inneredit-view/emwo-inneredit-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.gridview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'gridview9', parameterName: 'gridview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.gridview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'gridview9', parameterName: 'gridview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.gridview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'gridview9', parameterName: 'gridview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.gridview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'gridview9', parameterName: 'gridview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.gridview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'gridview9', parameterName: 'gridview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.gridview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'gridview9', parameterName: 'gridview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
                },
                {
                    path: 'emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.gridview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'gridview9', parameterName: 'gridview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
                },
                {
                    path: 'emeqspares/:emeqspare?/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.gridview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqspares', parameterName: 'emeqspare' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'gridview9', parameterName: 'gridview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
                },
                {
                    path: 'emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
                    meta: {
                        caption: 'entities.emeqsparedetail.views.gridview9.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                            { pathName: 'gridview9', parameterName: 'gridview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emapplies/:emapply?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emapply.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emapplies', parameterName: 'emapply' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emapplyedit-view-edit-mode/emapplyedit-view-edit-mode.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emapplies/:emapply?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emapply.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emapplies', parameterName: 'emapply' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emapplyedit-view-edit-mode/emapplyedit-view-edit-mode.vue'),
                },
                {
                    path: 'emequips/:emequip?/emapplies/:emapply?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emapply.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emapplies', parameterName: 'emapply' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emapplyedit-view-edit-mode/emapplyedit-view-edit-mode.vue'),
                },
                {
                    path: 'emapplies/:emapply?/editview_editmode/:editview_editmode?',
                    meta: {
                        caption: 'entities.emapply.views.editview_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emapplies', parameterName: 'emapply' },
                            { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-wo/emapplyedit-view-edit-mode/emapplyedit-view-edit-mode.vue'),
                },
                {
                    path: 'emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemprtns/:emitemprtn?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemprtn.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemprtngrid-view/emitemprtngrid-view.vue'),
                },
                {
                    path: 'pfunits/:pfunit?/emitems/:emitem?/emitemprtns/:emitemprtn?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemprtn.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfunits', parameterName: 'pfunit' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemprtngrid-view/emitemprtngrid-view.vue'),
                },
                {
                    path: 'pfemps/:pfemp?/emitems/:emitem?/emitemprtns/:emitemprtn?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemprtn.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfemps', parameterName: 'pfemp' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemprtngrid-view/emitemprtngrid-view.vue'),
                },
                {
                    path: 'emstores/:emstore?/emitems/:emitem?/emitemprtns/:emitemprtn?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemprtn.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstores', parameterName: 'emstore' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemprtngrid-view/emitemprtngrid-view.vue'),
                },
                {
                    path: 'emstoreparts/:emstorepart?/emitems/:emitem?/emitemprtns/:emitemprtn?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemprtn.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemprtngrid-view/emitemprtngrid-view.vue'),
                },
                {
                    path: 'emservices/:emservice?/emitems/:emitem?/emitemprtns/:emitemprtn?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemprtn.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemprtngrid-view/emitemprtngrid-view.vue'),
                },
                {
                    path: 'emitems/:emitem?/emitemprtns/:emitemprtn?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemprtn.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitems', parameterName: 'emitem' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemprtngrid-view/emitemprtngrid-view.vue'),
                },
                {
                    path: 'emitemprtns/:emitemprtn?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emitemprtn.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-mat/emitemprtngrid-view/emitemprtngrid-view.vue'),
                },
                {
                    path: 'emobjects/:emobject?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.emobject.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emobjects', parameterName: 'emobject' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emobjectpickup-grid-view/emobjectpickup-grid-view.vue'),
                },
                {
                    path: 'empurplans/:empurplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.empurplan.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'empurplans', parameterName: 'empurplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/empurplanpickup-view/empurplanpickup-view.vue'),
                },
                {
                    path: 'pfteams/:pfteam?/emequips/:emequip?/emeqdebugs/:emeqdebug?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqdebug.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'pfteams', parameterName: 'pfteam' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqdebugedit-view9-edit-mode/emeqdebugedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emeqtypes/:emeqtype?/emequips/:emequip?/emeqdebugs/:emeqdebug?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqdebug.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqdebugedit-view9-edit-mode/emeqdebugedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emequips/:emequip?/emeqdebugs/:emeqdebug?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqdebug.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emequips', parameterName: 'emequip' },
                            { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqdebugedit-view9-edit-mode/emeqdebugedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emeqdebugs/:emeqdebug?/editview9_editmode/:editview9_editmode?',
                    meta: {
                        caption: 'entities.emeqdebug.views.editview9_editmode.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                            { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-act/emeqdebugedit-view9-edit-mode/emeqdebugedit-view9-edit-mode.vue'),
                },
                {
                    path: 'emservices/:emservice?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.emservice.views.pickupview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emservices', parameterName: 'emservice' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-core/emservicepickup-view/emservicepickup-view.vue'),
                },
                {
                    path: 'emassets/:emasset?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.emasset.views.gridview.caption',
                        parameters: [
                            { pathName: 'appindex', parameterName: 'appindex' },
                            { pathName: 'emassets', parameterName: 'emasset' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/eam-as/emassetgrid-view/emassetgrid-view.vue'),
                },
            ...indexRoutes,
            ],
        },
    {
        path: '/emitemtypes/:emitemtype?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemtype.views.gridview.caption',
            parameters: [
                { pathName: 'emitemtypes', parameterName: 'emitemtype' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemtypegrid-view/emitemtypegrid-view.vue'),
    },
    {
        path: '/emassets/:emasset?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emasset.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emassets', parameterName: 'emasset' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emassetpickup-grid-view/emassetpickup-grid-view.vue'),
    },
    {
        path: '/emeqlctrhies/:emeqlctrhy?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqlctrhy.views.gridview.caption',
            parameters: [
                { pathName: 'emeqlctrhies', parameterName: 'emeqlctrhy' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqlctrhygrid-view/emeqlctrhygrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/editview/:editview?',
        meta: {
            caption: 'entities.emstorepart.views.editview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstorepartedit-view/emstorepartedit-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/editview/:editview?',
        meta: {
            caption: 'entities.emstorepart.views.editview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstorepartedit-view/emstorepartedit-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emrfode.views.tabexpview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfodetab-exp-view/emrfodetab-exp-view.vue'),
    },
    {
        path: '/empos/:empo?/gridview/:gridview?',
        meta: {
            caption: 'entities.empo.views.gridview.caption',
            parameters: [
                { pathName: 'empos', parameterName: 'empo' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empogrid-view/empogrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqkeeps/:emeqkeep?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqkeep.views.editview9.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqkeepedit-view9/emeqkeepedit-view9.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqkeeps/:emeqkeep?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqkeep.views.editview9.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqkeepedit-view9/emeqkeepedit-view9.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqkeeps/:emeqkeep?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqkeep.views.editview9.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqkeepedit-view9/emeqkeepedit-view9.vue'),
    },
    {
        path: '/emeqkeeps/:emeqkeep?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqkeep.views.editview9.caption',
            parameters: [
                { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqkeepedit-view9/emeqkeepedit-view9.vue'),
    },
    {
        path: '/pfemps/:pfemp?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.pfemp.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-pf/pfemppickup-grid-view/pfemppickup-grid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplantempls/:emplantempl?/editview/:editview?',
        meta: {
            caption: 'entities.emplantempl.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantempledit-view/emplantempledit-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplantempls/:emplantempl?/editview/:editview?',
        meta: {
            caption: 'entities.emplantempl.views.editview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantempledit-view/emplantempledit-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplantempls/:emplantempl?/editview/:editview?',
        meta: {
            caption: 'entities.emplantempl.views.editview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantempledit-view/emplantempledit-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplantempls/:emplantempl?/editview/:editview?',
        meta: {
            caption: 'entities.emplantempl.views.editview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantempledit-view/emplantempledit-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplantempls/:emplantempl?/editview/:editview?',
        meta: {
            caption: 'entities.emplantempl.views.editview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantempledit-view/emplantempledit-view.vue'),
    },
    {
        path: '/emplantempls/:emplantempl?/editview/:editview?',
        meta: {
            caption: 'entities.emplantempl.views.editview.caption',
            parameters: [
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantempledit-view/emplantempledit-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.empodetail.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.empodetail.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.empodetail.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.empodetail.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.empodetail.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.empodetail.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
    },
    {
        path: '/empos/:empo?/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.empodetail.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'empos', parameterName: 'empo' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
    },
    {
        path: '/emitems/:emitem?/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.empodetail.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
    },
    {
        path: '/empodetails/:empodetail?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.empodetail.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailedit-view9-edit-mode/empodetailedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeqlctgsses/:emeqlctgss?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emeqlctgss.views.tabexpview.caption',
            parameters: [
                { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqlctgsstab-exp-view/emeqlctgsstab-exp-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
    },
    {
        path: '/emeqspares/:emeqspare?/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview.caption',
            parameters: [
                { pathName: 'emeqspares', parameterName: 'emeqspare' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
    },
    {
        path: '/emeqsparedetails/:emeqsparedetail?/editview/:editview?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview.caption',
            parameters: [
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view/emeqsparedetailedit-view.vue'),
    },
    {
        path: '/emproducts/:emproduct?/gridview/:gridview?',
        meta: {
            caption: 'entities.emproduct.views.gridview.caption',
            parameters: [
                { pathName: 'emproducts', parameterName: 'emproduct' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emproductgrid-view/emproductgrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emwplist.views.treeexpview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplisttree-exp-view/emwplisttree-exp-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emwplists/:emwplist?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emwplist.views.treeexpview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplisttree-exp-view/emwplisttree-exp-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emwplists/:emwplist?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emwplist.views.treeexpview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplisttree-exp-view/emwplisttree-exp-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emwplists/:emwplist?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emwplist.views.treeexpview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplisttree-exp-view/emwplisttree-exp-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emwplist.views.treeexpview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplisttree-exp-view/emwplisttree-exp-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emwplists/:emwplist?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emwplist.views.treeexpview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplisttree-exp-view/emwplisttree-exp-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emwplists/:emwplist?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emwplist.views.treeexpview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplisttree-exp-view/emwplisttree-exp-view.vue'),
    },
    {
        path: '/emwplists/:emwplist?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emwplist.views.treeexpview.caption',
            parameters: [
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplisttree-exp-view/emwplisttree-exp-view.vue'),
    },
    {
        path: '/emitemcs/:emitemcs?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemcs.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emitemcs', parameterName: 'emitemcs' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemcsedit-view9-edit-mode/emitemcsedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqsetups/:emeqsetup?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqsetup.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqsetupedit-view9-edit-mode/emeqsetupedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqsetups/:emeqsetup?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqsetup.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqsetupedit-view9-edit-mode/emeqsetupedit-view9-edit-mode.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqsetups/:emeqsetup?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqsetup.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqsetupedit-view9-edit-mode/emeqsetupedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeqsetups/:emeqsetup?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqsetup.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqsetupedit-view9-edit-mode/emeqsetupedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemtrades/:emitemtrade?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemtrade.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtradegrid-view/emitemtradegrid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitemtrades/:emitemtrade?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemtrade.views.gridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtradegrid-view/emitemtradegrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitemtrades/:emitemtrade?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemtrade.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtradegrid-view/emitemtradegrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitemtrades/:emitemtrade?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemtrade.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtradegrid-view/emitemtradegrid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitemtrades/:emitemtrade?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemtrade.views.gridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtradegrid-view/emitemtradegrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitemtrades/:emitemtrade?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemtrade.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtradegrid-view/emitemtradegrid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emitemtrades/:emitemtrade?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemtrade.views.gridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtradegrid-view/emitemtradegrid-view.vue'),
    },
    {
        path: '/emitemtrades/:emitemtrade?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemtrade.views.gridview.caption',
            parameters: [
                { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtradegrid-view/emitemtradegrid-view.vue'),
    },
    {
        path: '/emeqlcttires/:emeqlcttires?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emeqlcttires.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emeqlcttires', parameterName: 'emeqlcttires' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqlcttirespickup-grid-view/emeqlcttirespickup-grid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqchecks/:emeqcheck?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqcheck.views.editview9.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqcheckedit-view9/emeqcheckedit-view9.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqchecks/:emeqcheck?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqcheck.views.editview9.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqcheckedit-view9/emeqcheckedit-view9.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqchecks/:emeqcheck?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqcheck.views.editview9.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqcheckedit-view9/emeqcheckedit-view9.vue'),
    },
    {
        path: '/emeqchecks/:emeqcheck?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqcheck.views.editview9.caption',
            parameters: [
                { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqcheckedit-view9/emeqcheckedit-view9.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emwo_dps/:emwo_dp?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_dp.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpedit-view-edit-mode/emwo-dpedit-view-edit-mode.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emwo_dps/:emwo_dp?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_dp.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpedit-view-edit-mode/emwo-dpedit-view-edit-mode.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emwo_dps/:emwo_dp?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_dp.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpedit-view-edit-mode/emwo-dpedit-view-edit-mode.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emwo_dps/:emwo_dp?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_dp.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpedit-view-edit-mode/emwo-dpedit-view-edit-mode.vue'),
    },
    {
        path: '/emequips/:emequip?/emwo_dps/:emwo_dp?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_dp.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpedit-view-edit-mode/emwo-dpedit-view-edit-mode.vue'),
    },
    {
        path: '/emwo_dps/:emwo_dp?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_dp.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpedit-view-edit-mode/emwo-dpedit-view-edit-mode.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emequip.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emequipedit-view-edit-mode/emequipedit-view-edit-mode.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emequip.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emequipedit-view-edit-mode/emequipedit-view-edit-mode.vue'),
    },
    {
        path: '/emequips/:emequip?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emequip.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emequipedit-view-edit-mode/emequipedit-view-edit-mode.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/gridview/:gridview?',
        meta: {
            caption: 'entities.emrfode.views.gridview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfodegrid-view/emrfodegrid-view.vue'),
    },
    {
        path: '/emassets/:emasset?/gridview_bf/:gridview_bf?',
        meta: {
            caption: 'entities.emasset.views.gridview_bf.caption',
            parameters: [
                { pathName: 'emassets', parameterName: 'emasset' },
                { pathName: 'gridview_bf', parameterName: 'gridview_bf' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-as/emassetgrid-view-bf/emassetgrid-view-bf.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqsetups/:emeqsetup?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqsetup.views.editview9.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqsetupedit-view9/emeqsetupedit-view9.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqsetups/:emeqsetup?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqsetup.views.editview9.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqsetupedit-view9/emeqsetupedit-view9.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqsetups/:emeqsetup?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqsetup.views.editview9.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqsetupedit-view9/emeqsetupedit-view9.vue'),
    },
    {
        path: '/emeqsetups/:emeqsetup?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqsetup.views.editview9.caption',
            parameters: [
                { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqsetupedit-view9/emeqsetupedit-view9.vue'),
    },
    {
        path: '/emoutputs/:emoutput?/editview9/:editview9?',
        meta: {
            caption: 'entities.emoutput.views.editview9.caption',
            parameters: [
                { pathName: 'emoutputs', parameterName: 'emoutput' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emoutputedit-view9/emoutputedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemprtn.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemprtnedit-view9-edit-mode/emitemprtnedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemprtn.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemprtnedit-view9-edit-mode/emitemprtnedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemprtn.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemprtnedit-view9-edit-mode/emitemprtnedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemprtn.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemprtnedit-view9-edit-mode/emitemprtnedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemprtn.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemprtnedit-view9-edit-mode/emitemprtnedit-view9-edit-mode.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemprtn.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemprtnedit-view9-edit-mode/emitemprtnedit-view9-edit-mode.vue'),
    },
    {
        path: '/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemprtn.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemprtnedit-view9-edit-mode/emitemprtnedit-view9-edit-mode.vue'),
    },
    {
        path: '/emitemprtns/:emitemprtn?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemprtn.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemprtnedit-view9-edit-mode/emitemprtnedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqkeeps/:emeqkeep?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqkeep.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqkeepgrid-view/emeqkeepgrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqkeeps/:emeqkeep?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqkeep.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqkeepgrid-view/emeqkeepgrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqkeeps/:emeqkeep?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqkeep.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqkeepgrid-view/emeqkeepgrid-view.vue'),
    },
    {
        path: '/emeqkeeps/:emeqkeep?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqkeep.views.gridview.caption',
            parameters: [
                { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqkeepgrid-view/emeqkeepgrid-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfomos/:emrfomo?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emrfomo.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfomopickup-grid-view/emrfomopickup-grid-view.vue'),
    },
    {
        path: '/emrfomos/:emrfomo?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emrfomo.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfomopickup-grid-view/emrfomopickup-grid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emservice.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emservicepickup-grid-view/emservicepickup-grid-view.vue'),
    },
    {
        path: '/empurplans/:empurplan?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.empurplan.views.pickupview.caption',
            parameters: [
                { pathName: 'empurplans', parameterName: 'empurplan' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empurplanpickup-view/empurplanpickup-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplantempls/:emplantempl?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emplantempl.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantempledit-view-edit-mode/emplantempledit-view-edit-mode.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplantempls/:emplantempl?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emplantempl.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantempledit-view-edit-mode/emplantempledit-view-edit-mode.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplantempls/:emplantempl?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emplantempl.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantempledit-view-edit-mode/emplantempledit-view-edit-mode.vue'),
    },
    {
        path: '/emservices/:emservice?/emplantempls/:emplantempl?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emplantempl.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantempledit-view-edit-mode/emplantempledit-view-edit-mode.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplantempls/:emplantempl?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emplantempl.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantempledit-view-edit-mode/emplantempledit-view-edit-mode.vue'),
    },
    {
        path: '/emplantempls/:emplantempl?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emplantempl.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantempledit-view-edit-mode/emplantempledit-view-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/gridview_ydh/:gridview_ydh?',
        meta: {
            caption: 'entities.emwplist.views.gridview_ydh.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'gridview_ydh', parameterName: 'gridview_ydh' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistgrid-view-ydh/emwplistgrid-view-ydh.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emwplists/:emwplist?/gridview_ydh/:gridview_ydh?',
        meta: {
            caption: 'entities.emwplist.views.gridview_ydh.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'gridview_ydh', parameterName: 'gridview_ydh' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistgrid-view-ydh/emwplistgrid-view-ydh.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emwplists/:emwplist?/gridview_ydh/:gridview_ydh?',
        meta: {
            caption: 'entities.emwplist.views.gridview_ydh.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'gridview_ydh', parameterName: 'gridview_ydh' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistgrid-view-ydh/emwplistgrid-view-ydh.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emwplists/:emwplist?/gridview_ydh/:gridview_ydh?',
        meta: {
            caption: 'entities.emwplist.views.gridview_ydh.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'gridview_ydh', parameterName: 'gridview_ydh' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistgrid-view-ydh/emwplistgrid-view-ydh.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/gridview_ydh/:gridview_ydh?',
        meta: {
            caption: 'entities.emwplist.views.gridview_ydh.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'gridview_ydh', parameterName: 'gridview_ydh' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistgrid-view-ydh/emwplistgrid-view-ydh.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emwplists/:emwplist?/gridview_ydh/:gridview_ydh?',
        meta: {
            caption: 'entities.emwplist.views.gridview_ydh.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'gridview_ydh', parameterName: 'gridview_ydh' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistgrid-view-ydh/emwplistgrid-view-ydh.vue'),
    },
    {
        path: '/emitems/:emitem?/emwplists/:emwplist?/gridview_ydh/:gridview_ydh?',
        meta: {
            caption: 'entities.emwplist.views.gridview_ydh.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'gridview_ydh', parameterName: 'gridview_ydh' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistgrid-view-ydh/emwplistgrid-view-ydh.vue'),
    },
    {
        path: '/emwplists/:emwplist?/gridview_ydh/:gridview_ydh?',
        meta: {
            caption: 'entities.emwplist.views.gridview_ydh.caption',
            parameters: [
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'gridview_ydh', parameterName: 'gridview_ydh' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistgrid-view-ydh/emwplistgrid-view-ydh.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwplistcost.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostpickup-view/emwplistcostpickup-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwplistcost.views.pickupview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostpickup-view/emwplistcostpickup-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwplistcost.views.pickupview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostpickup-view/emwplistcostpickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwplistcost.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostpickup-view/emwplistcostpickup-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwplistcost.views.pickupview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostpickup-view/emwplistcostpickup-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwplistcost.views.pickupview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostpickup-view/emwplistcostpickup-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwplistcost.views.pickupview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostpickup-view/emwplistcostpickup-view.vue'),
    },
    {
        path: '/emwplistcosts/:emwplistcost?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwplistcost.views.pickupview.caption',
            parameters: [
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostpickup-view/emwplistcostpickup-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.pfunit.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-pf/pfunitpickup-grid-view/pfunitpickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/editview9/:editview9?',
        meta: {
            caption: 'entities.emwplist.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistedit-view9/emwplistedit-view9.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emwplists/:emwplist?/editview9/:editview9?',
        meta: {
            caption: 'entities.emwplist.views.editview9.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistedit-view9/emwplistedit-view9.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emwplists/:emwplist?/editview9/:editview9?',
        meta: {
            caption: 'entities.emwplist.views.editview9.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistedit-view9/emwplistedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emwplists/:emwplist?/editview9/:editview9?',
        meta: {
            caption: 'entities.emwplist.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistedit-view9/emwplistedit-view9.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/editview9/:editview9?',
        meta: {
            caption: 'entities.emwplist.views.editview9.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistedit-view9/emwplistedit-view9.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emwplists/:emwplist?/editview9/:editview9?',
        meta: {
            caption: 'entities.emwplist.views.editview9.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistedit-view9/emwplistedit-view9.vue'),
    },
    {
        path: '/emitems/:emitem?/emwplists/:emwplist?/editview9/:editview9?',
        meta: {
            caption: 'entities.emwplist.views.editview9.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistedit-view9/emwplistedit-view9.vue'),
    },
    {
        path: '/emwplists/:emwplist?/editview9/:editview9?',
        meta: {
            caption: 'entities.emwplist.views.editview9.caption',
            parameters: [
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistedit-view9/emwplistedit-view9.vue'),
    },
    {
        path: '/emeqspares/:emeqspare?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emeqspare.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emeqspares', parameterName: 'emeqspare' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparepickup-grid-view/emeqsparepickup-grid-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfomos/:emrfomo?/emrfoacs/:emrfoac?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emrfoac.views.pickupview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfoacpickup-view/emrfoacpickup-view.vue'),
    },
    {
        path: '/emrfomos/:emrfomo?/emrfoacs/:emrfoac?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emrfoac.views.pickupview.caption',
            parameters: [
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfoacpickup-view/emrfoacpickup-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfoacs/:emrfoac?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emrfoac.views.pickupview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfoacpickup-view/emrfoacpickup-view.vue'),
    },
    {
        path: '/emrfoacs/:emrfoac?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emrfoac.views.pickupview.caption',
            parameters: [
                { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfoacpickup-view/emrfoacpickup-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emwo_inners/:emwo_inner?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_inner.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-inneredit-view/emwo-inneredit-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emwo_inners/:emwo_inner?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_inner.views.editview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-inneredit-view/emwo-inneredit-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emwo_inners/:emwo_inner?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_inner.views.editview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-inneredit-view/emwo-inneredit-view.vue'),
    },
    {
        path: '/emwo_inners/:emwo_inner?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_inner.views.editview.caption',
            parameters: [
                { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-inneredit-view/emwo-inneredit-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/editview/:editview?',
        meta: {
            caption: 'entities.emitem.views.editview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemedit-view/emitemedit-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/editview/:editview?',
        meta: {
            caption: 'entities.emitem.views.editview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemedit-view/emitemedit-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/editview/:editview?',
        meta: {
            caption: 'entities.emitem.views.editview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemedit-view/emitemedit-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/editview/:editview?',
        meta: {
            caption: 'entities.emitem.views.editview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemedit-view/emitemedit-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/editview/:editview?',
        meta: {
            caption: 'entities.emitem.views.editview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemedit-view/emitemedit-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/editview/:editview?',
        meta: {
            caption: 'entities.emitem.views.editview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemedit-view/emitemedit-view.vue'),
    },
    {
        path: '/emitems/:emitem?/editview/:editview?',
        meta: {
            caption: 'entities.emitem.views.editview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemedit-view/emitemedit-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.pfemp.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/pfempedit-view-edit-mode/pfempedit-view-edit-mode.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emwos/:emwo?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwo.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwos', parameterName: 'emwo' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwopickup-grid-view/emwopickup-grid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emwos/:emwo?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwo.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwos', parameterName: 'emwo' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwopickup-grid-view/emwopickup-grid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emwos/:emwo?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwo.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwos', parameterName: 'emwo' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwopickup-grid-view/emwopickup-grid-view.vue'),
    },
    {
        path: '/emwos/:emwo?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwo.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emwos', parameterName: 'emwo' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwopickup-grid-view/emwopickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitem.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempickup-view/emitempickup-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitem.views.pickupview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempickup-view/emitempickup-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitem.views.pickupview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempickup-view/emitempickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitem.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempickup-view/emitempickup-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitem.views.pickupview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempickup-view/emitempickup-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitem.views.pickupview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempickup-view/emitempickup-view.vue'),
    },
    {
        path: '/emitems/:emitem?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitem.views.pickupview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempickup-view/emitempickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/gridview/:gridview?',
        meta: {
            caption: 'entities.emen.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emengrid-view/emengrid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emen/:emen?/gridview/:gridview?',
        meta: {
            caption: 'entities.emen.views.gridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emengrid-view/emengrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emen/:emen?/gridview/:gridview?',
        meta: {
            caption: 'entities.emen.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emengrid-view/emengrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emen/:emen?/gridview/:gridview?',
        meta: {
            caption: 'entities.emen.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emengrid-view/emengrid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/gridview/:gridview?',
        meta: {
            caption: 'entities.emen.views.gridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emengrid-view/emengrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emen/:emen?/gridview/:gridview?',
        meta: {
            caption: 'entities.emen.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emengrid-view/emengrid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emen/:emen?/gridview/:gridview?',
        meta: {
            caption: 'entities.emen.views.gridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emengrid-view/emengrid-view.vue'),
    },
    {
        path: '/emen/:emen?/gridview/:gridview?',
        meta: {
            caption: 'entities.emen.views.gridview.caption',
            parameters: [
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emengrid-view/emengrid-view.vue'),
    },
    {
        path: '/appportalview/:appportalview?',
        meta: {
            caption: 'app.views.appportalview.caption',
            parameters: [
                { pathName: 'appportalview', parameterName: 'appportalview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-dyna/app-portal-view/app-portal-view.vue'),
    },
    {
        path: '/emrfodetypes/:emrfodetype?/gridview/:gridview?',
        meta: {
            caption: 'entities.emrfodetype.views.gridview.caption',
            parameters: [
                { pathName: 'emrfodetypes', parameterName: 'emrfodetype' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfodetypegrid-view/emrfodetypegrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/editview/:editview?',
        meta: {
            caption: 'entities.emeqtype.views.editview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqtypeedit-view/emeqtypeedit-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwplist.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistpickup-grid-view/emwplistpickup-grid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emwplists/:emwplist?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwplist.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistpickup-grid-view/emwplistpickup-grid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emwplists/:emwplist?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwplist.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistpickup-grid-view/emwplistpickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emwplists/:emwplist?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwplist.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistpickup-grid-view/emwplistpickup-grid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwplist.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistpickup-grid-view/emwplistpickup-grid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emwplists/:emwplist?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwplist.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistpickup-grid-view/emwplistpickup-grid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emwplists/:emwplist?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwplist.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistpickup-grid-view/emwplistpickup-grid-view.vue'),
    },
    {
        path: '/emwplists/:emwplist?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwplist.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistpickup-grid-view/emwplistpickup-grid-view.vue'),
    },
    {
        path: '/emeqlocations/:emeqlocation?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqlocation.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emeqlocations', parameterName: 'emeqlocation' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqlocationedit-view9-edit-mode/emeqlocationedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeqlctgsses/:emeqlctgss?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emeqlctgss.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqlctgsspickup-grid-view/emeqlctgsspickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemrin.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemrinedit-view9-edit-mode/emitemrinedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitemrins/:emitemrin?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemrin.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemrinedit-view9-edit-mode/emitemrinedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitemrins/:emitemrin?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemrin.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemrinedit-view9-edit-mode/emitemrinedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitemrins/:emitemrin?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemrin.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemrinedit-view9-edit-mode/emitemrinedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemrin.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemrinedit-view9-edit-mode/emitemrinedit-view9-edit-mode.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitemrins/:emitemrin?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemrin.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemrinedit-view9-edit-mode/emitemrinedit-view9-edit-mode.vue'),
    },
    {
        path: '/emitems/:emitem?/emitemrins/:emitemrin?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemrin.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemrinedit-view9-edit-mode/emitemrinedit-view9-edit-mode.vue'),
    },
    {
        path: '/emitemrins/:emitemrin?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemrin.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemrinedit-view9-edit-mode/emitemrinedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeqlcttires/:emeqlcttires?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emeqlcttires.views.pickupview.caption',
            parameters: [
                { pathName: 'emeqlcttires', parameterName: 'emeqlcttires' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqlcttirespickup-view/emeqlcttirespickup-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emwos/:emwo?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwos', parameterName: 'emwo' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwogrid-view/emwogrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emwos/:emwo?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwos', parameterName: 'emwo' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwogrid-view/emwogrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emwos/:emwo?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwos', parameterName: 'emwo' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwogrid-view/emwogrid-view.vue'),
    },
    {
        path: '/emwos/:emwo?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo.views.gridview.caption',
            parameters: [
                { pathName: 'emwos', parameterName: 'emwo' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwogrid-view/emwogrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emwo_ens/:emwo_en?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_en.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-enedit-view/emwo-enedit-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emwo_ens/:emwo_en?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_en.views.editview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-enedit-view/emwo-enedit-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emwo_ens/:emwo_en?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_en.views.editview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-enedit-view/emwo-enedit-view.vue'),
    },
    {
        path: '/emwo_ens/:emwo_en?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_en.views.editview.caption',
            parameters: [
                { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-enedit-view/emwo-enedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/dashboardview9/:dashboardview9?',
        meta: {
            caption: 'entities.emequip.views.dashboardview9.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'dashboardview9', parameterName: 'dashboardview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emequipdashboard-view9/emequipdashboard-view9.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/dashboardview9/:dashboardview9?',
        meta: {
            caption: 'entities.emequip.views.dashboardview9.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'dashboardview9', parameterName: 'dashboardview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emequipdashboard-view9/emequipdashboard-view9.vue'),
    },
    {
        path: '/emequips/:emequip?/dashboardview9/:dashboardview9?',
        meta: {
            caption: 'entities.emequip.views.dashboardview9.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'dashboardview9', parameterName: 'dashboardview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emequipdashboard-view9/emequipdashboard-view9.vue'),
    },
    {
        path: '/empos/:empo?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.empo.views.pickupview.caption',
            parameters: [
                { pathName: 'empos', parameterName: 'empo' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empopickup-view/empopickup-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emrfode.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfodepickup-grid-view/emrfodepickup-grid-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfomos/:emrfomo?/emrfoacs/:emrfoac?/gridview/:gridview?',
        meta: {
            caption: 'entities.emrfoac.views.gridview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfoacgrid-view/emrfoacgrid-view.vue'),
    },
    {
        path: '/emrfomos/:emrfomo?/emrfoacs/:emrfoac?/gridview/:gridview?',
        meta: {
            caption: 'entities.emrfoac.views.gridview.caption',
            parameters: [
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfoacgrid-view/emrfoacgrid-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfoacs/:emrfoac?/gridview/:gridview?',
        meta: {
            caption: 'entities.emrfoac.views.gridview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfoacgrid-view/emrfoacgrid-view.vue'),
    },
    {
        path: '/emrfoacs/:emrfoac?/gridview/:gridview?',
        meta: {
            caption: 'entities.emrfoac.views.gridview.caption',
            parameters: [
                { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfoacgrid-view/emrfoacgrid-view.vue'),
    },
    {
        path: '/emoutputs/:emoutput?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emoutput.views.pickupview.caption',
            parameters: [
                { pathName: 'emoutputs', parameterName: 'emoutput' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emoutputpickup-view/emoutputpickup-view.vue'),
    },
    {
        path: '/empos/:empo?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.empo.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'empos', parameterName: 'empo' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empoedit-view9-edit-mode/empoedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeqlctgsses/:emeqlctgss?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqlctgss.views.gridview.caption',
            parameters: [
                { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqlctgssgrid-view/emeqlctgssgrid-view.vue'),
    },
    {
        path: '/emassets/:emasset?/emassetclears/:emassetclear?/editview_908/:editview_908?',
        meta: {
            caption: 'entities.emassetclear.views.editview_908.caption',
            parameters: [
                { pathName: 'emassets', parameterName: 'emasset' },
                { pathName: 'emassetclears', parameterName: 'emassetclear' },
                { pathName: 'editview_908', parameterName: 'editview_908' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-as/emassetclearedit-view-908/emassetclearedit-view-908.vue'),
    },
    {
        path: '/emassetclears/:emassetclear?/editview_908/:editview_908?',
        meta: {
            caption: 'entities.emassetclear.views.editview_908.caption',
            parameters: [
                { pathName: 'emassetclears', parameterName: 'emassetclear' },
                { pathName: 'editview_908', parameterName: 'editview_908' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-as/emassetclearedit-view-908/emassetclearedit-view-908.vue'),
    },
    {
        path: '/emassetclasses/:emassetclass?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emassetclass.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emassetclasses', parameterName: 'emassetclass' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-as/emassetclasspickup-grid-view/emassetclasspickup-grid-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfomos/:emrfomo?/editview/:editview?',
        meta: {
            caption: 'entities.emrfomo.views.editview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfomoedit-view/emrfomoedit-view.vue'),
    },
    {
        path: '/emrfomos/:emrfomo?/editview/:editview?',
        meta: {
            caption: 'entities.emrfomo.views.editview.caption',
            parameters: [
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfomoedit-view/emrfomoedit-view.vue'),
    },
    {
        path: '/emwooris/:emwoori?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwoori.views.pickupview.caption',
            parameters: [
                { pathName: 'emwooris', parameterName: 'emwoori' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwooripickup-view/emwooripickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emstore.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstorepickup-grid-view/emstorepickup-grid-view.vue'),
    },
    {
        path: '/emitemtypes/:emitemtype?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emitemtype.views.treeexpview.caption',
            parameters: [
                { pathName: 'emitemtypes', parameterName: 'emitemtype' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtypetree-exp-view/emitemtypetree-exp-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitem.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemgrid-view/emitemgrid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitem.views.gridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemgrid-view/emitemgrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitem.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemgrid-view/emitemgrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitem.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemgrid-view/emitemgrid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitem.views.gridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemgrid-view/emitemgrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitem.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemgrid-view/emitemgrid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitem.views.gridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemgrid-view/emitemgrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqsetups/:emeqsetup?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqsetup.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqsetupgrid-view/emeqsetupgrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqsetups/:emeqsetup?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqsetup.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqsetupgrid-view/emeqsetupgrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqsetups/:emeqsetup?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqsetup.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqsetupgrid-view/emeqsetupgrid-view.vue'),
    },
    {
        path: '/emeqsetups/:emeqsetup?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqsetup.views.gridview.caption',
            parameters: [
                { pathName: 'emeqsetups', parameterName: 'emeqsetup' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqsetupgrid-view/emeqsetupgrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emen.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenedit-view9-edit-mode/emenedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emen/:emen?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emen.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenedit-view9-edit-mode/emenedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emen/:emen?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emen.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenedit-view9-edit-mode/emenedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emen/:emen?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emen.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenedit-view9-edit-mode/emenedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emen.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenedit-view9-edit-mode/emenedit-view9-edit-mode.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emen/:emen?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emen.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenedit-view9-edit-mode/emenedit-view9-edit-mode.vue'),
    },
    {
        path: '/emitems/:emitem?/emen/:emen?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emen.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenedit-view9-edit-mode/emenedit-view9-edit-mode.vue'),
    },
    {
        path: '/emen/:emen?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emen.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenedit-view9-edit-mode/emenedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwplist.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistgrid-view/emwplistgrid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emwplists/:emwplist?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwplist.views.gridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistgrid-view/emwplistgrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emwplists/:emwplist?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwplist.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistgrid-view/emwplistgrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emwplists/:emwplist?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwplist.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistgrid-view/emwplistgrid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwplist.views.gridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistgrid-view/emwplistgrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emwplists/:emwplist?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwplist.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistgrid-view/emwplistgrid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emwplists/:emwplist?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwplist.views.gridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistgrid-view/emwplistgrid-view.vue'),
    },
    {
        path: '/emwplists/:emwplist?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwplist.views.gridview.caption',
            parameters: [
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistgrid-view/emwplistgrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/empurplans/:empurplan?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'empurplans', parameterName: 'empurplan' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/emitempuses/:emitempuse?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupview.caption',
            parameters: [
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-view/emitempusepickup-view.vue'),
    },
    {
        path: '/emobjects/:emobject?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emobject.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emobjects', parameterName: 'emobject' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emobjectpickup-grid-view/emobjectpickup-grid-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfomos/:emrfomo?/emrfoacs/:emrfoac?/editview/:editview?',
        meta: {
            caption: 'entities.emrfoac.views.editview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfoacedit-view/emrfoacedit-view.vue'),
    },
    {
        path: '/emrfomos/:emrfomo?/emrfoacs/:emrfoac?/editview/:editview?',
        meta: {
            caption: 'entities.emrfoac.views.editview.caption',
            parameters: [
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfoacedit-view/emrfoacedit-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfoacs/:emrfoac?/editview/:editview?',
        meta: {
            caption: 'entities.emrfoac.views.editview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfoacedit-view/emrfoacedit-view.vue'),
    },
    {
        path: '/emrfoacs/:emrfoac?/editview/:editview?',
        meta: {
            caption: 'entities.emrfoac.views.editview.caption',
            parameters: [
                { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfoacedit-view/emrfoacedit-view.vue'),
    },
    {
        path: '/emassets/:emasset?/editview9/:editview9?',
        meta: {
            caption: 'entities.emasset.views.editview9.caption',
            parameters: [
                { pathName: 'emassets', parameterName: 'emasset' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emassetedit-view9/emassetedit-view9.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfomos/:emrfomo?/emrfocas/:emrfoca?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emrfoca.views.pickupview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'emrfocas', parameterName: 'emrfoca' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfocapickup-view/emrfocapickup-view.vue'),
    },
    {
        path: '/emrfomos/:emrfomo?/emrfocas/:emrfoca?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emrfoca.views.pickupview.caption',
            parameters: [
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'emrfocas', parameterName: 'emrfoca' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfocapickup-view/emrfocapickup-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfocas/:emrfoca?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emrfoca.views.pickupview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfocas', parameterName: 'emrfoca' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfocapickup-view/emrfocapickup-view.vue'),
    },
    {
        path: '/emrfocas/:emrfoca?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emrfoca.views.pickupview.caption',
            parameters: [
                { pathName: 'emrfocas', parameterName: 'emrfoca' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfocapickup-view/emrfocapickup-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emwo_ens/:emwo_en?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_en.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-engrid-view/emwo-engrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emwo_ens/:emwo_en?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_en.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-engrid-view/emwo-engrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emwo_ens/:emwo_en?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_en.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-engrid-view/emwo-engrid-view.vue'),
    },
    {
        path: '/emwo_ens/:emwo_en?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_en.views.gridview.caption',
            parameters: [
                { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-engrid-view/emwo-engrid-view.vue'),
    },
    {
        path: '/emitemtypes/:emitemtype?/editview_itemtype_editmode/:editview_itemtype_editmode?',
        meta: {
            caption: 'entities.emitemtype.views.editview_itemtype_editmode.caption',
            parameters: [
                { pathName: 'emitemtypes', parameterName: 'emitemtype' },
                { pathName: 'editview_itemtype_editmode', parameterName: 'editview_itemtype_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemtypeedit-view-itemtype-edit-mode/emitemtypeedit-view-itemtype-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
    },
    {
        path: '/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
    },
    {
        path: '/emeqspares/:emeqspare?/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emeqspares', parameterName: 'emeqspare' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
    },
    {
        path: '/emeqsparedetails/:emeqsparedetail?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emeqsparedetail.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparedetailedit-view-edit-mode/emeqsparedetailedit-view-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.empodetail.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.empodetail.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.empodetail.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.empodetail.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.empodetail.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.empodetail.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
    },
    {
        path: '/empos/:empo?/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.empodetail.views.pickupgridview.caption',
            parameters: [
                { pathName: 'empos', parameterName: 'empo' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.empodetail.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
    },
    {
        path: '/empodetails/:empodetail?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.empodetail.views.pickupgridview.caption',
            parameters: [
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-grid-view/empodetailpickup-grid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.pfteam.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/pfteamedit-view-edit-mode/pfteamedit-view-edit-mode.vue'),
    },
    {
        path: '/emassets/:emasset?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emasset.views.tabexpview.caption',
            parameters: [
                { pathName: 'emassets', parameterName: 'emasset' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emassettab-exp-view/emassettab-exp-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfomos/:emrfomo?/gridview/:gridview?',
        meta: {
            caption: 'entities.emrfomo.views.gridview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfomogrid-view/emrfomogrid-view.vue'),
    },
    {
        path: '/emrfomos/:emrfomo?/gridview/:gridview?',
        meta: {
            caption: 'entities.emrfomo.views.gridview.caption',
            parameters: [
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfomogrid-view/emrfomogrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emeqtype.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqtypepickup-grid-view/emeqtypepickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emstorepart.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstorepartpickup-view/emstorepartpickup-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emstorepart.views.pickupview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstorepartpickup-view/emstorepartpickup-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqdebugs/:emeqdebug?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqdebug.views.editview9.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqdebugedit-view9/emeqdebugedit-view9.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqdebugs/:emeqdebug?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqdebug.views.editview9.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqdebugedit-view9/emeqdebugedit-view9.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqdebugs/:emeqdebug?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqdebug.views.editview9.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqdebugedit-view9/emeqdebugedit-view9.vue'),
    },
    {
        path: '/emeqdebugs/:emeqdebug?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqdebug.views.editview9.caption',
            parameters: [
                { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqdebugedit-view9/emeqdebugedit-view9.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/editview/:editview?',
        meta: {
            caption: 'entities.emrfode.views.editview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfodeedit-view/emrfodeedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emwo_oscs/:emwo_osc?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_osc.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-oscgrid-view/emwo-oscgrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emwo_oscs/:emwo_osc?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_osc.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-oscgrid-view/emwo-oscgrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emwo_oscs/:emwo_osc?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_osc.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-oscgrid-view/emwo-oscgrid-view.vue'),
    },
    {
        path: '/emwo_oscs/:emwo_osc?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_osc.views.gridview.caption',
            parameters: [
                { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-oscgrid-view/emwo-oscgrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqmaintances/:emeqmaintance?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqmaintance.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqmaintancegrid-view/emeqmaintancegrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqmaintances/:emeqmaintance?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqmaintance.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqmaintancegrid-view/emeqmaintancegrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqmaintances/:emeqmaintance?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqmaintance.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqmaintancegrid-view/emeqmaintancegrid-view.vue'),
    },
    {
        path: '/emeqmaintances/:emeqmaintance?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqmaintance.views.gridview.caption',
            parameters: [
                { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqmaintancegrid-view/emeqmaintancegrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/editview_9836/:editview_9836?',
        meta: {
            caption: 'entities.emstorepart.views.editview_9836.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'editview_9836', parameterName: 'editview_9836' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstorepartedit-view-9836/emstorepartedit-view-9836.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/editview_9836/:editview_9836?',
        meta: {
            caption: 'entities.emstorepart.views.editview_9836.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'editview_9836', parameterName: 'editview_9836' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstorepartedit-view-9836/emstorepartedit-view-9836.vue'),
    },
    {
        path: '/emeqlocations/:emeqlocation?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emeqlocation.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emeqlocations', parameterName: 'emeqlocation' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqlocationpickup-grid-view/emeqlocationpickup-grid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emwo_ens/:emwo_en?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_en.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-enedit-view-edit-mode/emwo-enedit-view-edit-mode.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emwo_ens/:emwo_en?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_en.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-enedit-view-edit-mode/emwo-enedit-view-edit-mode.vue'),
    },
    {
        path: '/emequips/:emequip?/emwo_ens/:emwo_en?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_en.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-enedit-view-edit-mode/emwo-enedit-view-edit-mode.vue'),
    },
    {
        path: '/emwo_ens/:emwo_en?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_en.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emwo_ens', parameterName: 'emwo_en' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-enedit-view-edit-mode/emwo-enedit-view-edit-mode.vue'),
    },
    {
        path: '/pfcontracts/:pfcontract?/editview9/:editview9?',
        meta: {
            caption: 'entities.pfcontract.views.editview9.caption',
            parameters: [
                { pathName: 'pfcontracts', parameterName: 'pfcontract' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-pf/pfcontractedit-view9/pfcontractedit-view9.vue'),
    },
    {
        path: '/emservices/:emservice?/editview9/:editview9?',
        meta: {
            caption: 'entities.emservice.views.editview9.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emserviceedit-view9/emserviceedit-view9.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.pfdept.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-pf/pfdeptpickup-grid-view/pfdeptpickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emstorepart.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstorepartpickup-grid-view/emstorepartpickup-grid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emstorepart.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstorepartpickup-grid-view/emstorepartpickup-grid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emwo_inners/:emwo_inner?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_inner.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-innergrid-view/emwo-innergrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emwo_inners/:emwo_inner?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_inner.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-innergrid-view/emwo-innergrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emwo_inners/:emwo_inner?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_inner.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-innergrid-view/emwo-innergrid-view.vue'),
    },
    {
        path: '/emwo_inners/:emwo_inner?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_inner.views.gridview.caption',
            parameters: [
                { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-innergrid-view/emwo-innergrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emequip.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emequippickup-grid-view/emequippickup-grid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emequip.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emequippickup-grid-view/emequippickup-grid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emequip.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emequippickup-grid-view/emequippickup-grid-view.vue'),
    },
    {
        path: '/emitemtypes/:emitemtype?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitemtype.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emitemtypes', parameterName: 'emitemtype' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemtypepickup-grid-view/emitemtypepickup-grid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqchecks/:emeqcheck?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqcheck.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqcheckgrid-view/emeqcheckgrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqchecks/:emeqcheck?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqcheck.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqcheckgrid-view/emeqcheckgrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqchecks/:emeqcheck?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqcheck.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqcheckgrid-view/emeqcheckgrid-view.vue'),
    },
    {
        path: '/emeqchecks/:emeqcheck?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqcheck.views.gridview.caption',
            parameters: [
                { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqcheckgrid-view/emeqcheckgrid-view.vue'),
    },
    {
        path: '/emeqspares/:emeqspare?/emeqsparemaps/:emeqsparemap?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emeqsparemap.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emeqspares', parameterName: 'emeqspare' },
                { pathName: 'emeqsparemaps', parameterName: 'emeqsparemap' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparemapedit-view-edit-mode/emeqsparemapedit-view-edit-mode.vue'),
    },
    {
        path: '/emeqsparemaps/:emeqsparemap?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emeqsparemap.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emeqsparemaps', parameterName: 'emeqsparemap' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparemapedit-view-edit-mode/emeqsparemapedit-view-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emstocks/:emstock?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emstock.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emstocks/:emstock?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emstock.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emstocks/:emstock?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emstock.views.pickupview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emstocks/:emstock?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emstock.views.pickupview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emstocks/:emstock?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emstock.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emstocks/:emstock?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emstock.views.pickupview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emstocks/:emstock?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emstock.views.pickupview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstocks/:emstock?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emstock.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emstocks/:emstock?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emstock.views.pickupview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emstocks/:emstock?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emstock.views.pickupview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
    },
    {
        path: '/emstocks/:emstock?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emstock.views.pickupview.caption',
            parameters: [
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-view/emstockpickup-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emwo_dps/:emwo_dp?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_dp.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpedit-view/emwo-dpedit-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emwo_dps/:emwo_dp?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_dp.views.editview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpedit-view/emwo-dpedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emwo_dps/:emwo_dp?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_dp.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpedit-view/emwo-dpedit-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emwo_dps/:emwo_dp?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_dp.views.editview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpedit-view/emwo-dpedit-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emwo_dps/:emwo_dp?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_dp.views.editview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpedit-view/emwo-dpedit-view.vue'),
    },
    {
        path: '/emwo_dps/:emwo_dp?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_dp.views.editview.caption',
            parameters: [
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpedit-view/emwo-dpedit-view.vue'),
    },
    {
        path: '/emitempls/:emitempl?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempl.views.gridview.caption',
            parameters: [
                { pathName: 'emitempls', parameterName: 'emitempl' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemplgrid-view/emitemplgrid-view.vue'),
    },
    {
        path: '/emoutputs/:emoutput?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emoutput.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emoutputs', parameterName: 'emoutput' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emoutputpickup-grid-view/emoutputpickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9/:editview9?',
        meta: {
            caption: 'entities.emwplistcost.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostedit-view9/emwplistcostedit-view9.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9/:editview9?',
        meta: {
            caption: 'entities.emwplistcost.views.editview9.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostedit-view9/emwplistcostedit-view9.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9/:editview9?',
        meta: {
            caption: 'entities.emwplistcost.views.editview9.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostedit-view9/emwplistcostedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9/:editview9?',
        meta: {
            caption: 'entities.emwplistcost.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostedit-view9/emwplistcostedit-view9.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9/:editview9?',
        meta: {
            caption: 'entities.emwplistcost.views.editview9.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostedit-view9/emwplistcostedit-view9.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9/:editview9?',
        meta: {
            caption: 'entities.emwplistcost.views.editview9.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostedit-view9/emwplistcostedit-view9.vue'),
    },
    {
        path: '/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9/:editview9?',
        meta: {
            caption: 'entities.emwplistcost.views.editview9.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostedit-view9/emwplistcostedit-view9.vue'),
    },
    {
        path: '/emwplistcosts/:emwplistcost?/editview9/:editview9?',
        meta: {
            caption: 'entities.emwplistcost.views.editview9.caption',
            parameters: [
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostedit-view9/emwplistcostedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwplistcost.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostpickup-grid-view/emwplistcostpickup-grid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwplistcost.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostpickup-grid-view/emwplistcostpickup-grid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwplistcost.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostpickup-grid-view/emwplistcostpickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwplistcost.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostpickup-grid-view/emwplistcostpickup-grid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwplistcost.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostpickup-grid-view/emwplistcostpickup-grid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwplistcost.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostpickup-grid-view/emwplistcostpickup-grid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emwplistcosts/:emwplistcost?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwplistcost.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostpickup-grid-view/emwplistcostpickup-grid-view.vue'),
    },
    {
        path: '/emwplistcosts/:emwplistcost?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwplistcost.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistcostpickup-grid-view/emwplistcostpickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emstocks/:emstock?/gridview/:gridview?',
        meta: {
            caption: 'entities.emstock.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emstocks/:emstock?/gridview/:gridview?',
        meta: {
            caption: 'entities.emstock.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emstocks/:emstock?/gridview/:gridview?',
        meta: {
            caption: 'entities.emstock.views.gridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emstocks/:emstock?/gridview/:gridview?',
        meta: {
            caption: 'entities.emstock.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emstocks/:emstock?/gridview/:gridview?',
        meta: {
            caption: 'entities.emstock.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emstocks/:emstock?/gridview/:gridview?',
        meta: {
            caption: 'entities.emstock.views.gridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emstocks/:emstock?/gridview/:gridview?',
        meta: {
            caption: 'entities.emstock.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstocks/:emstock?/gridview/:gridview?',
        meta: {
            caption: 'entities.emstock.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emstocks/:emstock?/gridview/:gridview?',
        meta: {
            caption: 'entities.emstock.views.gridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emstocks/:emstock?/gridview/:gridview?',
        meta: {
            caption: 'entities.emstock.views.gridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
    },
    {
        path: '/emstocks/:emstock?/gridview/:gridview?',
        meta: {
            caption: 'entities.emstock.views.gridview.caption',
            parameters: [
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockgrid-view/emstockgrid-view.vue'),
    },
    {
        path: '/emitemtypes/:emitemtype?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitemtype.views.pickupview.caption',
            parameters: [
                { pathName: 'emitemtypes', parameterName: 'emitemtype' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemtypepickup-view/emitemtypepickup-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqmaintances/:emeqmaintance?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqmaintance.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqmaintanceedit-view9-edit-mode/emeqmaintanceedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqmaintances/:emeqmaintance?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqmaintance.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqmaintanceedit-view9-edit-mode/emeqmaintanceedit-view9-edit-mode.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqmaintances/:emeqmaintance?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqmaintance.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqmaintanceedit-view9-edit-mode/emeqmaintanceedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeqmaintances/:emeqmaintance?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqmaintance.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqmaintanceedit-view9-edit-mode/emeqmaintanceedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplandetail.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplandetail.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplandetail.views.gridview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplandetail.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplandetail.views.gridview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplandetail.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplandetail.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplandetail.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplandetail.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplandetail.views.gridview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplandetail.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
    },
    {
        path: '/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplandetail.views.gridview.caption',
            parameters: [
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplandetail.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplandetail.views.gridview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
    },
    {
        path: '/emplans/:emplan?/emplandetails/:emplandetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplandetail.views.gridview.caption',
            parameters: [
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
    },
    {
        path: '/emplandetails/:emplandetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplandetail.views.gridview.caption',
            parameters: [
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailgrid-view/emplandetailgrid-view.vue'),
    },
    {
        path: '/emassets/:emasset?/gridview/:gridview?',
        meta: {
            caption: 'entities.emasset.views.gridview.caption',
            parameters: [
                { pathName: 'emassets', parameterName: 'emasset' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-as/emassetgrid-view/emassetgrid-view.vue'),
    },
    {
        path: '/emeqlctrhies/:emeqlctrhy?/editview/:editview?',
        meta: {
            caption: 'entities.emeqlctrhy.views.editview.caption',
            parameters: [
                { pathName: 'emeqlctrhies', parameterName: 'emeqlctrhy' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqlctrhyedit-view/emeqlctrhyedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emapplies/:emapply?/gridview/:gridview?',
        meta: {
            caption: 'entities.emapply.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emapplies', parameterName: 'emapply' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emapplygrid-view/emapplygrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emapplies/:emapply?/gridview/:gridview?',
        meta: {
            caption: 'entities.emapply.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emapplies', parameterName: 'emapply' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emapplygrid-view/emapplygrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emapplies/:emapply?/gridview/:gridview?',
        meta: {
            caption: 'entities.emapply.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emapplies', parameterName: 'emapply' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emapplygrid-view/emapplygrid-view.vue'),
    },
    {
        path: '/emapplies/:emapply?/gridview/:gridview?',
        meta: {
            caption: 'entities.emapply.views.gridview.caption',
            parameters: [
                { pathName: 'emapplies', parameterName: 'emapply' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emapplygrid-view/emapplygrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqahs/:emeqah?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqah.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqahs', parameterName: 'emeqah' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqahgrid-view/emeqahgrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqahs/:emeqah?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqah.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqahs', parameterName: 'emeqah' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqahgrid-view/emeqahgrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqahs/:emeqah?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqah.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqahs', parameterName: 'emeqah' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqahgrid-view/emeqahgrid-view.vue'),
    },
    {
        path: '/emeqahs/:emeqah?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqah.views.gridview.caption',
            parameters: [
                { pathName: 'emeqahs', parameterName: 'emeqah' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqahgrid-view/emeqahgrid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.pfunit.views.pickupview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-pf/pfunitpickup-view/pfunitpickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/editview/:editview?',
        meta: {
            caption: 'entities.emstore.views.editview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstoreedit-view/emstoreedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.pfteam.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-pf/pfteampickup-grid-view/pfteampickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emenconsum.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emenconsum.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emenconsum.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emenconsum.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emenconsum.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emenconsum.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emenconsum.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emenconsum.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
    },
    {
        path: '/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emenconsum.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emenconsum.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
    },
    {
        path: '/emequips/:emequip?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emenconsum.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
    },
    {
        path: '/emen/:emen?/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emenconsum.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
    },
    {
        path: '/emenconsums/:emenconsum?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emenconsum.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumedit-view9-edit-mode/emenconsumedit-view9-edit-mode.vue'),
    },
    {
        path: '/emserviceevls/:emserviceevl?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emserviceevl.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emserviceevls', parameterName: 'emserviceevl' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emserviceevledit-view9-edit-mode/emserviceevledit-view9-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/editview9/:editview9?',
        meta: {
            caption: 'entities.emen.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenedit-view9/emenedit-view9.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emen/:emen?/editview9/:editview9?',
        meta: {
            caption: 'entities.emen.views.editview9.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenedit-view9/emenedit-view9.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emen/:emen?/editview9/:editview9?',
        meta: {
            caption: 'entities.emen.views.editview9.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenedit-view9/emenedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emen/:emen?/editview9/:editview9?',
        meta: {
            caption: 'entities.emen.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenedit-view9/emenedit-view9.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/editview9/:editview9?',
        meta: {
            caption: 'entities.emen.views.editview9.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenedit-view9/emenedit-view9.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emen/:emen?/editview9/:editview9?',
        meta: {
            caption: 'entities.emen.views.editview9.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenedit-view9/emenedit-view9.vue'),
    },
    {
        path: '/emitems/:emitem?/emen/:emen?/editview9/:editview9?',
        meta: {
            caption: 'entities.emen.views.editview9.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenedit-view9/emenedit-view9.vue'),
    },
    {
        path: '/emen/:emen?/editview9/:editview9?',
        meta: {
            caption: 'entities.emen.views.editview9.caption',
            parameters: [
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenedit-view9/emenedit-view9.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emwo_inners/:emwo_inner?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_inner.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-inneredit-view-edit-mode/emwo-inneredit-view-edit-mode.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emwo_inners/:emwo_inner?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_inner.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-inneredit-view-edit-mode/emwo-inneredit-view-edit-mode.vue'),
    },
    {
        path: '/emequips/:emequip?/emwo_inners/:emwo_inner?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_inner.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-inneredit-view-edit-mode/emwo-inneredit-view-edit-mode.vue'),
    },
    {
        path: '/emwo_inners/:emwo_inner?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_inner.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emwo_inners', parameterName: 'emwo_inner' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-inneredit-view-edit-mode/emwo-inneredit-view-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emwplist.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistedit-view9-edit-mode/emwplistedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emwplists/:emwplist?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emwplist.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistedit-view9-edit-mode/emwplistedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emwplists/:emwplist?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emwplist.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistedit-view9-edit-mode/emwplistedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emwplists/:emwplist?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emwplist.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistedit-view9-edit-mode/emwplistedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emwplist.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistedit-view9-edit-mode/emwplistedit-view9-edit-mode.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emwplists/:emwplist?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emwplist.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistedit-view9-edit-mode/emwplistedit-view9-edit-mode.vue'),
    },
    {
        path: '/emitems/:emitem?/emwplists/:emwplist?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emwplist.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistedit-view9-edit-mode/emwplistedit-view9-edit-mode.vue'),
    },
    {
        path: '/emwplists/:emwplist?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emwplist.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistedit-view9-edit-mode/emwplistedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfcontracts/:pfcontract?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.pfcontract.views.pickupview.caption',
            parameters: [
                { pathName: 'pfcontracts', parameterName: 'pfcontract' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-pf/pfcontractpickup-view/pfcontractpickup-view.vue'),
    },
    {
        path: '/emservices/:emservice?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emservice.views.pickupview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emservicepickup-view/emservicepickup-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/optionview/:optionview?',
        meta: {
            caption: 'entities.emequip.views.optionview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emequipoption-view/emequipoption-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/optionview/:optionview?',
        meta: {
            caption: 'entities.emequip.views.optionview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emequipoption-view/emequipoption-view.vue'),
    },
    {
        path: '/emequips/:emequip?/optionview/:optionview?',
        meta: {
            caption: 'entities.emequip.views.optionview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emequipoption-view/emequipoption-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqtype.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqtypegrid-view/emeqtypegrid-view.vue'),
    },
    {
        path: '/emassetclasses/:emassetclass?/gridview/:gridview?',
        meta: {
            caption: 'entities.emassetclass.views.gridview.caption',
            parameters: [
                { pathName: 'emassetclasses', parameterName: 'emassetclass' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-as/emassetclassgrid-view/emassetclassgrid-view.vue'),
    },
    {
        path: '/emserviceevls/:emserviceevl?/editview9/:editview9?',
        meta: {
            caption: 'entities.emserviceevl.views.editview9.caption',
            parameters: [
                { pathName: 'emserviceevls', parameterName: 'emserviceevl' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emserviceevledit-view9/emserviceevledit-view9.vue'),
    },
    {
        path: '/emeqlctgsses/:emeqlctgss?/editview/:editview?',
        meta: {
            caption: 'entities.emeqlctgss.views.editview.caption',
            parameters: [
                { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqlctgssedit-view/emeqlctgssedit-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfomos/:emrfomo?/emrfocas/:emrfoca?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emrfoca.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'emrfocas', parameterName: 'emrfoca' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfocapickup-grid-view/emrfocapickup-grid-view.vue'),
    },
    {
        path: '/emrfomos/:emrfomo?/emrfocas/:emrfoca?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emrfoca.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'emrfocas', parameterName: 'emrfoca' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfocapickup-grid-view/emrfocapickup-grid-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfocas/:emrfoca?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emrfoca.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfocas', parameterName: 'emrfoca' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfocapickup-grid-view/emrfocapickup-grid-view.vue'),
    },
    {
        path: '/emrfocas/:emrfoca?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emrfoca.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emrfocas', parameterName: 'emrfoca' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfocapickup-grid-view/emrfocapickup-grid-view.vue'),
    },
    {
        path: '/emeqlctgsses/:emeqlctgss?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqlctgss.views.editview9.caption',
            parameters: [
                { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqlctgssedit-view9/emeqlctgssedit-view9.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfomos/:emrfomo?/emrfocas/:emrfoca?/editview/:editview?',
        meta: {
            caption: 'entities.emrfoca.views.editview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'emrfocas', parameterName: 'emrfoca' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfocaedit-view/emrfocaedit-view.vue'),
    },
    {
        path: '/emrfomos/:emrfomo?/emrfocas/:emrfoca?/editview/:editview?',
        meta: {
            caption: 'entities.emrfoca.views.editview.caption',
            parameters: [
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'emrfocas', parameterName: 'emrfoca' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfocaedit-view/emrfocaedit-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfocas/:emrfoca?/editview/:editview?',
        meta: {
            caption: 'entities.emrfoca.views.editview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfocas', parameterName: 'emrfoca' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfocaedit-view/emrfocaedit-view.vue'),
    },
    {
        path: '/emrfocas/:emrfoca?/editview/:editview?',
        meta: {
            caption: 'entities.emrfoca.views.editview.caption',
            parameters: [
                { pathName: 'emrfocas', parameterName: 'emrfoca' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfocaedit-view/emrfocaedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emplan.views.tabexpview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emplan.views.tabexpview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emplan.views.tabexpview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emplan.views.tabexpview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emplan.views.tabexpview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emplan.views.tabexpview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emplan.views.tabexpview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplans/:emplan?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emplan.views.tabexpview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplans/:emplan?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emplan.views.tabexpview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplans/:emplan?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emplan.views.tabexpview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplans/:emplan?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emplan.views.tabexpview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
    },
    {
        path: '/emplantempls/:emplantempl?/emplans/:emplan?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emplan.views.tabexpview.caption',
            parameters: [
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emplans/:emplan?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emplan.views.tabexpview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplans/:emplan?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emplan.views.tabexpview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
    },
    {
        path: '/emplans/:emplan?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emplan.views.tabexpview.caption',
            parameters: [
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplantab-exp-view/emplantab-exp-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfomos/:emrfomo?/emrfoacs/:emrfoac?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emrfoac.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfoacpickup-grid-view/emrfoacpickup-grid-view.vue'),
    },
    {
        path: '/emrfomos/:emrfomo?/emrfoacs/:emrfoac?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emrfoac.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfoacpickup-grid-view/emrfoacpickup-grid-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfoacs/:emrfoac?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emrfoac.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfoacpickup-grid-view/emrfoacpickup-grid-view.vue'),
    },
    {
        path: '/emrfoacs/:emrfoac?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emrfoac.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emrfoacs', parameterName: 'emrfoac' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfoacpickup-grid-view/emrfoacpickup-grid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/editview/:editview?',
        meta: {
            caption: 'entities.pfemp.views.editview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/pfempedit-view/pfempedit-view.vue'),
    },
    {
        path: '/emeqspares/:emeqspare?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emeqspare.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emeqspares', parameterName: 'emeqspare' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqspareedit-view-edit-mode/emeqspareedit-view-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.empodetail.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/empodetails/:empodetail?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.empodetail.views.pickupview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/empodetails/:empodetail?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.empodetail.views.pickupview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/empodetails/:empodetail?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.empodetail.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.empodetail.views.pickupview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/empodetails/:empodetail?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.empodetail.views.pickupview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
    },
    {
        path: '/empos/:empo?/empodetails/:empodetail?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.empodetail.views.pickupview.caption',
            parameters: [
                { pathName: 'empos', parameterName: 'empo' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
    },
    {
        path: '/emitems/:emitem?/empodetails/:empodetail?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.empodetail.views.pickupview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
    },
    {
        path: '/empodetails/:empodetail?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.empodetail.views.pickupview.caption',
            parameters: [
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailpickup-view/empodetailpickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
        meta: {
            caption: 'entities.emeqsparedetail.views.gridview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'gridview9', parameterName: 'gridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
        meta: {
            caption: 'entities.emeqsparedetail.views.gridview9.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'gridview9', parameterName: 'gridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
        meta: {
            caption: 'entities.emeqsparedetail.views.gridview9.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'gridview9', parameterName: 'gridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
        meta: {
            caption: 'entities.emeqsparedetail.views.gridview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'gridview9', parameterName: 'gridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
        meta: {
            caption: 'entities.emeqsparedetail.views.gridview9.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'gridview9', parameterName: 'gridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
        meta: {
            caption: 'entities.emeqsparedetail.views.gridview9.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'gridview9', parameterName: 'gridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
    },
    {
        path: '/emitems/:emitem?/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
        meta: {
            caption: 'entities.emeqsparedetail.views.gridview9.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'gridview9', parameterName: 'gridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
    },
    {
        path: '/emeqspares/:emeqspare?/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
        meta: {
            caption: 'entities.emeqsparedetail.views.gridview9.caption',
            parameters: [
                { pathName: 'emeqspares', parameterName: 'emeqspare' },
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'gridview9', parameterName: 'gridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
    },
    {
        path: '/emeqsparedetails/:emeqsparedetail?/gridview9/:gridview9?',
        meta: {
            caption: 'entities.emeqsparedetail.views.gridview9.caption',
            parameters: [
                { pathName: 'emeqsparedetails', parameterName: 'emeqsparedetail' },
                { pathName: 'gridview9', parameterName: 'gridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqsparedetailgrid-view9/emeqsparedetailgrid-view9.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplancdt.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplancdt.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplancdt.views.gridview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplancdt.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplancdt.views.gridview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplancdt.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplancdt.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplancdt.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplancdt.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplancdt.views.gridview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplancdt.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
    },
    {
        path: '/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplancdt.views.gridview.caption',
            parameters: [
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplancdt.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplancdt.views.gridview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
    },
    {
        path: '/emplans/:emplan?/emplancdts/:emplancdt?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplancdt.views.gridview.caption',
            parameters: [
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
    },
    {
        path: '/emplancdts/:emplancdt?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplancdt.views.gridview.caption',
            parameters: [
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtgrid-view/emplancdtgrid-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfomos/:emrfomo?/emrfocas/:emrfoca?/gridview/:gridview?',
        meta: {
            caption: 'entities.emrfoca.views.gridview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'emrfocas', parameterName: 'emrfoca' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfocagrid-view/emrfocagrid-view.vue'),
    },
    {
        path: '/emrfomos/:emrfomo?/emrfocas/:emrfoca?/gridview/:gridview?',
        meta: {
            caption: 'entities.emrfoca.views.gridview.caption',
            parameters: [
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'emrfocas', parameterName: 'emrfoca' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfocagrid-view/emrfocagrid-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfocas/:emrfoca?/gridview/:gridview?',
        meta: {
            caption: 'entities.emrfoca.views.gridview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfocas', parameterName: 'emrfoca' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfocagrid-view/emrfocagrid-view.vue'),
    },
    {
        path: '/emrfocas/:emrfoca?/gridview/:gridview?',
        meta: {
            caption: 'entities.emrfoca.views.gridview.caption',
            parameters: [
                { pathName: 'emrfocas', parameterName: 'emrfoca' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfocagrid-view/emrfocagrid-view.vue'),
    },
    {
        path: '/emeqlctfdjs/:emeqlctfdj?/editview/:editview?',
        meta: {
            caption: 'entities.emeqlctfdj.views.editview.caption',
            parameters: [
                { pathName: 'emeqlctfdjs', parameterName: 'emeqlctfdj' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqlctfdjedit-view/emeqlctfdjedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emapplies/:emapply?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emapply.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emapplies', parameterName: 'emapply' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emapplyedit-view-edit-mode/emapplyedit-view-edit-mode.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emapplies/:emapply?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emapply.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emapplies', parameterName: 'emapply' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emapplyedit-view-edit-mode/emapplyedit-view-edit-mode.vue'),
    },
    {
        path: '/emequips/:emequip?/emapplies/:emapply?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emapply.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emapplies', parameterName: 'emapply' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emapplyedit-view-edit-mode/emapplyedit-view-edit-mode.vue'),
    },
    {
        path: '/emapplies/:emapply?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emapply.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emapplies', parameterName: 'emapply' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emapplyedit-view-edit-mode/emapplyedit-view-edit-mode.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emeqtype.views.pickupview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqtypepickup-view/emeqtypepickup-view.vue'),
    },
    {
        path: '/emoutputs/:emoutput?/emoutputrcts/:emoutputrct?/editview/:editview?',
        meta: {
            caption: 'entities.emoutputrct.views.editview.caption',
            parameters: [
                { pathName: 'emoutputs', parameterName: 'emoutput' },
                { pathName: 'emoutputrcts', parameterName: 'emoutputrct' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emoutputrctedit-view/emoutputrctedit-view.vue'),
    },
    {
        path: '/emoutputrcts/:emoutputrct?/editview/:editview?',
        meta: {
            caption: 'entities.emoutputrct.views.editview.caption',
            parameters: [
                { pathName: 'emoutputrcts', parameterName: 'emoutputrct' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emoutputrctedit-view/emoutputrctedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/gridview/:gridview?',
        meta: {
            caption: 'entities.emequip.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emequipgrid-view/emequipgrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/gridview/:gridview?',
        meta: {
            caption: 'entities.emequip.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emequipgrid-view/emequipgrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/gridview/:gridview?',
        meta: {
            caption: 'entities.emequip.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emequipgrid-view/emequipgrid-view.vue'),
    },
    {
        path: '/emoutputs/:emoutput?/emoutputrcts/:emoutputrct?/editview9/:editview9?',
        meta: {
            caption: 'entities.emoutputrct.views.editview9.caption',
            parameters: [
                { pathName: 'emoutputs', parameterName: 'emoutput' },
                { pathName: 'emoutputrcts', parameterName: 'emoutputrct' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emoutputrctedit-view9/emoutputrctedit-view9.vue'),
    },
    {
        path: '/emoutputrcts/:emoutputrct?/editview9/:editview9?',
        meta: {
            caption: 'entities.emoutputrct.views.editview9.caption',
            parameters: [
                { pathName: 'emoutputrcts', parameterName: 'emoutputrct' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emoutputrctedit-view9/emoutputrctedit-view9.vue'),
    },
    {
        path: '/emwooris/:emwoori?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emwoori.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emwooris', parameterName: 'emwoori' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwooripickup-grid-view/emwooripickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwplist.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistpickup-view/emwplistpickup-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emwplists/:emwplist?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwplist.views.pickupview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistpickup-view/emwplistpickup-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emwplists/:emwplist?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwplist.views.pickupview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistpickup-view/emwplistpickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emwplists/:emwplist?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwplist.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistpickup-view/emwplistpickup-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emwplists/:emwplist?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwplist.views.pickupview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistpickup-view/emwplistpickup-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emwplists/:emwplist?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwplist.views.pickupview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistpickup-view/emwplistpickup-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emwplists/:emwplist?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwplist.views.pickupview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistpickup-view/emwplistpickup-view.vue'),
    },
    {
        path: '/emwplists/:emwplist?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwplist.views.pickupview.caption',
            parameters: [
                { pathName: 'emwplists', parameterName: 'emwplist' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwplistpickup-view/emwplistpickup-view.vue'),
    },
    {
        path: '/emitemtypes/:emitemtype?/editview/:editview?',
        meta: {
            caption: 'entities.emitemtype.views.editview.caption',
            parameters: [
                { pathName: 'emitemtypes', parameterName: 'emitemtype' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemtypeedit-view/emitemtypeedit-view.vue'),
    },
    {
        path: '/empurplans/:empurplan?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.empurplan.views.pickupgridview.caption',
            parameters: [
                { pathName: 'empurplans', parameterName: 'empurplan' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empurplanpickup-grid-view/empurplanpickup-grid-view.vue'),
    },
    {
        path: '/emitemtypes/:emitemtype?/itemtreeexpview/:itemtreeexpview?',
        meta: {
            caption: 'entities.emitemtype.views.itemtreeexpview.caption',
            parameters: [
                { pathName: 'emitemtypes', parameterName: 'emitemtype' },
                { pathName: 'itemtreeexpview', parameterName: 'itemtreeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtypeitem-tree-exp-view/emitemtypeitem-tree-exp-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/empurplans/:empurplan?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'empurplans', parameterName: 'empurplan' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/emitempuses/:emitempuse?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitempuse.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempusepickup-grid-view/emitempusepickup-grid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emwo_oscs/:emwo_osc?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_osc.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-oscedit-view/emwo-oscedit-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emwo_oscs/:emwo_osc?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_osc.views.editview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-oscedit-view/emwo-oscedit-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emwo_oscs/:emwo_osc?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_osc.views.editview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-oscedit-view/emwo-oscedit-view.vue'),
    },
    {
        path: '/emwo_oscs/:emwo_osc?/editview/:editview?',
        meta: {
            caption: 'entities.emwo_osc.views.editview.caption',
            parameters: [
                { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-oscedit-view/emwo-oscedit-view.vue'),
    },
    {
        path: '/emoutputs/:emoutput?/editview/:editview?',
        meta: {
            caption: 'entities.emoutput.views.editview.caption',
            parameters: [
                { pathName: 'emoutputs', parameterName: 'emoutput' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emoutputedit-view/emoutputedit-view.vue'),
    },
    {
        path: '/emeqlctgsses/:emeqlctgss?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emeqlctgss.views.pickupview.caption',
            parameters: [
                { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqlctgsspickup-view/emeqlctgsspickup-view.vue'),
    },
    {
        path: '/emitemtypes/:emitemtype?/editview_itemtype/:editview_itemtype?',
        meta: {
            caption: 'entities.emitemtype.views.editview_itemtype.caption',
            parameters: [
                { pathName: 'emitemtypes', parameterName: 'emitemtype' },
                { pathName: 'editview_itemtype', parameterName: 'editview_itemtype' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemtypeedit-view-itemtype/emitemtypeedit-view-itemtype.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqahs/:emeqah?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emeqah.views.treeexpview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqahs', parameterName: 'emeqah' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqahtree-exp-view/emeqahtree-exp-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqahs/:emeqah?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emeqah.views.treeexpview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqahs', parameterName: 'emeqah' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqahtree-exp-view/emeqahtree-exp-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqahs/:emeqah?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emeqah.views.treeexpview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqahs', parameterName: 'emeqah' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqahtree-exp-view/emeqahtree-exp-view.vue'),
    },
    {
        path: '/emeqahs/:emeqah?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emeqah.views.treeexpview.caption',
            parameters: [
                { pathName: 'emeqahs', parameterName: 'emeqah' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqahtree-exp-view/emeqahtree-exp-view.vue'),
    },
    {
        path: '/emservices/:emservice?/gridview/:gridview?',
        meta: {
            caption: 'entities.emservice.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emservicegrid-view/emservicegrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emdrwgs/:emdrwg?/gridview/:gridview?',
        meta: {
            caption: 'entities.emdrwg.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emdrwgs', parameterName: 'emdrwg' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emdrwggrid-view/emdrwggrid-view.vue'),
    },
    {
        path: '/emdrwgs/:emdrwg?/gridview/:gridview?',
        meta: {
            caption: 'entities.emdrwg.views.gridview.caption',
            parameters: [
                { pathName: 'emdrwgs', parameterName: 'emdrwg' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emdrwggrid-view/emdrwggrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqchecks/:emeqcheck?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqcheck.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqcheckedit-view9-edit-mode/emeqcheckedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqchecks/:emeqcheck?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqcheck.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqcheckedit-view9-edit-mode/emeqcheckedit-view9-edit-mode.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqchecks/:emeqcheck?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqcheck.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqcheckedit-view9-edit-mode/emeqcheckedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeqchecks/:emeqcheck?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqcheck.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emeqchecks', parameterName: 'emeqcheck' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqcheckedit-view9-edit-mode/emeqcheckedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emwplistcost.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistcostedit-view9-edit-mode/emwplistcostedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emwplistcost.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistcostedit-view9-edit-mode/emwplistcostedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emwplistcost.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistcostedit-view9-edit-mode/emwplistcostedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emwplistcost.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistcostedit-view9-edit-mode/emwplistcostedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emwplistcost.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistcostedit-view9-edit-mode/emwplistcostedit-view9-edit-mode.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emwplistcost.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistcostedit-view9-edit-mode/emwplistcostedit-view9-edit-mode.vue'),
    },
    {
        path: '/emitems/:emitem?/emwplistcosts/:emwplistcost?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emwplistcost.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistcostedit-view9-edit-mode/emwplistcostedit-view9-edit-mode.vue'),
    },
    {
        path: '/emwplistcosts/:emwplistcost?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emwplistcost.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistcostedit-view9-edit-mode/emwplistcostedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfcontracts/:pfcontract?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.pfcontract.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfcontracts', parameterName: 'pfcontract' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-pf/pfcontractpickup-grid-view/pfcontractpickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emen.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenpickup-view/emenpickup-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emen/:emen?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emen.views.pickupview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenpickup-view/emenpickup-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emen/:emen?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emen.views.pickupview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenpickup-view/emenpickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emen/:emen?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emen.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenpickup-view/emenpickup-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emen.views.pickupview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenpickup-view/emenpickup-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emen/:emen?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emen.views.pickupview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenpickup-view/emenpickup-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emen/:emen?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emen.views.pickupview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenpickup-view/emenpickup-view.vue'),
    },
    {
        path: '/emen/:emen?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emen.views.pickupview.caption',
            parameters: [
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenpickup-view/emenpickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwplistcost.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistcostgrid-view/emwplistcostgrid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emwplistcosts/:emwplistcost?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwplistcost.views.gridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistcostgrid-view/emwplistcostgrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emwplistcosts/:emwplistcost?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwplistcost.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistcostgrid-view/emwplistcostgrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emwplistcosts/:emwplistcost?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwplistcost.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistcostgrid-view/emwplistcostgrid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emwplistcosts/:emwplistcost?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwplistcost.views.gridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistcostgrid-view/emwplistcostgrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emwplistcosts/:emwplistcost?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwplistcost.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistcostgrid-view/emwplistcostgrid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emwplistcosts/:emwplistcost?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwplistcost.views.gridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistcostgrid-view/emwplistcostgrid-view.vue'),
    },
    {
        path: '/emwplistcosts/:emwplistcost?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwplistcost.views.gridview.caption',
            parameters: [
                { pathName: 'emwplistcosts', parameterName: 'emwplistcost' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emwplistcostgrid-view/emwplistcostgrid-view.vue'),
    },
    {
        path: '/emitemtypes/:emitemtype?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emitemtype.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emitemtypes', parameterName: 'emitemtype' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemtypeedit-view-edit-mode/emitemtypeedit-view-edit-mode.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emequip.views.pickupview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emequippickup-view/emequippickup-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emequip.views.pickupview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emequippickup-view/emequippickup-view.vue'),
    },
    {
        path: '/emequips/:emequip?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emequip.views.pickupview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emequippickup-view/emequippickup-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emwo_dps/:emwo_dp?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_dp.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpgrid-view/emwo-dpgrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emwo_dps/:emwo_dp?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_dp.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpgrid-view/emwo-dpgrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emwo_dps/:emwo_dp?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_dp.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpgrid-view/emwo-dpgrid-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emwo_dps/:emwo_dp?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_dp.views.gridview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpgrid-view/emwo-dpgrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emwo_dps/:emwo_dp?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_dp.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpgrid-view/emwo-dpgrid-view.vue'),
    },
    {
        path: '/emwo_dps/:emwo_dp?/gridview/:gridview?',
        meta: {
            caption: 'entities.emwo_dp.views.gridview.caption',
            parameters: [
                { pathName: 'emwo_dps', parameterName: 'emwo_dp' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-dpgrid-view/emwo-dpgrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emdrwgs/:emdrwg?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emdrwg.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emdrwgs', parameterName: 'emdrwg' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emdrwgedit-view-edit-mode/emdrwgedit-view-edit-mode.vue'),
    },
    {
        path: '/emdrwgs/:emdrwg?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emdrwg.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emdrwgs', parameterName: 'emdrwg' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emdrwgedit-view-edit-mode/emdrwgedit-view-edit-mode.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emeqtype.views.treeexpview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqtypetree-exp-view/emeqtypetree-exp-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emstock.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emstock.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emstock.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emstock.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emstock.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emstock.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emstock.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emstock.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emstock.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emstocks/:emstock?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emstock.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
    },
    {
        path: '/emstocks/:emstock?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emstock.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstockpickup-grid-view/emstockpickup-grid-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/emrfomos/:emrfomo?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emrfomo.views.pickupview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfomopickup-view/emrfomopickup-view.vue'),
    },
    {
        path: '/emrfomos/:emrfomo?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emrfomo.views.pickupview.caption',
            parameters: [
                { pathName: 'emrfomos', parameterName: 'emrfomo' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfomopickup-view/emrfomopickup-view.vue'),
    },
    {
        path: '/emitemcs/:emitemcs?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemcs.views.gridview.caption',
            parameters: [
                { pathName: 'emitemcs', parameterName: 'emitemcs' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemcsgrid-view/emitemcsgrid-view.vue'),
    },
    {
        path: '/emeqlcttires/:emeqlcttires?/editview/:editview?',
        meta: {
            caption: 'entities.emeqlcttires.views.editview.caption',
            parameters: [
                { pathName: 'emeqlcttires', parameterName: 'emeqlcttires' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqlcttiresedit-view/emeqlcttiresedit-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/editview/:editview?',
        meta: {
            caption: 'entities.pfdept.views.editview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/pfdeptedit-view/pfdeptedit-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/optionview/:optionview?',
        meta: {
            caption: 'entities.emitem.views.optionview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemoption-view/emitemoption-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/optionview/:optionview?',
        meta: {
            caption: 'entities.emitem.views.optionview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemoption-view/emitemoption-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/optionview/:optionview?',
        meta: {
            caption: 'entities.emitem.views.optionview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemoption-view/emitemoption-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/optionview/:optionview?',
        meta: {
            caption: 'entities.emitem.views.optionview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemoption-view/emitemoption-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/optionview/:optionview?',
        meta: {
            caption: 'entities.emitem.views.optionview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemoption-view/emitemoption-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/optionview/:optionview?',
        meta: {
            caption: 'entities.emitem.views.optionview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemoption-view/emitemoption-view.vue'),
    },
    {
        path: '/emitems/:emitem?/optionview/:optionview?',
        meta: {
            caption: 'entities.emitem.views.optionview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemoption-view/emitemoption-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitemrin.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinpickup-grid-view/emitemrinpickup-grid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitemrins/:emitemrin?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitemrin.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinpickup-grid-view/emitemrinpickup-grid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitemrins/:emitemrin?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitemrin.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinpickup-grid-view/emitemrinpickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitemrins/:emitemrin?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitemrin.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinpickup-grid-view/emitemrinpickup-grid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitemrin.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinpickup-grid-view/emitemrinpickup-grid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitemrins/:emitemrin?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitemrin.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinpickup-grid-view/emitemrinpickup-grid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emitemrins/:emitemrin?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitemrin.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinpickup-grid-view/emitemrinpickup-grid-view.vue'),
    },
    {
        path: '/emitemrins/:emitemrin?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitemrin.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinpickup-grid-view/emitemrinpickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/editview_7215/:editview_7215?',
        meta: {
            caption: 'entities.emstorepart.views.editview_7215.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'editview_7215', parameterName: 'editview_7215' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstorepartedit-view-7215/emstorepartedit-view-7215.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/editview_7215/:editview_7215?',
        meta: {
            caption: 'entities.emstorepart.views.editview_7215.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'editview_7215', parameterName: 'editview_7215' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstorepartedit-view-7215/emstorepartedit-view-7215.vue'),
    },
    {
        path: '/emeqlocations/:emeqlocation?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emeqlocation.views.tabexpview.caption',
            parameters: [
                { pathName: 'emeqlocations', parameterName: 'emeqlocation' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqlocationtab-exp-view/emeqlocationtab-exp-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/editview9/:editview9?',
        meta: {
            caption: 'entities.empodetail.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/empodetails/:empodetail?/editview9/:editview9?',
        meta: {
            caption: 'entities.empodetail.views.editview9.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/empodetails/:empodetail?/editview9/:editview9?',
        meta: {
            caption: 'entities.empodetail.views.editview9.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/empodetails/:empodetail?/editview9/:editview9?',
        meta: {
            caption: 'entities.empodetail.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/editview9/:editview9?',
        meta: {
            caption: 'entities.empodetail.views.editview9.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/empodetails/:empodetail?/editview9/:editview9?',
        meta: {
            caption: 'entities.empodetail.views.editview9.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
    },
    {
        path: '/empos/:empo?/empodetails/:empodetail?/editview9/:editview9?',
        meta: {
            caption: 'entities.empodetail.views.editview9.caption',
            parameters: [
                { pathName: 'empos', parameterName: 'empo' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
    },
    {
        path: '/emitems/:emitem?/empodetails/:empodetail?/editview9/:editview9?',
        meta: {
            caption: 'entities.empodetail.views.editview9.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
    },
    {
        path: '/empodetails/:empodetail?/editview9/:editview9?',
        meta: {
            caption: 'entities.empodetail.views.editview9.caption',
            parameters: [
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empodetailedit-view9/empodetailedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emstore.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstorepickup-view/emstorepickup-view.vue'),
    },
    {
        path: '/emeqlcttires/:emeqlcttires?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqlcttires.views.gridview.caption',
            parameters: [
                { pathName: 'emeqlcttires', parameterName: 'emeqlcttires' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqlcttiresgrid-view/emeqlcttiresgrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emeqtype.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqtypeedit-view-edit-mode/emeqtypeedit-view-edit-mode.vue'),
    },
    {
        path: '/pfemps/:pfemp?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.pfemp.views.pickupview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-pf/pfemppickup-view/pfemppickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemrout.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemroutedit-view9-edit-mode/emitemroutedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemrout.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemroutedit-view9-edit-mode/emitemroutedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemrout.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemroutedit-view9-edit-mode/emitemroutedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemrout.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemroutedit-view9-edit-mode/emitemroutedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemrout.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemroutedit-view9-edit-mode/emitemroutedit-view9-edit-mode.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemrout.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemroutedit-view9-edit-mode/emitemroutedit-view9-edit-mode.vue'),
    },
    {
        path: '/emitems/:emitem?/emitemrouts/:emitemrout?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemrout.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemroutedit-view9-edit-mode/emitemroutedit-view9-edit-mode.vue'),
    },
    {
        path: '/emitemrouts/:emitemrout?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitemrout.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemroutedit-view9-edit-mode/emitemroutedit-view9-edit-mode.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emrfode.views.pickupview.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfodepickup-view/emrfodepickup-view.vue'),
    },
    {
        path: '/emassetclasses/:emassetclass?/editview/:editview?',
        meta: {
            caption: 'entities.emassetclass.views.editview.caption',
            parameters: [
                { pathName: 'emassetclasses', parameterName: 'emassetclass' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-as/emassetclassedit-view/emassetclassedit-view.vue'),
    },
    {
        path: '/emproducts/:emproduct?/editview9/:editview9?',
        meta: {
            caption: 'entities.emproduct.views.editview9.caption',
            parameters: [
                { pathName: 'emproducts', parameterName: 'emproduct' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emproductedit-view9/emproductedit-view9.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplan.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplan.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplan.views.gridview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplan.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplan.views.gridview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplan.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplan.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplans/:emplan?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplan.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplans/:emplan?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplan.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplans/:emplan?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplan.views.gridview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplans/:emplan?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplan.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
    },
    {
        path: '/emplantempls/:emplantempl?/emplans/:emplan?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplan.views.gridview.caption',
            parameters: [
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emplans/:emplan?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplan.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplans/:emplan?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplan.views.gridview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
    },
    {
        path: '/emplans/:emplan?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplan.views.gridview.caption',
            parameters: [
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplangrid-view/emplangrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitemrin.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinpickup-view/emitemrinpickup-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitemrins/:emitemrin?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitemrin.views.pickupview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinpickup-view/emitemrinpickup-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitemrins/:emitemrin?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitemrin.views.pickupview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinpickup-view/emitemrinpickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitemrins/:emitemrin?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitemrin.views.pickupview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinpickup-view/emitemrinpickup-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitemrin.views.pickupview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinpickup-view/emitemrinpickup-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitemrins/:emitemrin?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitemrin.views.pickupview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinpickup-view/emitemrinpickup-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emitemrins/:emitemrin?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitemrin.views.pickupview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinpickup-view/emitemrinpickup-view.vue'),
    },
    {
        path: '/emitemrins/:emitemrin?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emitemrin.views.pickupview.caption',
            parameters: [
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinpickup-view/emitemrinpickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/gridview/:gridview?',
        meta: {
            caption: 'entities.emenconsum.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/gridview/:gridview?',
        meta: {
            caption: 'entities.emenconsum.views.gridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/gridview/:gridview?',
        meta: {
            caption: 'entities.emenconsum.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/gridview/:gridview?',
        meta: {
            caption: 'entities.emenconsum.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/gridview/:gridview?',
        meta: {
            caption: 'entities.emenconsum.views.gridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/gridview/:gridview?',
        meta: {
            caption: 'entities.emenconsum.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emenconsums/:emenconsum?/gridview/:gridview?',
        meta: {
            caption: 'entities.emenconsum.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emenconsums/:emenconsum?/gridview/:gridview?',
        meta: {
            caption: 'entities.emenconsum.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/gridview/:gridview?',
        meta: {
            caption: 'entities.emenconsum.views.gridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emenconsums/:emenconsum?/gridview/:gridview?',
        meta: {
            caption: 'entities.emenconsum.views.gridview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emenconsums/:emenconsum?/gridview/:gridview?',
        meta: {
            caption: 'entities.emenconsum.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
    },
    {
        path: '/emen/:emen?/emenconsums/:emenconsum?/gridview/:gridview?',
        meta: {
            caption: 'entities.emenconsum.views.gridview.caption',
            parameters: [
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
    },
    {
        path: '/emenconsums/:emenconsum?/gridview/:gridview?',
        meta: {
            caption: 'entities.emenconsum.views.gridview.caption',
            parameters: [
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenconsumgrid-view/emenconsumgrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emdrwgs/:emdrwg?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emdrwg.views.treeexpview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emdrwgs', parameterName: 'emdrwg' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emdrwgtree-exp-view/emdrwgtree-exp-view.vue'),
    },
    {
        path: '/emdrwgs/:emdrwg?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emdrwg.views.treeexpview.caption',
            parameters: [
                { pathName: 'emdrwgs', parameterName: 'emdrwg' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emdrwgtree-exp-view/emdrwgtree-exp-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemprtns/:emitemprtn?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemprtn.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemprtngrid-view/emitemprtngrid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitemprtns/:emitemprtn?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemprtn.views.gridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemprtngrid-view/emitemprtngrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitemprtns/:emitemprtn?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemprtn.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemprtngrid-view/emitemprtngrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitemprtns/:emitemprtn?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemprtn.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemprtngrid-view/emitemprtngrid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitemprtns/:emitemprtn?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemprtn.views.gridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemprtngrid-view/emitemprtngrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitemprtns/:emitemprtn?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemprtn.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemprtngrid-view/emitemprtngrid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emitemprtns/:emitemprtn?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemprtn.views.gridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemprtngrid-view/emitemprtngrid-view.vue'),
    },
    {
        path: '/emitemprtns/:emitemprtn?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemprtn.views.gridview.caption',
            parameters: [
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemprtngrid-view/emitemprtngrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
        meta: {
            caption: 'entities.emplancdt.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
        meta: {
            caption: 'entities.emplancdt.views.editview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
        meta: {
            caption: 'entities.emplancdt.views.editview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
        meta: {
            caption: 'entities.emplancdt.views.editview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
        meta: {
            caption: 'entities.emplancdt.views.editview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
        meta: {
            caption: 'entities.emplancdt.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
        meta: {
            caption: 'entities.emplancdt.views.editview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
        meta: {
            caption: 'entities.emplancdt.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
        meta: {
            caption: 'entities.emplancdt.views.editview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
        meta: {
            caption: 'entities.emplancdt.views.editview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
        meta: {
            caption: 'entities.emplancdt.views.editview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
    },
    {
        path: '/emplantempls/:emplantempl?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
        meta: {
            caption: 'entities.emplancdt.views.editview.caption',
            parameters: [
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
        meta: {
            caption: 'entities.emplancdt.views.editview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
        meta: {
            caption: 'entities.emplancdt.views.editview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
    },
    {
        path: '/emplans/:emplan?/emplancdts/:emplancdt?/editview/:editview?',
        meta: {
            caption: 'entities.emplancdt.views.editview.caption',
            parameters: [
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
    },
    {
        path: '/emplancdts/:emplancdt?/editview/:editview?',
        meta: {
            caption: 'entities.emplancdt.views.editview.caption',
            parameters: [
                { pathName: 'emplancdts', parameterName: 'emplancdt' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplancdtedit-view/emplancdtedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emwos/:emwo?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwo.views.pickupview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwos', parameterName: 'emwo' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwopickup-view/emwopickup-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emwos/:emwo?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwo.views.pickupview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwos', parameterName: 'emwo' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwopickup-view/emwopickup-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emwos/:emwo?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwo.views.pickupview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwos', parameterName: 'emwo' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwopickup-view/emwopickup-view.vue'),
    },
    {
        path: '/emwos/:emwo?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emwo.views.pickupview.caption',
            parameters: [
                { pathName: 'emwos', parameterName: 'emwo' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwopickup-view/emwopickup-view.vue'),
    },
    {
        path: '/pfcontracts/:pfcontract?/gridview/:gridview?',
        meta: {
            caption: 'entities.pfcontract.views.gridview.caption',
            parameters: [
                { pathName: 'pfcontracts', parameterName: 'pfcontract' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/pfcontractgrid-view/pfcontractgrid-view.vue'),
    },
    {
        path: '/empos/:empo?/editview9/:editview9?',
        meta: {
            caption: 'entities.empo.views.editview9.caption',
            parameters: [
                { pathName: 'empos', parameterName: 'empo' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empoedit-view9/empoedit-view9.vue'),
    },
    {
        path: '/emeqspares/:emeqspare?/emeqsparemaps/:emeqsparemap?/editview/:editview?',
        meta: {
            caption: 'entities.emeqsparemap.views.editview.caption',
            parameters: [
                { pathName: 'emeqspares', parameterName: 'emeqspare' },
                { pathName: 'emeqsparemaps', parameterName: 'emeqsparemap' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparemapedit-view/emeqsparemapedit-view.vue'),
    },
    {
        path: '/emeqsparemaps/:emeqsparemap?/editview/:editview?',
        meta: {
            caption: 'entities.emeqsparemap.views.editview.caption',
            parameters: [
                { pathName: 'emeqsparemaps', parameterName: 'emeqsparemap' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparemapedit-view/emeqsparemapedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqdebugs/:emeqdebug?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqdebug.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqdebuggrid-view/emeqdebuggrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqdebugs/:emeqdebug?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqdebug.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqdebuggrid-view/emeqdebuggrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqdebugs/:emeqdebug?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqdebug.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqdebuggrid-view/emeqdebuggrid-view.vue'),
    },
    {
        path: '/emeqdebugs/:emeqdebug?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqdebug.views.gridview.caption',
            parameters: [
                { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqdebuggrid-view/emeqdebuggrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9/:editview9?',
        meta: {
            caption: 'entities.emenconsum.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9/:editview9?',
        meta: {
            caption: 'entities.emenconsum.views.editview9.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9/:editview9?',
        meta: {
            caption: 'entities.emenconsum.views.editview9.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9/:editview9?',
        meta: {
            caption: 'entities.emenconsum.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9/:editview9?',
        meta: {
            caption: 'entities.emenconsum.views.editview9.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9/:editview9?',
        meta: {
            caption: 'entities.emenconsum.views.editview9.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emenconsums/:emenconsum?/editview9/:editview9?',
        meta: {
            caption: 'entities.emenconsum.views.editview9.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emenconsums/:emenconsum?/editview9/:editview9?',
        meta: {
            caption: 'entities.emenconsum.views.editview9.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
    },
    {
        path: '/emitems/:emitem?/emen/:emen?/emenconsums/:emenconsum?/editview9/:editview9?',
        meta: {
            caption: 'entities.emenconsum.views.editview9.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emenconsums/:emenconsum?/editview9/:editview9?',
        meta: {
            caption: 'entities.emenconsum.views.editview9.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
    },
    {
        path: '/emequips/:emequip?/emenconsums/:emenconsum?/editview9/:editview9?',
        meta: {
            caption: 'entities.emenconsum.views.editview9.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
    },
    {
        path: '/emen/:emen?/emenconsums/:emenconsum?/editview9/:editview9?',
        meta: {
            caption: 'entities.emenconsum.views.editview9.caption',
            parameters: [
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
    },
    {
        path: '/emenconsums/:emenconsum?/editview9/:editview9?',
        meta: {
            caption: 'entities.emenconsum.views.editview9.caption',
            parameters: [
                { pathName: 'emenconsums', parameterName: 'emenconsum' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emenconsumedit-view9/emenconsumedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemtrades/:emitemtrade?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emitemtrade.views.treeexpview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtradetree-exp-view/emitemtradetree-exp-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitemtrades/:emitemtrade?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emitemtrade.views.treeexpview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtradetree-exp-view/emitemtradetree-exp-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitemtrades/:emitemtrade?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emitemtrade.views.treeexpview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtradetree-exp-view/emitemtradetree-exp-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitemtrades/:emitemtrade?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emitemtrade.views.treeexpview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtradetree-exp-view/emitemtradetree-exp-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitemtrades/:emitemtrade?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emitemtrade.views.treeexpview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtradetree-exp-view/emitemtradetree-exp-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitemtrades/:emitemtrade?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emitemtrade.views.treeexpview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtradetree-exp-view/emitemtradetree-exp-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emitemtrades/:emitemtrade?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emitemtrade.views.treeexpview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtradetree-exp-view/emitemtradetree-exp-view.vue'),
    },
    {
        path: '/emitemtrades/:emitemtrade?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emitemtrade.views.treeexpview.caption',
            parameters: [
                { pathName: 'emitemtrades', parameterName: 'emitemtrade' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtradetree-exp-view/emitemtradetree-exp-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emwo_oscs/:emwo_osc?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_osc.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-oscedit-view-edit-mode/emwo-oscedit-view-edit-mode.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emwo_oscs/:emwo_osc?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_osc.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-oscedit-view-edit-mode/emwo-oscedit-view-edit-mode.vue'),
    },
    {
        path: '/emequips/:emequip?/emwo_oscs/:emwo_osc?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_osc.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-oscedit-view-edit-mode/emwo-oscedit-view-edit-mode.vue'),
    },
    {
        path: '/emwo_oscs/:emwo_osc?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emwo_osc.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emwo_oscs', parameterName: 'emwo_osc' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emwo-oscedit-view-edit-mode/emwo-oscedit-view-edit-mode.vue'),
    },
    {
        path: '/emproducts/:emproduct?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emproduct.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emproducts', parameterName: 'emproduct' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emproductedit-view9-edit-mode/emproductedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfteams/:pfteam?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.pfteam.views.pickupview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-pf/pfteampickup-view/pfteampickup-view.vue'),
    },
    {
        path: '/emitempls/:emitempl?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempl.views.editview9.caption',
            parameters: [
                { pathName: 'emitempls', parameterName: 'emitempl' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempledit-view9/emitempledit-view9.vue'),
    },
    {
        path: '/empos/:empo?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.empo.views.pickupgridview.caption',
            parameters: [
                { pathName: 'empos', parameterName: 'empo' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/empopickup-grid-view/empopickup-grid-view.vue'),
    },
    {
        path: '/emassets/:emasset?/emassetclears/:emassetclear?/editview/:editview?',
        meta: {
            caption: 'entities.emassetclear.views.editview.caption',
            parameters: [
                { pathName: 'emassets', parameterName: 'emasset' },
                { pathName: 'emassetclears', parameterName: 'emassetclear' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-as/emassetclearedit-view/emassetclearedit-view.vue'),
    },
    {
        path: '/emassetclears/:emassetclear?/editview/:editview?',
        meta: {
            caption: 'entities.emassetclear.views.editview.caption',
            parameters: [
                { pathName: 'emassetclears', parameterName: 'emassetclear' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-as/emassetclearedit-view/emassetclearedit-view.vue'),
    },
    {
        path: '/emassets/:emasset?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emasset.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emassets', parameterName: 'emasset' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-as/emassetedit-view9-edit-mode/emassetedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/editview/:editview?',
        meta: {
            caption: 'entities.emplan.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/editview/:editview?',
        meta: {
            caption: 'entities.emplan.views.editview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/editview/:editview?',
        meta: {
            caption: 'entities.emplan.views.editview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/editview/:editview?',
        meta: {
            caption: 'entities.emplan.views.editview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/editview/:editview?',
        meta: {
            caption: 'entities.emplan.views.editview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/editview/:editview?',
        meta: {
            caption: 'entities.emplan.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/editview/:editview?',
        meta: {
            caption: 'entities.emplan.views.editview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplans/:emplan?/editview/:editview?',
        meta: {
            caption: 'entities.emplan.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplans/:emplan?/editview/:editview?',
        meta: {
            caption: 'entities.emplan.views.editview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplans/:emplan?/editview/:editview?',
        meta: {
            caption: 'entities.emplan.views.editview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplans/:emplan?/editview/:editview?',
        meta: {
            caption: 'entities.emplan.views.editview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
    },
    {
        path: '/emplantempls/:emplantempl?/emplans/:emplan?/editview/:editview?',
        meta: {
            caption: 'entities.emplan.views.editview.caption',
            parameters: [
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emplans/:emplan?/editview/:editview?',
        meta: {
            caption: 'entities.emplan.views.editview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplans/:emplan?/editview/:editview?',
        meta: {
            caption: 'entities.emplan.views.editview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
    },
    {
        path: '/emplans/:emplan?/editview/:editview?',
        meta: {
            caption: 'entities.emplan.views.editview.caption',
            parameters: [
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplanedit-view/emplanedit-view.vue'),
    },
    {
        path: '/emstores/:emstore?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.emstore.views.editview_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstoreedit-view-edit-mode/emstoreedit-view-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemrin.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinedit-view9/emitemrinedit-view9.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitemrins/:emitemrin?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemrin.views.editview9.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinedit-view9/emitemrinedit-view9.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitemrins/:emitemrin?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemrin.views.editview9.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinedit-view9/emitemrinedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitemrins/:emitemrin?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemrin.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinedit-view9/emitemrinedit-view9.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemrin.views.editview9.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinedit-view9/emitemrinedit-view9.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitemrins/:emitemrin?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemrin.views.editview9.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinedit-view9/emitemrinedit-view9.vue'),
    },
    {
        path: '/emitems/:emitem?/emitemrins/:emitemrin?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemrin.views.editview9.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinedit-view9/emitemrinedit-view9.vue'),
    },
    {
        path: '/emitemrins/:emitemrin?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemrin.views.editview9.caption',
            parameters: [
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemrinedit-view9/emitemrinedit-view9.vue'),
    },
    {
        path: '/emeqlctgsses/:emeqlctgss?/gridview_cqyj/:gridview_cqyj?',
        meta: {
            caption: 'entities.emeqlctgss.views.gridview_cqyj.caption',
            parameters: [
                { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                { pathName: 'gridview_cqyj', parameterName: 'gridview_cqyj' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-yj/emeqlctgssgrid-view-cqyj/emeqlctgssgrid-view-cqyj.vue'),
    },
    {
        path: '/emassetclasses/:emassetclass?/editview_4778/:editview_4778?',
        meta: {
            caption: 'entities.emassetclass.views.editview_4778.caption',
            parameters: [
                { pathName: 'emassetclasses', parameterName: 'emassetclass' },
                { pathName: 'editview_4778', parameterName: 'editview_4778' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-as/emassetclassedit-view-4778/emassetclassedit-view-4778.vue'),
    },
    {
        path: '/emeqlocations/:emeqlocation?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqlocation.views.editview9.caption',
            parameters: [
                { pathName: 'emeqlocations', parameterName: 'emeqlocation' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqlocationedit-view9/emeqlocationedit-view9.vue'),
    },
    {
        path: '/emservices/:emservice?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emservice.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emserviceedit-view9-edit-mode/emserviceedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqmaintances/:emeqmaintance?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqmaintance.views.editview9.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqmaintanceedit-view9/emeqmaintanceedit-view9.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqmaintances/:emeqmaintance?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqmaintance.views.editview9.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqmaintanceedit-view9/emeqmaintanceedit-view9.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqmaintances/:emeqmaintance?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqmaintance.views.editview9.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqmaintanceedit-view9/emeqmaintanceedit-view9.vue'),
    },
    {
        path: '/emeqmaintances/:emeqmaintance?/editview9/:editview9?',
        meta: {
            caption: 'entities.emeqmaintance.views.editview9.caption',
            parameters: [
                { pathName: 'emeqmaintances', parameterName: 'emeqmaintance' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqmaintanceedit-view9/emeqmaintanceedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitem.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempickup-grid-view/emitempickup-grid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitem.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempickup-grid-view/emitempickup-grid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitem.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempickup-grid-view/emitempickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitem.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempickup-grid-view/emitempickup-grid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitem.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempickup-grid-view/emitempickup-grid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitem.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempickup-grid-view/emitempickup-grid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emitem.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempickup-grid-view/emitempickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemrin.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemringrid-view/emitemringrid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitemrins/:emitemrin?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemrin.views.gridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemringrid-view/emitemringrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitemrins/:emitemrin?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemrin.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemringrid-view/emitemringrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitemrins/:emitemrin?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemrin.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemringrid-view/emitemringrid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrins/:emitemrin?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemrin.views.gridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemringrid-view/emitemringrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitemrins/:emitemrin?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemrin.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemringrid-view/emitemringrid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emitemrins/:emitemrin?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemrin.views.gridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemringrid-view/emitemringrid-view.vue'),
    },
    {
        path: '/emitemrins/:emitemrin?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemrin.views.gridview.caption',
            parameters: [
                { pathName: 'emitemrins', parameterName: 'emitemrin' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemringrid-view/emitemringrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emplan.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emplan.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emplan.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emplan.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emplan.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emplan.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emplan.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplans/:emplan?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emplan.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplans/:emplan?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emplan.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplans/:emplan?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emplan.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplans/:emplan?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emplan.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
    },
    {
        path: '/emplantempls/:emplantempl?/emplans/:emplan?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emplan.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emplans/:emplan?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emplan.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplans/:emplan?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emplan.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
    },
    {
        path: '/emplans/:emplan?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emplan.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-grid-view/emplanpickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/emservices/:emservice?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/empurplans/:empurplan?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'empurplans', parameterName: 'empurplan' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/emitems/:emitem?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/emequips/:emequip?/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/emitempuses/:emitempuse?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempuse.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9-edit-mode/emitempuseedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeitires/:emeitires?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emeitires.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emeitires', parameterName: 'emeitires' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeitirespickup-grid-view/emeitirespickup-grid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emwos/:emwo?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emwo.views.treeexpview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwos', parameterName: 'emwo' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwotree-exp-view/emwotree-exp-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emwos/:emwo?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emwo.views.treeexpview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwos', parameterName: 'emwo' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwotree-exp-view/emwotree-exp-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emwos/:emwo?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emwo.views.treeexpview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emwos', parameterName: 'emwo' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwotree-exp-view/emwotree-exp-view.vue'),
    },
    {
        path: '/emwos/:emwo?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emwo.views.treeexpview.caption',
            parameters: [
                { pathName: 'emwos', parameterName: 'emwo' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emwotree-exp-view/emwotree-exp-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.empodetail.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/empodetails/:empodetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.empodetail.views.gridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/empodetails/:empodetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.empodetail.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/empodetails/:empodetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.empodetail.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/empodetails/:empodetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.empodetail.views.gridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/empodetails/:empodetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.empodetail.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
    },
    {
        path: '/empos/:empo?/empodetails/:empodetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.empodetail.views.gridview.caption',
            parameters: [
                { pathName: 'empos', parameterName: 'empo' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/empodetails/:empodetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.empodetail.views.gridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
    },
    {
        path: '/empodetails/:empodetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.empodetail.views.gridview.caption',
            parameters: [
                { pathName: 'empodetails', parameterName: 'empodetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/empodetailgrid-view/empodetailgrid-view.vue'),
    },
    {
        path: '/emassets/:emasset?/emassetclears/:emassetclear?/gridview_5564/:gridview_5564?',
        meta: {
            caption: 'entities.emassetclear.views.gridview_5564.caption',
            parameters: [
                { pathName: 'emassets', parameterName: 'emasset' },
                { pathName: 'emassetclears', parameterName: 'emassetclear' },
                { pathName: 'gridview_5564', parameterName: 'gridview_5564' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-as/emassetcleargrid-view-5564/emassetcleargrid-view-5564.vue'),
    },
    {
        path: '/emassetclears/:emassetclear?/gridview_5564/:gridview_5564?',
        meta: {
            caption: 'entities.emassetclear.views.gridview_5564.caption',
            parameters: [
                { pathName: 'emassetclears', parameterName: 'emassetclear' },
                { pathName: 'gridview_5564', parameterName: 'gridview_5564' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-as/emassetcleargrid-view-5564/emassetcleargrid-view-5564.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/optionview/:optionview?',
        meta: {
            caption: 'entities.emplan.views.optionview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/optionview/:optionview?',
        meta: {
            caption: 'entities.emplan.views.optionview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/optionview/:optionview?',
        meta: {
            caption: 'entities.emplan.views.optionview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/optionview/:optionview?',
        meta: {
            caption: 'entities.emplan.views.optionview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/optionview/:optionview?',
        meta: {
            caption: 'entities.emplan.views.optionview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/optionview/:optionview?',
        meta: {
            caption: 'entities.emplan.views.optionview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/optionview/:optionview?',
        meta: {
            caption: 'entities.emplan.views.optionview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplans/:emplan?/optionview/:optionview?',
        meta: {
            caption: 'entities.emplan.views.optionview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplans/:emplan?/optionview/:optionview?',
        meta: {
            caption: 'entities.emplan.views.optionview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplans/:emplan?/optionview/:optionview?',
        meta: {
            caption: 'entities.emplan.views.optionview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplans/:emplan?/optionview/:optionview?',
        meta: {
            caption: 'entities.emplan.views.optionview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
    },
    {
        path: '/emplantempls/:emplantempl?/emplans/:emplan?/optionview/:optionview?',
        meta: {
            caption: 'entities.emplan.views.optionview.caption',
            parameters: [
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emplans/:emplan?/optionview/:optionview?',
        meta: {
            caption: 'entities.emplan.views.optionview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplans/:emplan?/optionview/:optionview?',
        meta: {
            caption: 'entities.emplan.views.optionview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
    },
    {
        path: '/emplans/:emplan?/optionview/:optionview?',
        meta: {
            caption: 'entities.emplan.views.optionview.caption',
            parameters: [
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'optionview', parameterName: 'optionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanoption-view/emplanoption-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqdebugs/:emeqdebug?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqdebug.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqdebugedit-view9-edit-mode/emeqdebugedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqdebugs/:emeqdebug?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqdebug.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqdebugedit-view9-edit-mode/emeqdebugedit-view9-edit-mode.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqdebugs/:emeqdebug?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqdebug.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqdebugedit-view9-edit-mode/emeqdebugedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeqdebugs/:emeqdebug?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqdebug.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emeqdebugs', parameterName: 'emeqdebug' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqdebugedit-view9-edit-mode/emeqdebugedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/editview_editmode/:editview_editmode?',
        meta: {
            caption: 'entities.pfdept.views.editview_editmode.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'editview_editmode', parameterName: 'editview_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/pfdeptedit-view-edit-mode/pfdeptedit-view-edit-mode.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emen.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenpickup-grid-view/emenpickup-grid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emen/:emen?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emen.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenpickup-grid-view/emenpickup-grid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emen/:emen?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emen.views.pickupgridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenpickup-grid-view/emenpickup-grid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emen/:emen?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emen.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenpickup-grid-view/emenpickup-grid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emen/:emen?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emen.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenpickup-grid-view/emenpickup-grid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emen/:emen?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emen.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenpickup-grid-view/emenpickup-grid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emen/:emen?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emen.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenpickup-grid-view/emenpickup-grid-view.vue'),
    },
    {
        path: '/emen/:emen?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.emen.views.pickupgridview.caption',
            parameters: [
                { pathName: 'emen', parameterName: 'emen' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emenpickup-grid-view/emenpickup-grid-view.vue'),
    },
    {
        path: '/emeqspares/:emeqspare?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emeqspare.views.pickupview.caption',
            parameters: [
                { pathName: 'emeqspares', parameterName: 'emeqspare' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparepickup-view/emeqsparepickup-view.vue'),
    },
    {
        path: '/emeqlocations/:emeqlocation?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqlocation.views.gridview.caption',
            parameters: [
                { pathName: 'emeqlocations', parameterName: 'emeqlocation' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqlocationgrid-view/emeqlocationgrid-view.vue'),
    },
    {
        path: '/emeqspares/:emeqspare?/editview/:editview?',
        meta: {
            caption: 'entities.emeqspare.views.editview.caption',
            parameters: [
                { pathName: 'emeqspares', parameterName: 'emeqspare' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqspareedit-view/emeqspareedit-view.vue'),
    },
    {
        path: '/emeqlctfdjs/:emeqlctfdj?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqlctfdj.views.gridview.caption',
            parameters: [
                { pathName: 'emeqlctfdjs', parameterName: 'emeqlctfdj' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqlctfdjgrid-view/emeqlctfdjgrid-view.vue'),
    },
    {
        path: '/emeqspares/:emeqspare?/gridview/:gridview?',
        meta: {
            caption: 'entities.emeqspare.views.gridview.caption',
            parameters: [
                { pathName: 'emeqspares', parameterName: 'emeqspare' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqsparegrid-view/emeqsparegrid-view.vue'),
    },
    {
        path: '/emeitires/:emeitires?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emeitires.views.pickupview.caption',
            parameters: [
                { pathName: 'emeitires', parameterName: 'emeitires' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeitirespickup-view/emeitirespickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemrout.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemroutedit-view9/emitemroutedit-view9.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemrout.views.editview9.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemroutedit-view9/emitemroutedit-view9.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemrout.views.editview9.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemroutedit-view9/emitemroutedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemrout.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemroutedit-view9/emitemroutedit-view9.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemrout.views.editview9.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemroutedit-view9/emitemroutedit-view9.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitemrouts/:emitemrout?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemrout.views.editview9.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemroutedit-view9/emitemroutedit-view9.vue'),
    },
    {
        path: '/emitems/:emitem?/emitemrouts/:emitemrout?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemrout.views.editview9.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemroutedit-view9/emitemroutedit-view9.vue'),
    },
    {
        path: '/emitemrouts/:emitemrout?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemrout.views.editview9.caption',
            parameters: [
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemroutedit-view9/emitemroutedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emitem.views.tabexpview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtab-exp-view/emitemtab-exp-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emitem.views.tabexpview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtab-exp-view/emitemtab-exp-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emitem.views.tabexpview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtab-exp-view/emitemtab-exp-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emitem.views.tabexpview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtab-exp-view/emitemtab-exp-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emitem.views.tabexpview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtab-exp-view/emitemtab-exp-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emitem.views.tabexpview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtab-exp-view/emitemtab-exp-view.vue'),
    },
    {
        path: '/emitems/:emitem?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emitem.views.tabexpview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemtab-exp-view/emitemtab-exp-view.vue'),
    },
    {
        path: '/emoutputs/:emoutput?/gridview/:gridview?',
        meta: {
            caption: 'entities.emoutput.views.gridview.caption',
            parameters: [
                { pathName: 'emoutputs', parameterName: 'emoutput' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emoutputgrid-view/emoutputgrid-view.vue'),
    },
    {
        path: '/emeqlctgsses/:emeqlctgss?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emeqlctgss.views.treeexpview.caption',
            parameters: [
                { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqlctgsstree-exp-view/emeqlctgsstree-exp-view.vue'),
    },
    {
        path: '/emitempls/:emitempl?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emitempl.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emitempls', parameterName: 'emitempl' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempledit-view9-edit-mode/emitempledit-view9-edit-mode.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emeqkeeps/:emeqkeep?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqkeep.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqkeepedit-view9-edit-mode/emeqkeepedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emeqkeeps/:emeqkeep?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqkeep.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqkeepedit-view9-edit-mode/emeqkeepedit-view9-edit-mode.vue'),
    },
    {
        path: '/emequips/:emequip?/emeqkeeps/:emeqkeep?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqkeep.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqkeepedit-view9-edit-mode/emeqkeepedit-view9-edit-mode.vue'),
    },
    {
        path: '/emeqkeeps/:emeqkeep?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqkeep.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emeqkeeps', parameterName: 'emeqkeep' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-act/emeqkeepedit-view9-edit-mode/emeqkeepedit-view9-edit-mode.vue'),
    },
    {
        path: '/emoutputs/:emoutput?/emoutputrcts/:emoutputrct?/gridview/:gridview?',
        meta: {
            caption: 'entities.emoutputrct.views.gridview.caption',
            parameters: [
                { pathName: 'emoutputs', parameterName: 'emoutput' },
                { pathName: 'emoutputrcts', parameterName: 'emoutputrct' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emoutputrctgrid-view/emoutputrctgrid-view.vue'),
    },
    {
        path: '/emoutputrcts/:emoutputrct?/gridview/:gridview?',
        meta: {
            caption: 'entities.emoutputrct.views.gridview.caption',
            parameters: [
                { pathName: 'emoutputrcts', parameterName: 'emoutputrct' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-en/emoutputrctgrid-view/emoutputrctgrid-view.vue'),
    },
    {
        path: '/emeqlocations/:emeqlocation?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emeqlocation.views.pickupview.caption',
            parameters: [
                { pathName: 'emeqlocations', parameterName: 'emeqlocation' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emeqlocationpickup-view/emeqlocationpickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/empurplans/:empurplan?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'empurplans', parameterName: 'empurplan' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/emitempuses/:emitempuse?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitempuse.views.gridview.caption',
            parameters: [
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitempusegrid-view/emitempusegrid-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/editview9/:editview9?',
        meta: {
            caption: 'entities.emrfode.views.editview9.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emrfodeedit-view9/emrfodeedit-view9.vue'),
    },
    {
        path: '/emeqspares/:emeqspare?/emeqsparemaps/:emeqsparemap?/gridview9/:gridview9?',
        meta: {
            caption: 'entities.emeqsparemap.views.gridview9.caption',
            parameters: [
                { pathName: 'emeqspares', parameterName: 'emeqspare' },
                { pathName: 'emeqsparemaps', parameterName: 'emeqsparemap' },
                { pathName: 'gridview9', parameterName: 'gridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqsparemapgrid-view9/emeqsparemapgrid-view9.vue'),
    },
    {
        path: '/emeqsparemaps/:emeqsparemap?/gridview9/:gridview9?',
        meta: {
            caption: 'entities.emeqsparemap.views.gridview9.caption',
            parameters: [
                { pathName: 'emeqsparemaps', parameterName: 'emeqsparemap' },
                { pathName: 'gridview9', parameterName: 'gridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emeqsparemapgrid-view9/emeqsparemapgrid-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/editview_9924/:editview_9924?',
        meta: {
            caption: 'entities.emstore.views.editview_9924.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'editview_9924', parameterName: 'editview_9924' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstoreedit-view-9924/emstoreedit-view-9924.vue'),
    },
    {
        path: '/emobjects/:emobject?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emobject.views.pickupview.caption',
            parameters: [
                { pathName: 'emobjects', parameterName: 'emobject' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emobjectpickup-view/emobjectpickup-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
        meta: {
            caption: 'entities.emplandetail.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
        meta: {
            caption: 'entities.emplandetail.views.editview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
        meta: {
            caption: 'entities.emplandetail.views.editview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
        meta: {
            caption: 'entities.emplandetail.views.editview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
        meta: {
            caption: 'entities.emplandetail.views.editview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
        meta: {
            caption: 'entities.emplandetail.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
        meta: {
            caption: 'entities.emplandetail.views.editview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
        meta: {
            caption: 'entities.emplandetail.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
        meta: {
            caption: 'entities.emplandetail.views.editview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
        meta: {
            caption: 'entities.emplandetail.views.editview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
        meta: {
            caption: 'entities.emplandetail.views.editview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
    },
    {
        path: '/emplantempls/:emplantempl?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
        meta: {
            caption: 'entities.emplandetail.views.editview.caption',
            parameters: [
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
        meta: {
            caption: 'entities.emplandetail.views.editview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
        meta: {
            caption: 'entities.emplandetail.views.editview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
    },
    {
        path: '/emplans/:emplan?/emplandetails/:emplandetail?/editview/:editview?',
        meta: {
            caption: 'entities.emplandetail.views.editview.caption',
            parameters: [
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
    },
    {
        path: '/emplandetails/:emplandetail?/editview/:editview?',
        meta: {
            caption: 'entities.emplandetail.views.editview.caption',
            parameters: [
                { pathName: 'emplandetails', parameterName: 'emplandetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplandetailedit-view/emplandetailedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/editview/:editview?',
        meta: {
            caption: 'entities.pfteam.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/pfteamedit-view/pfteamedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplantempls/:emplantempl?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplantempl.views.gridview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantemplgrid-view/emplantemplgrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplantempls/:emplantempl?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplantempl.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantemplgrid-view/emplantemplgrid-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplantempls/:emplantempl?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplantempl.views.gridview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantemplgrid-view/emplantemplgrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplantempls/:emplantempl?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplantempl.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantemplgrid-view/emplantemplgrid-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplantempls/:emplantempl?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplantempl.views.gridview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantemplgrid-view/emplantemplgrid-view.vue'),
    },
    {
        path: '/emplantempls/:emplantempl?/gridview/:gridview?',
        meta: {
            caption: 'entities.emplantempl.views.gridview.caption',
            parameters: [
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-plan/emplantemplgrid-view/emplantemplgrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/treeexpview/:treeexpview?',
        meta: {
            caption: 'entities.emstore.views.treeexpview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'treeexpview', parameterName: 'treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emstoretree-exp-view/emstoretree-exp-view.vue'),
    },
    {
        path: '/pfcontracts/:pfcontract?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.pfcontract.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'pfcontracts', parameterName: 'pfcontract' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/pfcontractedit-view9-edit-mode/pfcontractedit-view9-edit-mode.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emequip.views.tabexpview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emequiptab-exp-view/emequiptab-exp-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emequip.views.tabexpview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emequiptab-exp-view/emequiptab-exp-view.vue'),
    },
    {
        path: '/emequips/:emequip?/tabexpview/:tabexpview?',
        meta: {
            caption: 'entities.emequip.views.tabexpview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'tabexpview', parameterName: 'tabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emequiptab-exp-view/emequiptab-exp-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemprtn.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemprtnedit-view9/emitemprtnedit-view9.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemprtn.views.editview9.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemprtnedit-view9/emitemprtnedit-view9.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemprtn.views.editview9.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemprtnedit-view9/emitemprtnedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemprtn.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemprtnedit-view9/emitemprtnedit-view9.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemprtn.views.editview9.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemprtnedit-view9/emitemprtnedit-view9.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemprtn.views.editview9.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemprtnedit-view9/emitemprtnedit-view9.vue'),
    },
    {
        path: '/emitems/:emitem?/emitemprtns/:emitemprtn?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemprtn.views.editview9.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemprtnedit-view9/emitemprtnedit-view9.vue'),
    },
    {
        path: '/emitemprtns/:emitemprtn?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemprtn.views.editview9.caption',
            parameters: [
                { pathName: 'emitemprtns', parameterName: 'emitemprtn' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemprtnedit-view9/emitemprtnedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/gridview/:gridview?',
        meta: {
            caption: 'entities.emstorepart.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstorepartgrid-view/emstorepartgrid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/gridview/:gridview?',
        meta: {
            caption: 'entities.emstorepart.views.gridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstorepartgrid-view/emstorepartgrid-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.pfdept.views.pickupview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-pf/pfdeptpickup-view/pfdeptpickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/emstores/:emstore?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/emservices/:emservice?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/empurplans/:empurplan?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'empurplans', parameterName: 'empurplan' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/emitems/:emitem?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/emequips/:emequip?/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/emitempuses/:emitempuse?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitempuse.views.editview9.caption',
            parameters: [
                { pathName: 'emitempuses', parameterName: 'emitempuse' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitempuseedit-view9/emitempuseedit-view9.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emapplies/:emapply?/editview/:editview?',
        meta: {
            caption: 'entities.emapply.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emapplies', parameterName: 'emapply' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emapplyedit-view/emapplyedit-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emapplies/:emapply?/editview/:editview?',
        meta: {
            caption: 'entities.emapply.views.editview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emapplies', parameterName: 'emapply' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emapplyedit-view/emapplyedit-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emapplies/:emapply?/editview/:editview?',
        meta: {
            caption: 'entities.emapply.views.editview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emapplies', parameterName: 'emapply' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emapplyedit-view/emapplyedit-view.vue'),
    },
    {
        path: '/emapplies/:emapply?/editview/:editview?',
        meta: {
            caption: 'entities.emapply.views.editview.caption',
            parameters: [
                { pathName: 'emapplies', parameterName: 'emapply' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wo/emapplyedit-view/emapplyedit-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/editview/:editview?',
        meta: {
            caption: 'entities.emequip.views.editview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emequipedit-view/emequipedit-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/editview/:editview?',
        meta: {
            caption: 'entities.emequip.views.editview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emequipedit-view/emequipedit-view.vue'),
    },
    {
        path: '/emequips/:emequip?/editview/:editview?',
        meta: {
            caption: 'entities.emequip.views.editview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-eq/emequipedit-view/emequipedit-view.vue'),
    },
    {
        path: '/emeqlctgsses/:emeqlctgss?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emeqlctgss.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emeqlctgsses', parameterName: 'emeqlctgss' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-yj/emeqlctgssedit-view9-edit-mode/emeqlctgssedit-view9-edit-mode.vue'),
    },
    {
        path: '/emassetclasses/:emassetclass?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emassetclass.views.pickupview.caption',
            parameters: [
                { pathName: 'emassetclasses', parameterName: 'emassetclass' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-as/emassetclasspickup-view/emassetclasspickup-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplantempls/:emplantempl?/emplans/:emplan?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emplan.views.pickupview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplantempls/:emplantempl?/emplans/:emplan?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emplan.views.pickupview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplantempls/:emplantempl?/emplans/:emplan?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emplan.views.pickupview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplantempls/:emplantempl?/emplans/:emplan?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emplan.views.pickupview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplantempls/:emplantempl?/emplans/:emplan?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emplan.views.pickupview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emequips/:emequip?/emplans/:emplan?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emplan.views.pickupview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
    },
    {
        path: '/emeqtypes/:emeqtype?/emequips/:emequip?/emplans/:emplan?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emplan.views.pickupview.caption',
            parameters: [
                { pathName: 'emeqtypes', parameterName: 'emeqtype' },
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
    },
    {
        path: '/pfteams/:pfteam?/emplans/:emplan?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emplan.views.pickupview.caption',
            parameters: [
                { pathName: 'pfteams', parameterName: 'pfteam' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emplans/:emplan?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emplan.views.pickupview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
    },
    {
        path: '/pfdepts/:pfdept?/emplans/:emplan?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emplan.views.pickupview.caption',
            parameters: [
                { pathName: 'pfdepts', parameterName: 'pfdept' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emplans/:emplan?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emplan.views.pickupview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
    },
    {
        path: '/emplantempls/:emplantempl?/emplans/:emplan?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emplan.views.pickupview.caption',
            parameters: [
                { pathName: 'emplantempls', parameterName: 'emplantempl' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
    },
    {
        path: '/emequips/:emequip?/emplans/:emplan?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emplan.views.pickupview.caption',
            parameters: [
                { pathName: 'emequips', parameterName: 'emequip' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
    },
    {
        path: '/emacclasses/:emacclass?/emplans/:emplan?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emplan.views.pickupview.caption',
            parameters: [
                { pathName: 'emacclasses', parameterName: 'emacclass' },
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
    },
    {
        path: '/emplans/:emplan?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emplan.views.pickupview.caption',
            parameters: [
                { pathName: 'emplans', parameterName: 'emplan' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emplanpickup-view/emplanpickup-view.vue'),
    },
    {
        path: '/emstores/:emstore?/gridview_7848/:gridview_7848?',
        meta: {
            caption: 'entities.emstore.views.gridview_7848.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'gridview_7848', parameterName: 'gridview_7848' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstoregrid-view-7848/emstoregrid-view-7848.vue'),
    },
    {
        path: '/emrfodetypes/:emrfodetype?/editview/:editview?',
        meta: {
            caption: 'entities.emrfodetype.views.editview.caption',
            parameters: [
                { pathName: 'emrfodetypes', parameterName: 'emrfodetype' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfodetypeedit-view/emrfodetypeedit-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emstocks/:emstock?/editview/:editview?',
        meta: {
            caption: 'entities.emstock.views.editview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emstocks/:emstock?/editview/:editview?',
        meta: {
            caption: 'entities.emstock.views.editview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emstocks/:emstock?/editview/:editview?',
        meta: {
            caption: 'entities.emstock.views.editview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emstocks/:emstock?/editview/:editview?',
        meta: {
            caption: 'entities.emstock.views.editview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emstocks/:emstock?/editview/:editview?',
        meta: {
            caption: 'entities.emstock.views.editview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emstocks/:emstock?/editview/:editview?',
        meta: {
            caption: 'entities.emstock.views.editview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emstocks/:emstock?/editview/:editview?',
        meta: {
            caption: 'entities.emstock.views.editview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstocks/:emstock?/editview/:editview?',
        meta: {
            caption: 'entities.emstock.views.editview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emstocks/:emstock?/editview/:editview?',
        meta: {
            caption: 'entities.emstock.views.editview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emstocks/:emstock?/editview/:editview?',
        meta: {
            caption: 'entities.emstock.views.editview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
    },
    {
        path: '/emstocks/:emstock?/editview/:editview?',
        meta: {
            caption: 'entities.emstock.views.editview.caption',
            parameters: [
                { pathName: 'emstocks', parameterName: 'emstock' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emstockedit-view/emstockedit-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrouts/:emitemrout?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemrout.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemroutgrid-view/emitemroutgrid-view.vue'),
    },
    {
        path: '/pfunits/:pfunit?/emitems/:emitem?/emitemrouts/:emitemrout?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemrout.views.gridview.caption',
            parameters: [
                { pathName: 'pfunits', parameterName: 'pfunit' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemroutgrid-view/emitemroutgrid-view.vue'),
    },
    {
        path: '/pfemps/:pfemp?/emitems/:emitem?/emitemrouts/:emitemrout?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemrout.views.gridview.caption',
            parameters: [
                { pathName: 'pfemps', parameterName: 'pfemp' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemroutgrid-view/emitemroutgrid-view.vue'),
    },
    {
        path: '/emstores/:emstore?/emitems/:emitem?/emitemrouts/:emitemrout?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemrout.views.gridview.caption',
            parameters: [
                { pathName: 'emstores', parameterName: 'emstore' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemroutgrid-view/emitemroutgrid-view.vue'),
    },
    {
        path: '/emstoreparts/:emstorepart?/emitems/:emitem?/emitemrouts/:emitemrout?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemrout.views.gridview.caption',
            parameters: [
                { pathName: 'emstoreparts', parameterName: 'emstorepart' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemroutgrid-view/emitemroutgrid-view.vue'),
    },
    {
        path: '/emservices/:emservice?/emitems/:emitem?/emitemrouts/:emitemrout?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemrout.views.gridview.caption',
            parameters: [
                { pathName: 'emservices', parameterName: 'emservice' },
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemroutgrid-view/emitemroutgrid-view.vue'),
    },
    {
        path: '/emitems/:emitem?/emitemrouts/:emitemrout?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemrout.views.gridview.caption',
            parameters: [
                { pathName: 'emitems', parameterName: 'emitem' },
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemroutgrid-view/emitemroutgrid-view.vue'),
    },
    {
        path: '/emitemrouts/:emitemrout?/gridview/:gridview?',
        meta: {
            caption: 'entities.emitemrout.views.gridview.caption',
            parameters: [
                { pathName: 'emitemrouts', parameterName: 'emitemrout' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-mat/emitemroutgrid-view/emitemroutgrid-view.vue'),
    },
    {
        path: '/emrfodes/:emrfode?/editview9_editmode/:editview9_editmode?',
        meta: {
            caption: 'entities.emrfode.views.editview9_editmode.caption',
            parameters: [
                { pathName: 'emrfodes', parameterName: 'emrfode' },
                { pathName: 'editview9_editmode', parameterName: 'editview9_editmode' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-rfo/emrfodeedit-view9-edit-mode/emrfodeedit-view9-edit-mode.vue'),
    },
    {
        path: '/emassets/:emasset?/emassetclears/:emassetclear?/gridview/:gridview?',
        meta: {
            caption: 'entities.emassetclear.views.gridview.caption',
            parameters: [
                { pathName: 'emassets', parameterName: 'emasset' },
                { pathName: 'emassetclears', parameterName: 'emassetclear' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-as/emassetcleargrid-view/emassetcleargrid-view.vue'),
    },
    {
        path: '/emassetclears/:emassetclear?/gridview/:gridview?',
        meta: {
            caption: 'entities.emassetclear.views.gridview.caption',
            parameters: [
                { pathName: 'emassetclears', parameterName: 'emassetclear' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-as/emassetcleargrid-view/emassetcleargrid-view.vue'),
    },
    {
        path: '/emserviceevls/:emserviceevl?/gridview/:gridview?',
        meta: {
            caption: 'entities.emserviceevl.views.gridview.caption',
            parameters: [
                { pathName: 'emserviceevls', parameterName: 'emserviceevl' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-wp/emserviceevlgrid-view/emserviceevlgrid-view.vue'),
    },
    {
        path: '/emitemcs/:emitemcs?/editview9/:editview9?',
        meta: {
            caption: 'entities.emitemcs.views.editview9.caption',
            parameters: [
                { pathName: 'emitemcs', parameterName: 'emitemcs' },
                { pathName: 'editview9', parameterName: 'editview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emitemcsedit-view9/emitemcsedit-view9.vue'),
    },
    {
        path: '/emassets/:emasset?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.emasset.views.pickupview.caption',
            parameters: [
                { pathName: 'emassets', parameterName: 'emasset' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/eam-core/emassetpickup-view/emassetpickup-view.vue'),
    },
        ...globalRoutes,
        {
            path: '/login/:login?',
            name: 'login',
            meta: {  
                caption: '登录',
                viewType: 'login',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                router.app.$store.commit('resetRootStateData');
                next();
            },
            component: () => import('@components/login/login.vue'),
        },
        {
            path: '/404',
            component: () => import('@components/404/404.vue')
        },
        {
            path: '/500',
            component: () => import('@components/500/500.vue')
        },
        {
            path: '*',
            redirect: 'appindex'
        },
    ],
});

export default router;
